bible_names = {
    "Aaron": "<b>Aaron</b> - A Teacher; Lofty; Mountain Of Strength",
    "Abaddon": "<b>Abaddon</b> - The Destroyer",
    "Abagtha": "<b>Abagtha</b> - Father Of The Wine-Press",
    "Abana": "<b>Abana</b> - Made Of Stone; A Building",
    "Abarim": "<b>Abarim</b> - Passages; Passengers",
    "Abba": "<b>Abba</b> - Father",
    "Abda": "<b>Abda</b> - A Servant; Servitude",
    "Abdeel": "<b>Abdeel</b> - A Vapor; A Cloud Of God",
    "Abdi": "<b>Abdi</b> - My Servant",
    "Abdiel": "<b>Abdiel</b> - Servant Of God",
    "Abdon": "<b>Abdon</b> - Servant; Cloud Of Judgment",
    "Abednego": "<b>Abednego</b> - Servant Of Light; Shining",
    "Abel": "<b>Abel</b> - Vanity; Breath; Vapor",
    "Abel": "<b>Abel</b> - A City; Mourning",
    "Abel-Beth-Maachah": "<b>Abel-Beth-Maachah</b> - Mourning To The House Of Maachah",
    "Abel-Maim": "<b>Abel-Maim</b> - Mourning Of Waters",
    "Abel-Meholah": "<b>Abel-Meholah</b> - Mourning Of Sickness",
    "Abel-Mizraim": "<b>Abel-Mizraim</b> - The Mourning Of Egyptians",
    "Abel-Shittim": "<b>Abel-Shittim</b> - Mourning Of Thorns",
    "Abez": "<b>Abez</b> - An Egg; Muddy",
    "Abi": "<b>Abi</b> - My Father",
    "Abi-Albon": "<b>Abi-Albon</b> - Most Intelligent Father",
    "Abiah": "<b>Abiah</b> - The Lord Is My Father",
    "Abiasaph": "<b>Abiasaph</b> - Consuming Father; Gathering",
    "Abiathar": "<b>Abiathar</b> - Excellent Father; Father Of The Remnant",
    "Abib": "<b>Abib</b> - Green Fruit; Ears Of Corn",
    "Abidah": "<b>Abidah</b> - Father Of Knowledge",
    "Abidan": "<b>Abidan</b> - Father Of Judgment",
    "Abiel": "<b>Abiel</b> - God My Father",
    "Abiezer": "<b>Abiezer</b> - Father Of Help",
    "Abigail": "<b>Abigail</b> - The Father'S Joy",
    "Abihail": "<b>Abihail</b> - The Father Of Strength",
    "Abihu": "<b>Abihu</b> - He Is My Father",
    "Abihud": "<b>Abihud</b> - Father Of Praise; Confession",
    "Abijah": "<b>Abijah</b> - The Lord Is My Father",
    "Abijam": "<b>Abijam</b> - Father Of The Sea",
    "Abilene": "<b>Abilene</b> - The Father Of Mourning",
    "Abimael": "<b>Abimael</b> - A Father Sent From God",
    "Abimelech": "<b>Abimelech</b> - Father Of The King",
    "Abinadab": "<b>Abinadab</b> - Father Of A Vow, Or Of Willingness",
    "Abinoam": "<b>Abinoam</b> - Father Of Beauty",
    "Abiram": "<b>Abiram</b> - High Father; Father Of Deceit",
    "Abishag": "<b>Abishag</b> - Ignorance Of The Father",
    "Abishai": "<b>Abishai</b> - The Present Of My Father",
    "Abishalom": "<b>Abishalom</b> - Father Of Peace",
    "Abishua": "<b>Abishua</b> - Father Of Salvation",
    "Abishur": "<b>Abishur</b> - Father Of The Wall; Father Of Uprightness",
    "Abital": "<b>Abital</b> - The Father Of The Dew; Or Of The Shadow",
    "Abitub": "<b>Abitub</b> - Father Of Goodness",
    "Abiud": "<b>Abiud</b> - Father Of Praise",
    "Abner": "<b>Abner</b> - Father Of Light",
    "Abraham": "<b>Abraham</b> - Father Of A Great Multitude",
    "Abram": "<b>Abram</b> - High Father",
    "Absalom": "<b>Absalom</b> - Father Of Peace",
    "Accad": "<b>Accad</b> - A Vessel; Pitcher; Spark",
    "Accho": "<b>Accho</b> - Close; Pressed Together",
    "Aceldama": "<b>Aceldama</b> - Field Of Blood",
    "Achab": "<b>Achab</b> - Brother Of The Father",
    "Achaia": "<b>Achaia</b> - Grief; Trouble",
    "Achaicus": "<b>Achaicus</b> - A Native Of Achaia; Sorrowing; Sad",
    "Achan": "<b>Achan</b> - Or Achar, He That Troubleth",
    "Achaz": "<b>Achaz</b> - One That Takes, Or Possesses",
    "Achbor": "<b>Achbor</b> - A Rat; Bruising",
    "Achim": "<b>Achim</b> - Preparing; Revenging; Confirming",
    "Achish": "<b>Achish</b> - Thus It Is; How Is This",
    "Achmetha": "<b>Achmetha</b> - Brother Of Death",
    "Achor": "<b>Achor</b> - Trouble",
    "Achsah": "<b>Achsah</b> - Adorned; Bursting The Veil",
    "Achshaph": "<b>Achshaph</b> - Poison; Tricks",
    "Achzib": "<b>Achzib</b> - Liar; Lying; One That Runs",
    "Adadah": "<b>Adadah</b> - Testimony Of The Assembly",
    "Adah": "<b>Adah</b> - An Assembly",
    "Adaiah": "<b>Adaiah</b> - The Witness Of The Lord",
    "Adaliah": "<b>Adaliah</b> - One That Draws Water; Poverty; Cloud; Death",
    "Adam": "<b>Adam</b> - Earthy; Red",
    "Adamah": "<b>Adamah</b> - Red Earth; Of Blood",
    "Adami": "<b>Adami</b> - My Man; Red; Earthy; Human",
    "Adar": "<b>Adar</b> - High; Eminent",
    "Adbeel": "<b>Adbeel</b> - Vapor, Or Cloud Of God",
    "Addi": "<b>Addi</b> - My Witness; Adorned; Prey",
    "Addin": "<b>Addin</b> - Adorned; Delicious; Voluptuous",
    "Addon": "<b>Addon</b> - Basis; Foundation; The Lord",
    "Adiel": "<b>Adiel</b> - The Witness Of The Lord",
    "Adin": "<b>Adin</b> - Adina, Adorned; Voluptuous; Dainty",
    "Adithaim": "<b>Adithaim</b> - Assemblies; Testimonies",
    "Adlai": "<b>Adlai</b> - My Witness; My Ornament",
    "Admah": "<b>Admah</b> - Earthy; Red; Bloody",
    "Admatha": "<b>Admatha</b> - A Cloud Of Death; A Mortal Vapor",
    "Adna": "<b>Adna</b> - Pleasure; Delight",
    "Adnah": "<b>Adnah</b> - Eternal Rest",
    "Adoni-Bezek": "<b>Adoni-Bezek</b> - The Lightning Of The Lord; The Lord Of Lightning",
    "Adoni-Zedek": "<b>Adoni-Zedek</b> - Justice Of The Lord; Lord Of Justice",
    "Adonijah": "<b>Adonijah</b> - The Lord Is My Master",
    "Adonikam": "<b>Adonikam</b> - The Lord Is Raised",
    "Adoniram": "<b>Adoniram</b> - My Lord Is Most High; Lord Of Might And Elevation",
    "Adoraim": "<b>Adoraim</b> - Strength Of The Sea",
    "Adoram": "<b>Adoram</b> - Their Beauty; Their Power",
    "Adrammelech": "<b>Adrammelech</b> - The Cloak, Glory, Grandeur Or Power Of The King",
    "Adramyttium": "<b>Adramyttium</b> - The Court Of Death",
    "Adriel": "<b>Adriel</b> - The Flock Of God",
    "Adullam": "<b>Adullam</b> - Their Testimony; Their Prey; Their Ornament",
    "Adummim": "<b>Adummim</b> - Earthy; Red; Bloody Things",
    "Aeneas": "<b>Aeneas</b> - Praised; Praiseworthy",
    "Aenon": "<b>Aenon</b> - A Cloud; Fountain; His Eye",
    "Agabus": "<b>Agabus</b> - A Locust; The Father'S Joy Or Feast",
    "Agag": "<b>Agag</b> - Roof; Upper Floor",
    "Agar": "<b>Agar</b> - Or Hagar, A Stranger; One That Fears",
    "Agee": "<b>Agee</b> - A Valley; Deepness",
    "Agrippa": "<b>Agrippa</b> - One Who Causes Great Pain At His Birth",
    "Agur": "<b>Agur</b> - Stranger; Gathered Together",
    "Ahab": "<b>Ahab</b> - Uncle, Or Father'S Brother",
    "Aharah": "<b>Aharah</b> - A Smiling Brother; A Meadow Of A Sweet Savor",
    "Aharhel": "<b>Aharhel</b> - Another Host; The Last Sorrow; A Brother'S Sheep",
    "Ahasbai": "<b>Ahasbai</b> - Trusting In Me; A Grown-Up Brother",
    "Ahasuerus": "<b>Ahasuerus</b> - Prince; Head; Chief",
    "Ahava": "<b>Ahava</b> - Essence; Being; Generation",
    "Ahaz": "<b>Ahaz</b> - One That Takes Or Possesses",
    "Ahaziah": "<b>Ahaziah</b> - Seizure; Vision Of The Lord",
    "Ahi": "<b>Ahi</b> - My Brother; My Brethren",
    "Ahiah": "<b>Ahiah</b> - Brother Of The Lord",
    "Ahiam": "<b>Ahiam</b> - Mother'S Brother; Brother Of A Nation",
    "Ahian": "<b>Ahian</b> - Brother Of Wine",
    "Ahiezer": "<b>Ahiezer</b> - Brother Of Assistance",
    "Ahihud": "<b>Ahihud</b> - Brother Of Vanity, Or Of Darkness, Or Of Joy, Or Of Praise; Witty Brother",
    "Ahijah": "<b>Ahijah</b> - Same With Ahiah",
    "Ahikam": "<b>Ahikam</b> - A Brother Who Raises Up Or Avenges",
    "Ahilud": "<b>Ahilud</b> - A Brother Born, Or Begotten",
    "Ahimaaz": "<b>Ahimaaz</b> - A Brother Of The Council",
    "Ahiman": "<b>Ahiman</b> - Brother Of The Right Hand",
    "Ahimelech": "<b>Ahimelech</b> - My Brother Is A King; My King'S Brother",
    "Ahimoth": "<b>Ahimoth</b> - Brother Of Death",
    "Ahinadab": "<b>Ahinadab</b> - A Willing Brother; Brother Of A Vow",
    "Ahinoam": "<b>Ahinoam</b> - Beauty Of The Brother; Brother Of Motion",
    "Ahio": "<b>Ahio</b> - His Brother; His Brethren",
    "Ahira": "<b>Ahira</b> - Brother Of Iniquity; Brother Of The Shepherd",
    "Ahiram": "<b>Ahiram</b> - Brother Of Craft, Or Of Protection",
    "Ahisamach": "<b>Ahisamach</b> - Brother Of Strength",
    "Ahishahur": "<b>Ahishahur</b> - Brother Of The Morning Or Dew; Brother Of Blackness",
    "Ahishar": "<b>Ahishar</b> - Brother Of A Prince; Brother Of A Song",
    "Ahithophel": "<b>Ahithophel</b> - Brother Of Ruin Or Folly",
    "Ahitub": "<b>Ahitub</b> - Brother Of Goodness",
    "Ahlab": "<b>Ahlab</b> - Made Of Milk, Or Of Fat; Brother Of The Heart",
    "Ahlai": "<b>Ahlai</b> - Beseeching; Sorrowing; Expecting",
    "Ahoah": "<b>Ahoah</b> - A Live Brother; My Thorn Or Thistle",
    "Aholah": "<b>Aholah</b> - His Tabernacle; His Tent",
    "Aholiab": "<b>Aholiab</b> - The Tent Of The Father",
    "Aholibah": "<b>Aholibah</b> - My Tent, Or My Tabernacle, In Her",
    "Aholibamah": "<b>Aholibamah</b> - My Tabernacle Is Exalted",
    "Ahumai": "<b>Ahumai</b> - A Meadow Of Waters; A Brother Of Waters",
    "Ahuzam": "<b>Ahuzam</b> - Their Taking Or Possessing Vision",
    "Ahuzzah": "<b>Ahuzzah</b> - Possession; Seizing; Collecting",
    "Ai": "<b>Ai</b> - Or Hai, Mass; Heap",
    "Aiah": "<b>Aiah</b> - Vulture, Raven; An Isle; Alas, Where Is It?",
    "Aiath": "<b>Aiath</b> - Same As Ai; An Hour; Eye; Fountain",
    "Aijeleth-Shahar": "<b>Aijeleth-Shahar</b> - The Land Of The Morning",
    "Ain": "<b>Ain</b> - Same As Aiath",
    "Ajalon": "<b>Ajalon</b> - A Chain; Strength; A Stag",
    "Akkub": "<b>Akkub</b> - Foot-Print; Supplanting; Crookedness; Lewdness",
    "Akrabbim": "<b>Akrabbim</b> - Scorpions",
    "Alammelech": "<b>Alammelech</b> - God Is King",
    "Alemeth": "<b>Alemeth</b> - Hiding; Youth; Worlds; Upon The Dead",
    "Alexander": "<b>Alexander</b> - One Who Assists Men",
    "Alian": "<b>Alian</b> - High",
    "Alleluia": "<b>Alleluia</b> - Praise The Lord",
    "Allon": "<b>Allon</b> - An Oak; Strong",
    "Allon-Bachuth": "<b>Allon-Bachuth</b> - The Oak Of Weeping",
    "Almodad": "<b>Almodad</b> - Measure Of God",
    "Almon": "<b>Almon</b> - Hidden",
    "Almon-Diblathaim": "<b>Almon-Diblathaim</b> - Hidden In A Cluster Of Fig Trees",
    "Alpheus": "<b>Alpheus</b> - A Thousand; Learned; Chief",
    "Alush": "<b>Alush</b> - Mingling Together",
    "Alvah": "<b>Alvah</b> - His Rising Up; His Highness",
    "Amad": "<b>Amad</b> - People Of Witness; A Prey",
    "Amal": "<b>Amal</b> - Labor; Iniquity",
    "Amalek": "<b>Amalek</b> - A People That Licks Up",
    "Aman": "<b>Aman</b> - Mother; Fear Of Them",
    "Amana": "<b>Amana</b> - Integrity; Truth; A Nurse",
    "Amariah": "<b>Amariah</b> - The Lord Says; The Integrity Of The Lord",
    "Amasa": "<b>Amasa</b> - Sparing The People",
    "Amasai": "<b>Amasai</b> - Strong",
    "Amashai": "<b>Amashai</b> - The People'S Gift",
    "Amashi-Ali": "<b>Amashi-Ali</b> - Same As Amaziah",
    "Amaziah": "<b>Amaziah</b> - The Strength Of The Lord",
    "Ami": "<b>Ami</b> - Mother; Fear; People",
    "Aminadab": "<b>Aminadab</b> - Same As Amminadab",
    "Amittai": "<b>Amittai</b> - True; Fearing",
    "Ammah": "<b>Ammah</b> - My, Or His, People",
    "Ammi": "<b>Ammi</b> - Same As Ammah",
    "Ammi-Nadab": "<b>Ammi-Nadab</b> - My People Is Liberal",
    "Ammiel": "<b>Ammiel</b> - The People Of God",
    "Ammihud": "<b>Ammihud</b> - People Of Praise",
    "Ammishaddai": "<b>Ammishaddai</b> - The People Of The Almighty; The Almighty Is With Me",
    "Ammizabad": "<b>Ammizabad</b> - Dowry Of The People",
    "Ammon": "<b>Ammon</b> - A People; The Son Of My People",
    "Amnon": "<b>Amnon</b> - Faithful And True; Tutor",
    "Amok": "<b>Amok</b> - A Valley; A Depth",
    "Amon": "<b>Amon</b> - Faithful; True",
    "Amorite": "<b>Amorite</b> - Bitter; A Rebel; A Babbler",
    "Amos": "<b>Amos</b> - Loading; Weighty",
    "Amoz": "<b>Amoz</b> - Strong; Robust",
    "Amplias": "<b>Amplias</b> - Large; Extensive",
    "Amram": "<b>Amram</b> - An Exalted People; Their Sheaves; Handfuls Of Corn",
    "Amraphel": "<b>Amraphel</b> - One That Speaks Of Secrets",
    "Amzi": "<b>Amzi</b> - Strong, Mighty",
    "Anab": "<b>Anab</b> - A Grape; A Knot",
    "Anah": "<b>Anah</b> - One Who Answers; Afflicted",
    "Anaharath": "<b>Anaharath</b> - Dryness, Burning, Wrath",
    "Anak": "<b>Anak</b> - A Collar; Ornament",
    "Anamim": "<b>Anamim</b> - A Fountain; Answer; Affliction",
    "Anammelech": "<b>Anammelech</b> - Answer; Poverty Of The King",
    "Anani": "<b>Anani</b> - A Cloud; Prophecy; Divination",
    "Ananias": "<b>Ananias</b> - Or Ananiah, The Cloud Of The Lord",
    "Anathema": "<b>Anathema</b> - Separated; Set Apart",
    "Anathoth": "<b>Anathoth</b> - Or Anath, Answer; Song; Poverty",
    "Andrew": "<b>Andrew</b> - A Strong Man",
    "Andronicus": "<b>Andronicus</b> - A Man Excelling Others",
    "Anem": "<b>Anem</b> - Or Anen, An Answer; Their Affliction",
    "Aner": "<b>Aner</b> - Answer; Song; Affliction",
    "Aniam": "<b>Aniam</b> - A People; The Strength Or Sorrow Of People",
    "Anim": "<b>Anim</b> - Answerings; Singings; Afflicted",
    "Anna": "<b>Anna</b> - Gracious; One Who Gives",
    "Annas": "<b>Annas</b> - One Who Answers; Humble",
    "Antichrist": "<b>Antichrist</b> - An Adversary To Christ",
    "Antioch": "<b>Antioch</b> - Speedy As A Chariot",
    "Antipas": "<b>Antipas</b> - For All, Or Against All",
    "Antipatris": "<b>Antipatris</b> - For, Or Against The Father",
    "Antothijah": "<b>Antothijah</b> - Answers Or Songs Of The Lord; Afflictions",
    "Anub": "<b>Anub</b> - Same As Anab",
    "Apelles": "<b>Apelles</b> - Exclusion; Separation",
    "Apharsathchites": "<b>Apharsathchites</b> - Apharsites (From A Root Meaning) Dividing Or Rending",
    "Aphek": "<b>Aphek</b> - Aphekah, Aphik, Strength; A Rapid Torrent",
    "Aphiah": "<b>Aphiah</b> - Speaking, Blowing",
    "Apocalypse": "<b>Apocalypse</b> - Uncovering, Revelation",
    "Apocrypha": "<b>Apocrypha</b> - Hidden",
    "Apollonia": "<b>Apollonia</b> - Perdition, Destruction",
    "Apollonius": "<b>Apollonius</b> - Destroying",
    "Apollos": "<b>Apollos</b> - One Who Destroys; Destroyer",
    "Apollyon": "<b>Apollyon</b> - A Destroyer",
    "Appaim": "<b>Appaim</b> - Face; Nostrils",
    "Apphia": "<b>Apphia</b> - Productive; Fruitful",
    "Aquila": "<b>Aquila</b> - An Eagle",
    "Ar": "<b>Ar</b> - Awakening; Uncovering",
    "Ara": "<b>Ara</b> - Cursing; Seeing",
    "Arab": "<b>Arab</b> - Multiplying; Sowing Sedition; A Window; A Locust",
    "Arabia": "<b>Arabia</b> - Evening; Desert; Ravens",
    "Arad": "<b>Arad</b> - A Wild Ass; A Dragon",
    "Arah": "<b>Arah</b> - The Way; A Traveler",
    "Aram": "<b>Aram</b> - Highness, Magnificence, One That Deceives; Curse",
    "Aran": "<b>Aran</b> - An Ark; Their Curse",
    "Ararat": "<b>Ararat</b> - The Curse Of Trembling",
    "Araunah": "<b>Araunah</b> - Ark; Song; Joyful Cry",
    "Arba": "<b>Arba</b> - Four",
    "Archelaus": "<b>Archelaus</b> - The Prince Of The People",
    "Archippus": "<b>Archippus</b> - A Master Of Horses",
    "Arcturus": "<b>Arcturus</b> - A Gathering Together",
    "Ard": "<b>Ard</b> - One That Commands; He That Descends",
    "Ardon": "<b>Ardon</b> - Ruling; A Judgment Of Malediction",
    "Areli": "<b>Areli</b> - The Light Or Vision Of God",
    "Areopagus": "<b>Areopagus</b> - The Hill Of Mars",
    "Aretas": "<b>Aretas</b> - Agreeable, Virtuous",
    "Argob": "<b>Argob</b> - A Turf, Or Fat Land",
    "Ariel": "<b>Ariel</b> - Altar; Light Or Lion Of God",
    "Arimathea": "<b>Arimathea</b> - A Lion Dead To The Lord",
    "Arioch": "<b>Arioch</b> - Long; Great; Tall",
    "Aristarchus": "<b>Aristarchus</b> - The Best Prince",
    "Aristobulus": "<b>Aristobulus</b> - A Good Counselor",
    "Armageddon": "<b>Armageddon</b> - Hill Of Fruits; Mountain Of Megiddo",
    "Arnon": "<b>Arnon</b> - Rejoicing; Sunlight",
    "Aroer": "<b>Aroer</b> - Heath; Tamarisk",
    "Arpad": "<b>Arpad</b> - The Light Of Redemption",
    "Arphaxad": "<b>Arphaxad</b> - A Healer; A Releaser",
    "Artaxerxes": "<b>Artaxerxes</b> - The Silence Of Light; Fervent To Spoil",
    "Artemas": "<b>Artemas</b> - Whole, Sound",
    "Arumah": "<b>Arumah</b> - High; Exalted",
    "Asa": "<b>Asa</b> - Physician; Cure",
    "Asahel": "<b>Asahel</b> - Creature Of God",
    "Asaiah": "<b>Asaiah</b> - The Lord Hath Wrought",
    "Asaph": "<b>Asaph</b> - Who Gathers Together",
    "Asareel": "<b>Asareel</b> - The Beatitude Of God",
    "Asenath": "<b>Asenath</b> - Peril; Misfortune",
    "Ashan": "<b>Ashan</b> - Smoke",
    "Ashbel": "<b>Ashbel</b> - An Old Fire",
    "Ashdod": "<b>Ashdod</b> - Effusion; Inclination; Theft",
    "Asher": "<b>Asher</b> - Happiness",
    "Ashima": "<b>Ashima</b> - Crime; Offense",
    "Ashkenaz": "<b>Ashkenaz</b> - A Fire That Spreads",
    "Ashnah": "<b>Ashnah</b> - Change",
    "Ashriel": "<b>Ashriel</b> - Same As Asareel",
    "Ashtaroth": "<b>Ashtaroth</b> - Ashtoreth, Flocks; Sheep; Riches",
    "Ashur": "<b>Ashur</b> - Who Is Happy; Or Walks; Or Looks",
    "Asia": "<b>Asia</b> - Muddy; Boggy",
    "Asiel": "<b>Asiel</b> - The Work Of God",
    "Askelon": "<b>Askelon</b> - Weight; Balance; Fire Of Infamy",
    "Asnapper": "<b>Asnapper</b> - Unhappiness; Increase Of Danger",
    "Asriel": "<b>Asriel</b> - Help Of God",
    "Asshurim": "<b>Asshurim</b> - Liers In Want; Beholders",
    "Assir": "<b>Assir</b> - Prisoner; Fettered",
    "Assos": "<b>Assos</b> - Approaching; Coming Near",
    "Assur": "<b>Assur</b> - Same As Ashur",
    "Assyria": "<b>Assyria</b> - Country Of Assur Or Ashur",
    "Asuppim": "<b>Asuppim</b> - Gatherings",
    "Asyncritus": "<b>Asyncritus</b> - Incomparable",
    "Atad": "<b>Atad</b> - A Thorn",
    "Atarah": "<b>Atarah</b> - A Crown",
    "Ataroth": "<b>Ataroth</b> - Crowns",
    "Ataroth-Addar": "<b>Ataroth-Addar</b> - Crowns Of Power",
    "Ater": "<b>Ater</b> - Left Hand; Shut",
    "Athach": "<b>Athach</b> - Thy Time",
    "Athaiah": "<b>Athaiah</b> - The Lord'S Time",
    "Athaliah": "<b>Athaliah</b> - The Time Of The Lord",
    "Athlai": "<b>Athlai</b> - My Hour Or Time",
    "Attai": "<b>Attai</b> - Same As Athlai",
    "Attalia": "<b>Attalia</b> - That Increases Or Sends",
    "Attalus": "<b>Attalus</b> - Increased, Nourished",
    "Augustus": "<b>Augustus</b> - Increased, Augmented",
    "Ava": "<b>Ava</b> - Or Ivah, Iniquity",
    "Aven": "<b>Aven</b> - Iniquity; Force; Riches; Sorrow",
    "Avim": "<b>Avim</b> - Wicked Or Perverse Men",
    "Avith": "<b>Avith</b> - Wicked, Perverse",
    "Azaliah": "<b>Azaliah</b> - Near The Lord",
    "Azaniah": "<b>Azaniah</b> - Hearing The Lord; The Lord'S Weapons",
    "Azareel": "<b>Azareel</b> - Help Of God",
    "Azariah": "<b>Azariah</b> - He That Hears The Lord",
    "Azaz": "<b>Azaz</b> - Strong One",
    "Azazel": "<b>Azazel</b> - The Scape-Goat",
    "Azaziah": "<b>Azaziah</b> - Strength Of The Lord",
    "Azekah": "<b>Azekah</b> - Strength Of Walls",
    "Azgad": "<b>Azgad</b> - A Strong Army; A Gang Of Robbers",
    "Azmaveth": "<b>Azmaveth</b> - Strong Death; A He-Goat",
    "Azmon": "<b>Azmon</b> - Bone Of A Bone; Our Strength",
    "Aznoth-Tabor": "<b>Aznoth-Tabor</b> - The Ears Of Tabor; The Ears Of Purity Or Contrition",
    "Azor": "<b>Azor</b> - A Helper; A Court",
    "Azotus": "<b>Azotus</b> - The Same As Ashdod",
    "Azriel": "<b>Azriel</b> - Same As Asriel",
    "Azrikam": "<b>Azrikam</b> - Help, Revenging",
    "Azubah": "<b>Azubah</b> - Forsaken",
    "Azur": "<b>Azur</b> - He That Assists Or Is Assisted",
    "Azzan": "<b>Azzan</b> - Their Strength",
    "Azzur": "<b>Azzur</b> - Same As Azur",
    "Baal": "<b>Baal</b> - Master; Lord",
    "Baal-Berith": "<b>Baal-Berith</b> - Idol Of The Covenant",
    "Baal-Gad": "<b>Baal-Gad</b> - Idol Of Fortune Or Felicity",
    "Baal-Hamon": "<b>Baal-Hamon</b> - Who Rules A Crowd",
    "Baal-Hermon": "<b>Baal-Hermon</b> - Possessor Of Destruction Or Of A Thing Cursed",
    "Baal-Meon": "<b>Baal-Meon</b> - Idol Or Master Of The House",
    "Baal-Peor": "<b>Baal-Peor</b> - Master Of The Opening",
    "Baal-Perazim": "<b>Baal-Perazim</b> - God Of Divisions",
    "Baal-Shalisha": "<b>Baal-Shalisha</b> - The God That Presides Over Three; The Third Idol",
    "Baal-Tamar": "<b>Baal-Tamar</b> - Master Of The Palm-Tree",
    "Baal-Zebub": "<b>Baal-Zebub</b> - God Of The Fly",
    "Baal-Zephon": "<b>Baal-Zephon</b> - The Idol Or Possession Of The North; Hidden; Secret",
    "Baalah": "<b>Baalah</b> - Her Idol; She That Is Governed Or Subdued; A Spouse",
    "Baalath": "<b>Baalath</b> - A Rejoicing; Our Proud Lord",
    "Baalath-Beer": "<b>Baalath-Beer</b> - Subjected Pit",
    "Baale": "<b>Baale</b> - Same As Baalath",
    "Baali": "<b>Baali</b> - My Idol; Lord Over Me",
    "Baalim": "<b>Baalim</b> - Idols; Masters; False Gods",
    "Baalis": "<b>Baalis</b> - A Rejoicing; A Proud Lord",
    "Baanah": "<b>Baanah</b> - In The Answer; In Affliction",
    "Baara": "<b>Baara</b> - A Flame; Purging",
    "Baaseiah": "<b>Baaseiah</b> - In Making; In Pressing Together",
    "Baasha": "<b>Baasha</b> - He That Seeks, Or Lays Waste",
    "Babel": "<b>Babel</b> - Confusion; Mixture",
    "Babylon": "<b>Babylon</b> - Same As Babel",
    "Baca": "<b>Baca</b> - A Mulberry-Tree",
    "Bahurim": "<b>Bahurim</b> - Choice; Warlike; Valiant",
    "Bajith": "<b>Bajith</b> - A House",
    "Balaam": "<b>Balaam</b> - The Ancient Of The People; The Destruction Of The People",
    "Baladan": "<b>Baladan</b> - One Without Judgment",
    "Balak": "<b>Balak</b> - Who Lays Waste Or Destroys",
    "Bamah": "<b>Bamah</b> - An Eminence Or High Place",
    "Barabbas": "<b>Barabbas</b> - Son Of Shame, Confusion",
    "Barachel": "<b>Barachel</b> - That Bows Before God",
    "Barachias": "<b>Barachias</b> - Same As Barachel",
    "Barak": "<b>Barak</b> - Thunder, Or In Vain",
    "Barjesus": "<b>Barjesus</b> - Son Of Jesus Or Joshua",
    "Barjona": "<b>Barjona</b> - Son Of A Jona; Of A Dove",
    "Barnabas": "<b>Barnabas</b> - Son Of The Prophet, Or Of Consolation",
    "Barsabas": "<b>Barsabas</b> - Son Of Return; Son Of Rest",
    "Bartholomew": "<b>Bartholomew</b> - A Son That Suspends The Waters",
    "Bartimeus": "<b>Bartimeus</b> - Son Of The Honorable",
    "Baruch": "<b>Baruch</b> - Who Is Blessed",
    "Barzillai": "<b>Barzillai</b> - Son Of Contempt; Made Of Iron",
    "Bashan": "<b>Bashan</b> - In The Tooth, In Ivory",
    "Bashemath": "<b>Bashemath</b> - Perfumed; Confusion Of Death; In Desolation",
    "Bathsheba": "<b>Bathsheba</b> - The Seventh Daughter; The Daughter Of Satiety",
    "Bathsuha": "<b>Bathsuha</b> - Same As Bathsheba",
    "Bealiah": "<b>Bealiah</b> - The God Of An Idol; In An Assembly",
    "Bealoth": "<b>Bealoth</b> - Cast Under",
    "Bebai": "<b>Bebai</b> - Void, Empty",
    "Becher": "<b>Becher</b> - First Begotten; First Fruits",
    "Bechorath": "<b>Bechorath</b> - First Fruits",
    "Bedad": "<b>Bedad</b> - Alone; Solitary",
    "Bedaiah": "<b>Bedaiah</b> - Bedeiah, The Only Lord",
    "Bedan": "<b>Bedan</b> - According To Judgment",
    "Beeliada": "<b>Beeliada</b> - An Open Idol",
    "Beelzebub": "<b>Beelzebub</b> - Same As Baalzebub",
    "Beer": "<b>Beer</b> - A Well",
    "Beer-Lahai-Roi": "<b>Beer-Lahai-Roi</b> - The Well Of Him That Liveth And Seeth Me",
    "Beera": "<b>Beera</b> - A Well; Declaring",
    "Beerelim": "<b>Beerelim</b> - The Well Of Elim, Or Of Rains",
    "Beeri": "<b>Beeri</b> - My Well",
    "Beeroth": "<b>Beeroth</b> - Wells; Explaining",
    "Beersheba": "<b>Beersheba</b> - The Well Of An Oath; The Seventh Well",
    "Behemoth": "<b>Behemoth</b> - Beasts",
    "Bekah": "<b>Bekah</b> - Half A Shekel",
    "Belah": "<b>Belah</b> - Destroying",
    "Belial": "<b>Belial</b> - Wicked, Worthless",
    "Belshazzar": "<b>Belshazzar</b> - Master Of The Treasure",
    "Belteshazzar": "<b>Belteshazzar</b> - Who Lays Up Treasures In Secret",
    "Ben": "<b>Ben</b> - A Son",
    "Ben-Ammi": "<b>Ben-Ammi</b> - Son Of My People",
    "Benaiah": "<b>Benaiah</b> - Son Of The Lord",
    "Bene-Jaakan": "<b>Bene-Jaakan</b> - Sons Of Sorrow",
    "Beneberak": "<b>Beneberak</b> - Sons Of Lightning",
    "Benhadad": "<b>Benhadad</b> - Son Of Hadad, Or Noise",
    "Benhail": "<b>Benhail</b> - Son Of Strength",
    "Benhanan": "<b>Benhanan</b> - Son Of Grace",
    "Benimi": "<b>Benimi</b> - Our Sons",
    "Benjamin": "<b>Benjamin</b> - Son Of The Right Hand",
    "Beno": "<b>Beno</b> - His Son",
    "Benoni": "<b>Benoni</b> - Son Of My Sorrow, Or Pain",
    "Benzoheth": "<b>Benzoheth</b> - Son Of Separation",
    "Beon": "<b>Beon</b> - In Affliction",
    "Beor": "<b>Beor</b> - Burning; Foolish; Mad",
    "Bera": "<b>Bera</b> - A Well; Declaring",
    "Berachah": "<b>Berachah</b> - Blessing; Bending The Knee",
    "Berachiah": "<b>Berachiah</b> - Speaking Well Of The Lord",
    "Beraiah": "<b>Beraiah</b> - The Choosing Of The Lord",
    "Berea": "<b>Berea</b> - Heavy; Weighty",
    "Bered": "<b>Bered</b> - Hail",
    "Beri": "<b>Beri</b> - My Son; My Corn",
    "Beriah": "<b>Beriah</b> - In Fellowship; In Envy",
    "Berith": "<b>Berith</b> - Covenant",
    "Bernice": "<b>Bernice</b> - One That Brings Victory",
    "Berodach-Baladan": "<b>Berodach-Baladan</b> - The Son Of Death",
    "Berothai": "<b>Berothai</b> - Wells; A Cypress",
    "Berothath": "<b>Berothath</b> - Of A Well",
    "Besai": "<b>Besai</b> - A Despising; Dirty",
    "Besodeiah": "<b>Besodeiah</b> - Counsel Of The Lord",
    "Besor": "<b>Besor</b> - Glad News; Incarnation",
    "Betah": "<b>Betah</b> - Confidence",
    "Beten": "<b>Beten</b> - Belly",
    "Beth-Aram": "<b>Beth-Aram</b> - House Of Height",
    "Beth-Aven": "<b>Beth-Aven</b> - The House Of Vanity; Of Iniquity Of Trouble",
    "Beth-Azmaveth": "<b>Beth-Azmaveth</b> - House Of Death'S Strength",
    "Beth-Baalmeon": "<b>Beth-Baalmeon</b> - An Idol Of The Dwelling-Place",
    "Beth-Barah": "<b>Beth-Barah</b> - The Chosen House",
    "Beth-Birei": "<b>Beth-Birei</b> - The House Of My Creator, The House Of My Health",
    "Beth-Car": "<b>Beth-Car</b> - The House Of The Lamb",
    "Beth-Dagon": "<b>Beth-Dagon</b> - The House Of Corn, Or Of Fish",
    "Beth-Diblathaim": "<b>Beth-Diblathaim</b> - House Of Dry Figs",
    "Beth-El": "<b>Beth-El</b> - The House Of God",
    "Beth-Ezal": "<b>Beth-Ezal</b> - A Neighbor'S House",
    "Beth-Gader": "<b>Beth-Gader</b> - A House For A Mouse",
    "Beth-Gamul": "<b>Beth-Gamul</b> - House Of Recompense, Or Of The Camel",
    "Beth-Haccerem": "<b>Beth-Haccerem</b> - House Of The Vineyard",
    "Beth-Haran": "<b>Beth-Haran</b> - House Of Grace",
    "Beth-Horon": "<b>Beth-Horon</b> - House Of Wrath",
    "Beth-Lebaoth": "<b>Beth-Lebaoth</b> - House Of Lionesses",
    "Beth-Lehem": "<b>Beth-Lehem</b> - House Of Bread",
    "Beth-Marcaboth": "<b>Beth-Marcaboth</b> - House Of Bitterness Wiped Out",
    "Beth-Meon": "<b>Beth-Meon</b> - House Of The Dwelling-Place",
    "Beth-Nimrah": "<b>Beth-Nimrah</b> - House Of Rebellion",
    "Beth-Palet": "<b>Beth-Palet</b> - House Of Expulsion",
    "Beth-Pazzez": "<b>Beth-Pazzez</b> - House Of Dividing Asunder",
    "Beth-Peor": "<b>Beth-Peor</b> - House Of Gaping, Or Opening",
    "Beth-Phelet": "<b>Beth-Phelet</b> - Same As Beth-Palet",
    "Beth-Rapha": "<b>Beth-Rapha</b> - House Of Health",
    "Beth-Shemesh": "<b>Beth-Shemesh</b> - House Of The Sun",
    "Beth-Zur": "<b>Beth-Zur</b> - House Of A Rock",
    "Bethabara": "<b>Bethabara</b> - The House Of Confidence",
    "Bethanath": "<b>Bethanath</b> - House Of Affliction",
    "Bethany": "<b>Bethany</b> - The House Of Song; The House Of Affliction",
    "Betharabah": "<b>Betharabah</b> - House Of Sweet Smell",
    "Bethemek": "<b>Bethemek</b> - House Of Deepness",
    "Bether": "<b>Bether</b> - Division, Or In The Trial",
    "Bethesda": "<b>Bethesda</b> - House Of Pity Or Mercy",
    "Bethphage": "<b>Bethphage</b> - House Of My Month, Or Of Early Figs",
    "Bethsaida": "<b>Bethsaida</b> - House Of Fruits, Or Of Food, Or Of Snares",
    "Bethshan": "<b>Bethshan</b> - Beth-Shean, House Of The Tooth, Or Of Ivory, Or Of Sleep",
    "Bethuel": "<b>Bethuel</b> - Filiation Of God",
    "Betonim": "<b>Betonim</b> - Bellies",
    "Beulah": "<b>Beulah</b> - Married",
    "Bezai": "<b>Bezai</b> - Eggs",
    "Bezaleel": "<b>Bezaleel</b> - In The Shadow Of God",
    "Bezek": "<b>Bezek</b> - Lightning; In The Chains",
    "Bezer": "<b>Bezer</b> - Vine Branches",
    "Bichri": "<b>Bichri</b> - First-Born; First Fruits",
    "Bidkar": "<b>Bidkar</b> - In Compunction, Or Sharp Pain",
    "Bigthan": "<b>Bigthan</b> - In The Press; Giving Meat",
    "Bigvai": "<b>Bigvai</b> - In My Body",
    "Bildad": "<b>Bildad</b> - Old Friendship",
    "Bileam": "<b>Bileam</b> - The Ancient Of The People; The Devourer",
    "Bilgah": "<b>Bilgah</b> - Ancient Countenance",
    "Bilhah": "<b>Bilhah</b> - Bilhan, Who Is Old Or Confused",
    "Bilshan": "<b>Bilshan</b> - In The Tongue",
    "Binea": "<b>Binea</b> - Son Of The Lord",
    "Binnui": "<b>Binnui</b> - Building",
    "Birsha": "<b>Birsha</b> - An Evil; A Son Who Beholds",
    "Bishlam": "<b>Bishlam</b> - In Peace",
    "Bithiah": "<b>Bithiah</b> - Daughter Of The Lord",
    "Bithron": "<b>Bithron</b> - Divisions",
    "Bithynia": "<b>Bithynia</b> - Violent Precipitation",
    "Bizjothjah": "<b>Bizjothjah</b> - Despite",
    "Blastus": "<b>Blastus</b> - That Buds Or Brings Forth",
    "Boanerges": "<b>Boanerges</b> - Son Of Thunder",
    "Boaz": "<b>Boaz</b> - Or Booz, In Strength",
    "Bocheru": "<b>Bocheru</b> - The First Born",
    "Bochim": "<b>Bochim</b> - The Place Of Weeping; Or Of Mulberry-Trees",
    "Bohan": "<b>Bohan</b> - In Them",
    "Boskath": "<b>Boskath</b> - In Poverty",
    "Boson": "<b>Boson</b> - Taking Away",
    "Bozez": "<b>Bozez</b> - Mud; Bog",
    "Bozrah": "<b>Bozrah</b> - In Tribulation Or Distress",
    "Bukki": "<b>Bukki</b> - Void",
    "Bukkiah": "<b>Bukkiah</b> - The Dissipation Of The Lord",
    "Bul": "<b>Bul</b> - Old Age; Perishing",
    "Bunah": "<b>Bunah</b> - Building; Understanding",
    "Bunni": "<b>Bunni</b> - Building Me",
    "Buz": "<b>Buz</b> - Despised; Plundered",
    "Buzi": "<b>Buzi</b> - My Contempt",
    "Cabbon": "<b>Cabbon</b> - As Though Understanding",
    "Cabul": "<b>Cabul</b> - Displeasing; Dirty",
    "Cain": "<b>Cain</b> - Possession, Or Possessed",
    "Cainan": "<b>Cainan</b> - Possessor; Purchaser",
    "Caiphas": "<b>Caiphas</b> - He That Seeks With Diligence; One That Vomiteth",
    "Calah": "<b>Calah</b> - Favorable; Opportunity",
    "Calcol": "<b>Calcol</b> - Nourishing",
    "Caleb": "<b>Caleb</b> - A Dog; A Crow; A Basket",
    "Caleb-Ephratah": "<b>Caleb-Ephratah</b> - See <Term>Ephratah</Term>",
    "Calneh": "<b>Calneh</b> - Our Consummation",
    "Calno": "<b>Calno</b> - Our Consummation; Altogether Himself",
    "Calvary": "<b>Calvary</b> - The Place Of A Skull",
    "Camon": "<b>Camon</b> - His Resurrection",
    "Cana": "<b>Cana</b> - Zeal; Jealousy; Possession",
    "Canaan": "<b>Canaan</b> - Merchant; Trader; Or That Humbles And Subdues",
    "Candace": "<b>Candace</b> - Who Possesses Contrition",
    "Capernaum": "<b>Capernaum</b> - The Field Of Repentance; City Of Comfort",
    "Caphtor": "<b>Caphtor</b> - A Sphere, Buckle, Or Hand",
    "Cappadocia": "<b>Cappadocia</b> - The Same As Caphtor",
    "Carcas": "<b>Carcas</b> - The Covering Of A Lamb",
    "Careah": "<b>Careah</b> - Bald; Ice",
    "Carmel": "<b>Carmel</b> - Circumcised Lamb; Harvest; Full Of Ears Of Corn",
    "Carmi": "<b>Carmi</b> - My Vineyard; Lamb Of The Waters",
    "Carpus": "<b>Carpus</b> - Fruit; Fruitful",
    "Carshena": "<b>Carshena</b> - A Lamb; Sleeping",
    "Casiphia": "<b>Casiphia</b> - Money; Covetousness",
    "Casluhim": "<b>Casluhim</b> - Hopes Of Life",
    "Cedron": "<b>Cedron</b> - Black; Sad",
    "Cenchrea": "<b>Cenchrea</b> - Millet; Small Pulse",
    "Cephas": "<b>Cephas</b> - A Rock Or Stone",
    "Cesar": "<b>Cesar</b> - A Name Applied To Those Who Are Cut Out Of The Womb",
    "Chalcol": "<b>Chalcol</b> - Who Nourishes, Consumes, And Sustains The Whole",
    "Chaldea": "<b>Chaldea</b> - As Demons, Or As Robbers",
    "Charchemish": "<b>Charchemish</b> - A Lamb; As Taken Away; Withdrawn",
    "Charran": "<b>Charran</b> - A Singing Or Calling Out",
    "Chebar": "<b>Chebar</b> - Force Or Strength",
    "Chedorlaomer": "<b>Chedorlaomer</b> - Roundness Of A Sheaf",
    "Chelal": "<b>Chelal</b> - As Night",
    "Chelluh": "<b>Chelluh</b> - All",
    "Chelub": "<b>Chelub</b> - A Basket",
    "Chelubai": "<b>Chelubai</b> - He Altogether Against Me",
    "Chemarims": "<b>Chemarims</b> - Black Ones",
    "Chemosh": "<b>Chemosh</b> - Handling; Stroking; Taking Away",
    "Chenaanah": "<b>Chenaanah</b> - Broken In Pieces",
    "Chenani": "<b>Chenani</b> - My Pillar",
    "Chenaniah": "<b>Chenaniah</b> - Preparation, Or Disposition, Or Strength, Of The Lord",
    "Chephirah": "<b>Chephirah</b> - A Little Lioness",
    "Cheran": "<b>Cheran</b> - Anger",
    "Cherethims": "<b>Cherethims</b> - Cherethites, Who Cut Or Tear Away",
    "Cherith": "<b>Cherith</b> - Cutting; Piercing; Slaying",
    "Chesed": "<b>Chesed</b> - As A Devil, Or A Destroyer",
    "Chesil": "<b>Chesil</b> - Foolishness",
    "Chesulloth": "<b>Chesulloth</b> - Fearfulness",
    "Chidon": "<b>Chidon</b> - A Dart",
    "Chiliab": "<b>Chiliab</b> - Totality; Or The Perfection Of The Father",
    "Chilion": "<b>Chilion</b> - Finished; Complete; Perfect",
    "Chilmad": "<b>Chilmad</b> - Teaching Or Learning",
    "Chimham": "<b>Chimham</b> - As They; Like To Them",
    "Chios": "<b>Chios</b> - Open; Opening",
    "Chisleu": "<b>Chisleu</b> - Cisleu, Casleu, Rashness; Confidence",
    "Chislon": "<b>Chislon</b> - Hope, Trust",
    "Chisloth-Tabor": "<b>Chisloth-Tabor</b> - Fears; Purity",
    "Chittem": "<b>Chittem</b> - Those That Bruise; Gold",
    "Chloe": "<b>Chloe</b> - Green Herb",
    "Chorazin": "<b>Chorazin</b> - The Secret; Here Is A Mystery",
    "Chozeba": "<b>Chozeba</b> - Men Liers In Wait",
    "Christ": "<b>Christ</b> - Anointed",
    "Chun": "<b>Chun</b> - Making Ready",
    "Chushan-Rishathaim": "<b>Chushan-Rishathaim</b> - Blackness Of Iniquities",
    "Chuza": "<b>Chuza</b> - The Seer Or Prophet",
    "Cilicia": "<b>Cilicia</b> - Which Rolls Or Overturns",
    "Cis": "<b>Cis</b> - Same As Kish",
    "Clauda": "<b>Clauda</b> - A Lamentable Voice",
    "Claudia": "<b>Claudia</b> - Claudius, Lame",
    "Clement": "<b>Clement</b> - Mild; Good; Merciful",
    "Cleophas": "<b>Cleophas</b> - The Whole Glory",
    "Cnidus": "<b>Cnidus</b> - Age",
    "Colhozeh": "<b>Colhozeh</b> - Every Prophet",
    "Colosse": "<b>Colosse</b> - Punishment; Correction",
    "Coniah": "<b>Coniah</b> - Strength Of The Lord",
    "Coos": "<b>Coos</b> - Top, Summit",
    "Corinth": "<b>Corinth</b> - Which Is Satisfied; Ornament; Beauty",
    "Cornelius": "<b>Cornelius</b> - Of A Horn",
    "Cosam": "<b>Cosam</b> - Divining",
    "Coz": "<b>Coz</b> - A Thorn",
    "Cozbi": "<b>Cozbi</b> - A Liar; Sliding Away",
    "Crescens": "<b>Crescens</b> - Growing; Increasing",
    "Crete": "<b>Crete</b> - Carnal; Fleshly",
    "Crispus": "<b>Crispus</b> - Curled",
    "Cush": "<b>Cush</b> - Cushan, Cushi, Ethiopians; Blackness",
    "Cuth": "<b>Cuth</b> - Cuthah, Burning",
    "Cyprus": "<b>Cyprus</b> - Fair; Fairness",
    "Cyrene": "<b>Cyrene</b> - A Wall; Coldness; The Floor",
    "Cyrenius": "<b>Cyrenius</b> - Who Governs",
    "Cyrus": "<b>Cyrus</b> - As Miserable; As Heir",
    "Dabareh": "<b>Dabareh</b> - The Word; The Thing; A Bee; Obedient",
    "Dabbasheth": "<b>Dabbasheth</b> - Flowing With Honey",
    "Daberath": "<b>Daberath</b> - Same As Dabareh",
    "Dagon": "<b>Dagon</b> - Corn; A Fish",
    "Dalaiah": "<b>Dalaiah</b> - The Poor Of The Lord",
    "Dalmanutha": "<b>Dalmanutha</b> - A Bucket; A Branch",
    "Dalmatia": "<b>Dalmatia</b> - Deceitful Lamps; Vain Brightness",
    "Dalphon": "<b>Dalphon</b> - The House Of Caves",
    "Damaris": "<b>Damaris</b> - A Little Woman",
    "Damascus": "<b>Damascus</b> - A Sack Full Of Blood; The Similitude Of Burning",
    "Dan": "<b>Dan</b> - Judgment; He That Judges",
    "Daniel": "<b>Daniel</b> - Judgment Of God; God My Judge",
    "Dannah": "<b>Dannah</b> - Judging",
    "Darah": "<b>Darah</b> - Generation; House Of The Shepherd Or Of The Companion",
    "Darda": "<b>Darda</b> - Home Of Knowledge",
    "Darius": "<b>Darius</b> - He That Informs Himself",
    "Darkon": "<b>Darkon</b> - Of Generation; Of Possession",
    "Dathan": "<b>Dathan</b> - Laws Or Rites",
    "David": "<b>David</b> - Well-Beloved, Dear",
    "Debir": "<b>Debir</b> - An Orator; A Word",
    "Deborah": "<b>Deborah</b> - Word; Thing; A Bee",
    "Decapolis": "<b>Decapolis</b> - Containing Ten Cities",
    "Dedan": "<b>Dedan</b> - Their Breasts; Friendship; A Judge",
    "Dedanim": "<b>Dedanim</b> - The Descendants Of Dedan",
    "Dekar": "<b>Dekar</b> - Force",
    "Delaiah": "<b>Delaiah</b> - The Poor Of The Lord",
    "Delilah": "<b>Delilah</b> - Poor; Small; Head Of Hair",
    "Demas": "<b>Demas</b> - Popular",
    "Demetrius": "<b>Demetrius</b> - Belonging To Corn, Or To Ceres",
    "Derbe": "<b>Derbe</b> - A Sting",
    "Deuel": "<b>Deuel</b> - The Knowledge Of God",
    "Deuteronomy": "<b>Deuteronomy</b> - Repetition Of The Law",
    "Diana": "<b>Diana</b> - Luminous, Perfect",
    "Diblaim": "<b>Diblaim</b> - Cluster Of Figs",
    "Diblath": "<b>Diblath</b> - Paste Of Dry Figs",
    "Dibon": "<b>Dibon</b> - Abundance Of Knowledge",
    "Dibon-Gad": "<b>Dibon-Gad</b> - Great Understanding; Abundance Of Sons",
    "Dibri": "<b>Dibri</b> - An Orator",
    "Dibzahab": "<b>Dibzahab</b> - Dizahab, Where Much Gold Is",
    "Didymus": "<b>Didymus</b> - A Twin; Double",
    "Diklah": "<b>Diklah</b> - Dildah, His Diminishing",
    "Dilean": "<b>Dilean</b> - That Is Poor",
    "Dimon": "<b>Dimon</b> - Where It Is Red",
    "Dimonah": "<b>Dimonah</b> - Dunghill",
    "Dinah": "<b>Dinah</b> - Judgment; Who Judges",
    "Dinhabah": "<b>Dinhabah</b> - He Gives Judgment",
    "Dionysius": "<b>Dionysius</b> - Divinely Touched",
    "Diotrephes": "<b>Diotrephes</b> - Nourished By Jupiter",
    "Dishan": "<b>Dishan</b> - A Threshing",
    "Dishon": "<b>Dishon</b> - Fatness; Ashes",
    "Dodai": "<b>Dodai</b> - Dodanim, Beloved",
    "Dodavah": "<b>Dodavah</b> - Love",
    "Dodo": "<b>Dodo</b> - His Uncle",
    "Doeg": "<b>Doeg</b> - Careful, Who Acts With Uneasiness",
    "Dophkah": "<b>Dophkah</b> - A Knocking",
    "Dor": "<b>Dor</b> - Generation, Habitation",
    "Dorcas": "<b>Dorcas</b> - A Female Roe-Deer",
    "Dothan": "<b>Dothan</b> - The Law; Custom",
    "Drusilla": "<b>Drusilla</b> - Watered By The Dew",
    "Dumali": "<b>Dumali</b> - Silence; Resemblance",
    "Dura": "<b>Dura</b> - Same As Dor",
    "Ebal": "<b>Ebal</b> - Ancient Heaps",
    "Ebed": "<b>Ebed</b> - A Servant; Laborer",
    "Ebed-Melech": "<b>Ebed-Melech</b> - The King'S Servant",
    "Eben-Ezer": "<b>Eben-Ezer</b> - The Stone Of Help",
    "Eber": "<b>Eber</b> - One That Passes; Anger",
    "Ebiasaph": "<b>Ebiasaph</b> - A Father That Gathers Or Adds",
    "Ebronah": "<b>Ebronah</b> - Passage Over; Being Angry",
    "Ecclesiastes": "<b>Ecclesiastes</b> - A Preacher",
    "Ed": "<b>Ed</b> - Witness",
    "Eden": "<b>Eden</b> - Pleasure; Delight",
    "Eder": "<b>Eder</b> - A Flock",
    "Edom": "<b>Edom</b> - Red, Earthy; Of Blood",
    "Edrei": "<b>Edrei</b> - A Very Great Mass, Or Cloud",
    "Eglah": "<b>Eglah</b> - Heifer; Chariot; Round",
    "Eglaim": "<b>Eglaim</b> - Drops Of The Sea",
    "Eglon": "<b>Eglon</b> - Same As Eglah",
    "Egypt": "<b>Egypt</b> - That Troubles Or Oppresses; Anguish",
    "Ehud": "<b>Ehud</b> - He That Praises",
    "Eker": "<b>Eker</b> - Barren, Feeble",
    "Ekron": "<b>Ekron</b> - Barrenness; Torn Away",
    "El-Beth-El": "<b>El-Beth-El</b> - The God Of Bethel",
    "El-Elohe-Israel": "<b>El-Elohe-Israel</b> - God, The God Of Israel",
    "Eladah": "<b>Eladah</b> - The Eternity Of God",
    "Elah": "<b>Elah</b> - An Oak; A Curse; Perjury",
    "Elam": "<b>Elam</b> - A Young Man; A Virgin; A Secret",
    "Elasah": "<b>Elasah</b> - The Doings Of God",
    "Elath": "<b>Elath</b> - A Hind; Strength; An Oak",
    "Eldaah": "<b>Eldaah</b> - Knowledge Of God",
    "Eldad": "<b>Eldad</b> - Favored Of God; Love Of God",
    "Elead": "<b>Elead</b> - Witness Of God",
    "Elealeh": "<b>Elealeh</b> - Burnt-Offering Of God",
    "Eleazar": "<b>Eleazar</b> - Help Of God, Court Of God",
    "Eleph": "<b>Eleph</b> - Learning",
    "Elhanan": "<b>Elhanan</b> - Grace, Or Gift, Or Mercy Of God",
    "Eli": "<b>Eli</b> - The Offering Or Lifting Up",
    "Eli": "<b>Eli</b> - Eli, My God, My God",
    "Eliab": "<b>Eliab</b> - God Is My Father; God Is The Father",
    "Eliada": "<b>Eliada</b> - Knowledge Of God",
    "Eliah": "<b>Eliah</b> - God The Lord",
    "Eliahba": "<b>Eliahba</b> - My God The Father",
    "Eliakim": "<b>Eliakim</b> - Resurrection Of God",
    "Eliam": "<b>Eliam</b> - The People Of God",
    "Elias": "<b>Elias</b> - Same As Elijah",
    "Eliasaph": "<b>Eliasaph</b> - The Lord Increaseth",
    "Eliashib": "<b>Eliashib</b> - The God Of Conversion",
    "Eliathah": "<b>Eliathah</b> - Thou Art My God",
    "Elidad": "<b>Elidad</b> - Beloved Of God",
    "Eliel": "<b>Eliel</b> - God, My God",
    "Elienai": "<b>Elienai</b> - The God Of My Eyes",
    "Eliezer": "<b>Eliezer</b> - Help, Or Court, Of My God",
    "Elihoreph": "<b>Elihoreph</b> - God Of Winter, Or Of Youth",
    "Elihu": "<b>Elihu</b> - He Is My God Himself",
    "Elijah": "<b>Elijah</b> - God The Lord, The Strong Lord",
    "Elika": "<b>Elika</b> - Pelican Of God",
    "Elim": "<b>Elim</b> - The Rams; The Strong; Stags",
    "Elimelech": "<b>Elimelech</b> - My God Is King",
    "Elioenai": "<b>Elioenai</b> - Toward Him Are Mine Eyes; Or To Him Are My Fountains",
    "Eliphal": "<b>Eliphal</b> - A Miracle Of God",
    "Eliphalet": "<b>Eliphalet</b> - The God Of Deliverance",
    "Eliphaz": "<b>Eliphaz</b> - The Endeavor Of God",
    "Elisabeth": "<b>Elisabeth</b> - Elizabeth, The Oath, Or Fullness, Of God",
    "Elisha": "<b>Elisha</b> - Salvation Of God",
    "Elishah": "<b>Elishah</b> - It Is God; The Lamb Of God: God That Gives Help",
    "Elishama": "<b>Elishama</b> - God Hearing",
    "Elishaphat": "<b>Elishaphat</b> - My God Judgeth",
    "Elisheba": "<b>Elisheba</b> - Same As Elisabeth",
    "Elishua": "<b>Elishua</b> - God Is My Salvation",
    "Eliud": "<b>Eliud</b> - God Is My Praise",
    "Elizur": "<b>Elizur</b> - God Is My Strength; My Rock; Rock Of God",
    "Elkanah": "<b>Elkanah</b> - God The Zealous; The Zeal Of God",
    "Elkeshai": "<b>Elkeshai</b> - Hardiness Or Rigor Of God",
    "Elkoshite": "<b>Elkoshite</b> - A Man Of Elkeshai",
    "Ellasar": "<b>Ellasar</b> - Revolting From God",
    "Elmodam": "<b>Elmodam</b> - The God Of Measure, Or Of The Garment",
    "Elnaam": "<b>Elnaam</b> - God'S Fairness",
    "Elnathan": "<b>Elnathan</b> - God Hath Given; The Gift Of God",
    "Elohi": "<b>Elohi</b> - Elohim, God",
    "Elon": "<b>Elon</b> - Oak; Grove; Strong",
    "Elon-Beth-Hanan": "<b>Elon-Beth-Hanan</b> - The House Of Grace Or Mercy",
    "Elpaal": "<b>Elpaal</b> - God'S Work",
    "Elpalet": "<b>Elpalet</b> - Same As Eliphalet",
    "Eltekeh": "<b>Eltekeh</b> - Of Grace Or Mercy",
    "Elteketh": "<b>Elteketh</b> - The Case Of God",
    "Eltolad": "<b>Eltolad</b> - The Generation Of God",
    "Elul": "<b>Elul</b> - Cry Or Outcry",
    "Eluzai": "<b>Eluzai</b> - God Is My Strength",
    "Elymas": "<b>Elymas</b> - A Magician, A Corrupter",
    "Elzabad": "<b>Elzabad</b> - The Dowry Of God",
    "Elzaphan": "<b>Elzaphan</b> - God Of The Northeast Wind",
    "Emims": "<b>Emims</b> - Fears; Terrors; Formidable; People",
    "Emmanuel": "<b>Emmanuel</b> - God With Us",
    "Emmaus": "<b>Emmaus</b> - People Despised Or Obscure",
    "Emmor": "<b>Emmor</b> - An Ass",
    "En-Dor": "<b>En-Dor</b> - Fountain, Eye Of Generation, Or Of Habitation",
    "En-Eglaim": "<b>En-Eglaim</b> - Eye, Or Fountain, Of Calves",
    "En-Gannim": "<b>En-Gannim</b> - Eye, Or Fountain, Of Protection Or Of Gardens",
    "En-Gedi": "<b>En-Gedi</b> - Eye, Or Fountain, Of The Goat, Or Of Happiness",
    "En-Haddah": "<b>En-Haddah</b> - Quick Sight; Well Of Gladness",
    "En-Hakkore": "<b>En-Hakkore</b> - Fountain Of Him That Called Or Prayed",
    "En-Hazor": "<b>En-Hazor</b> - The Grass Of The Well",
    "En-Mishpat": "<b>En-Mishpat</b> - Fountain Of Judgment",
    "En-Rimmon": "<b>En-Rimmon</b> - Well Of Weight",
    "En-Rogel": "<b>En-Rogel</b> - The Fuller'S Fountain; The Well Of Searching",
    "En-Shemesh": "<b>En-Shemesh</b> - Fountain, Or Eye, Of The Sun",
    "En-Tappuah": "<b>En-Tappuah</b> - Fountain Of An Apple, Or Of Inflation",
    "Enam": "<b>Enam</b> - Fountain, Open Place",
    "Enan": "<b>Enan</b> - Cloud",
    "Eneas": "<b>Eneas</b> - Laudable",
    "Enoch": "<b>Enoch</b> - Dedicated; Disciplined",
    "Enon": "<b>Enon</b> - Cloud; Mass Of Darkness; Fountain; Eye",
    "Enos": "<b>Enos</b> - Mortal Man; Sick; Despaired Of; Forgetful",
    "Epaphras": "<b>Epaphras</b> - Covered With Foam",
    "Epaphroditus": "<b>Epaphroditus</b> - Agreeable; Handsome",
    "Epenetus": "<b>Epenetus</b> - Laudable; Worthy Of Praise",
    "Eph-Lal": "<b>Eph-Lal</b> - Judging; Praying",
    "Ephah": "<b>Ephah</b> - Weary; Tired",
    "Epher": "<b>Epher</b> - Dust; Lead",
    "Ephes-Dammim": "<b>Ephes-Dammim</b> - Effusion Of Blood",
    "Ephesus": "<b>Ephesus</b> - Desirable",
    "Ephphatha": "<b>Ephphatha</b> - Be Opened",
    "Ephraim": "<b>Ephraim</b> - Fruitful; Increasing",
    "Ephratah": "<b>Ephratah</b> - Ephrath, Abundance; Bearing Fruit",
    "Ephron": "<b>Ephron</b> - Dust",
    "Epicurean": "<b>Epicurean</b> - Follower Of Epicurus, I.E., Of One Who Gives Assistance",
    "Er": "<b>Er</b> - Watchman",
    "Eran": "<b>Eran</b> - Follower",
    "Erastus": "<b>Erastus</b> - Lovely, Amiable",
    "Erech": "<b>Erech</b> - Length; Health; Physic",
    "Eri": "<b>Eri</b> - My City",
    "Esaias": "<b>Esaias</b> - Same As Isaiah",
    "Esar-Haddon": "<b>Esar-Haddon</b> - That Closes The Point; Joy; Cheerfulness",
    "Esau": "<b>Esau</b> - He That Acts Or Finishes",
    "Esek": "<b>Esek</b> - Contention",
    "Esh-Baal": "<b>Esh-Baal</b> - The Fire Of The Idol, Or Of The Ruler",
    "Esh-Ban": "<b>Esh-Ban</b> - Fire Of The Sun",
    "Eshcol": "<b>Eshcol</b> - Bunch Of Grapes",
    "Eshean": "<b>Eshean</b> - Held Up",
    "Eshek": "<b>Eshek</b> - Violence, Force",
    "Eshkalon": "<b>Eshkalon</b> - Same As Askelon",
    "Eshtaol": "<b>Eshtaol</b> - A Strong Woman",
    "Eshtemoa": "<b>Eshtemoa</b> - The Bosom Of A Woman",
    "Esli": "<b>Esli</b> - Near Me; He Who Separates",
    "Esmachiah": "<b>Esmachiah</b> - Joined To The Lord",
    "Esrom": "<b>Esrom</b> - Dart Of Joy; Division Of A Song",
    "Esther": "<b>Esther</b> - Secret; Hidden",
    "Etam": "<b>Etam</b> - Their Bird, Their Covering",
    "Etham": "<b>Etham</b> - Their Strength; Their Sign",
    "Ethan": "<b>Ethan</b> - Strong; The Gift Of The Island",
    "Ethanim": "<b>Ethanim</b> - Strong; Valiant",
    "Ethbaal": "<b>Ethbaal</b> - Toward The Idol, Or With Baal",
    "Ether": "<b>Ether</b> - Talk",
    "Ethiopia": "<b>Ethiopia</b> - Blackness; Heat",
    "Ethnan": "<b>Ethnan</b> - Gift",
    "Ethni": "<b>Ethni</b> - Strong",
    "Eubulus": "<b>Eubulus</b> - Prudent; Good Counselor",
    "Eunice": "<b>Eunice</b> - Good Victory",
    "Euodias": "<b>Euodias</b> - Sweet Scent",
    "Euphrates": "<b>Euphrates</b> - That Makes Fruitful",
    "Eutychus": "<b>Eutychus</b> - Happy; Fortunate",
    "Eve": "<b>Eve</b> - Living; Enlivening",
    "Evi": "<b>Evi</b> - Unjust",
    "Evil-Merodach": "<b>Evil-Merodach</b> - The Fool Of Merodach; The Fool Grinds Bitterly",
    "Exodus": "<b>Exodus</b> - Going Out, Departure",
    "Ezbon": "<b>Ezbon</b> - Hastening To Understand",
    "Ezekiel": "<b>Ezekiel</b> - The Strength Of God",
    "Ezel": "<b>Ezel</b> - Going Abroad; Walk",
    "Ezem": "<b>Ezem</b> - A Bone",
    "Ezer": "<b>Ezer</b> - A Help",
    "Ezion-Geber": "<b>Ezion-Geber</b> - The Wood Of The Man",
    "Ezra": "<b>Ezra</b> - Help; Court",
    "Ezri": "<b>Ezri</b> - My Help",
    "Felix": "<b>Felix</b> - Happy, Prosperous",
    "Festus": "<b>Festus</b> - Festive, Joyful",
    "Fortunatus": "<b>Fortunatus</b> - Lucky, Fortunate",
    "Gaal": "<b>Gaal</b> - Contempt; Abomination",
    "Gaash": "<b>Gaash</b> - Tempest; Commotion",
    "Gabbai": "<b>Gabbai</b> - The Back",
    "Gabbatha": "<b>Gabbatha</b> - High; Elevated",
    "Gabriel": "<b>Gabriel</b> - God Is My Strength",
    "Gad": "<b>Gad</b> - A Band; A Troop",
    "Gadarenes": "<b>Gadarenes</b> - Men Of Gadara, I.E., A Place Surrounded Or Walled",
    "Gaddi": "<b>Gaddi</b> - My Troop; A Kid",
    "Gaddiel": "<b>Gaddiel</b> - Goat Of God; The Lord My Happiness",
    "Gaius": "<b>Gaius</b> - Lord; An Earthly Man",
    "Galal": "<b>Galal</b> - A Roll, A Wheel",
    "Galatia": "<b>Galatia</b> - White; The Color Of Milk",
    "Galeed": "<b>Galeed</b> - The Heap Of Witness",
    "Galilee": "<b>Galilee</b> - Wheel; Revolution",
    "Gallim": "<b>Gallim</b> - Who Heap Up; Who Cover",
    "Gallio": "<b>Gallio</b> - Who Sucks, Or Lives On Milk",
    "Gamaliel": "<b>Gamaliel</b> - Recompense Of God; Camel Of God",
    "Gammadims": "<b>Gammadims</b> - Dwarfs",
    "Gamul": "<b>Gamul</b> - A Recompense",
    "Gareb": "<b>Gareb</b> - A Scab",
    "Garmites": "<b>Garmites</b> - Men Of Garmi, Ie., Bones, Or, My Cause",
    "Gatam": "<b>Gatam</b> - Their Lowing; Their Touch",
    "Gath": "<b>Gath</b> - A Wine-Press",
    "Gath-Rimmon": "<b>Gath-Rimmon</b> - The High Wine-Press",
    "Gaza": "<b>Gaza</b> - Strong; A Goat",
    "Gazabar": "<b>Gazabar</b> - A Treasurer",
    "Gazer": "<b>Gazer</b> - A Dividing; A Sentence",
    "Gazez": "<b>Gazez</b> - A Passing Over",
    "Gazzam": "<b>Gazzam</b> - The Fleece Of Them",
    "Geba": "<b>Geba</b> - A Hill; Cup",
    "Gebal": "<b>Gebal</b> - Bound; Limit",
    "Geber": "<b>Geber</b> - Manly, Strong",
    "Gebim": "<b>Gebim</b> - Grasshoppers; Height",
    "Gedaliah": "<b>Gedaliah</b> - God Is My Greatness",
    "Geder": "<b>Geder</b> - Gederah, Gederoth, A Wall",
    "Gederothaim": "<b>Gederothaim</b> - Hedges",
    "Gehazi": "<b>Gehazi</b> - Valley Of Sight",
    "Geliloth": "<b>Geliloth</b> - Rolling, Wheel, Heap",
    "Gemalli": "<b>Gemalli</b> - Wares; A Camel",
    "Gemariah": "<b>Gemariah</b> - Accomplishment Or Perfection Of The Lord",
    "Genesis": "<b>Genesis</b> - Beginning",
    "Gennesaret": "<b>Gennesaret</b> - Garden Of The Prince",
    "Genubath": "<b>Genubath</b> - Theft; Robbery",
    "Gera": "<b>Gera</b> - Pilgrimage, Combat; Dispute",
    "Gerar": "<b>Gerar</b> - Same As Gera",
    "Gergesenes": "<b>Gergesenes</b> - Those Who Come From Pilgrimage Or Fight",
    "Gerizim": "<b>Gerizim</b> - Cutters, Hatchets",
    "Gershom": "<b>Gershom</b> - A Stranger Here",
    "Gershon": "<b>Gershon</b> - His Banishment; The Change Of Pilgrimage",
    "Geshur": "<b>Geshur</b> - Geshuri, Sight Of The Valley; A Walled Valley",
    "Gether": "<b>Gether</b> - The Vale Of Trial Or Searching",
    "Gethsemane": "<b>Gethsemane</b> - A Very Fat Or Plentiful Vale",
    "Geuel": "<b>Geuel</b> - God'S Redemption",
    "Gezer": "<b>Gezer</b> - Dividing, Sentence",
    "Giah": "<b>Giah</b> - To Guide; Draw Out; Produce; A Groan Or Sigh",
    "Gibbar": "<b>Gibbar</b> - Strong, Manly",
    "Gibbethon": "<b>Gibbethon</b> - A Back; A High House",
    "Gibeah": "<b>Gibeah</b> - A Hill",
    "Gibeon": "<b>Gibeon</b> - Hill; Cup; Thing Lifted Up",
    "Giddel": "<b>Giddel</b> - Great",
    "Gideon": "<b>Gideon</b> - He That Bruises Or Breaks; A Destroyer",
    "Gideoni": "<b>Gideoni</b> - Same As Gideon",
    "Gihon": "<b>Gihon</b> - Valley Of Grace",
    "Gilalai": "<b>Gilalai</b> - A Wheel",
    "Gilboa": "<b>Gilboa</b> - Revolution Of Inquiry",
    "Gilead": "<b>Gilead</b> - The Heap Or Mass Of Testimony",
    "Gilgal": "<b>Gilgal</b> - Wheel; Rolling; Heap",
    "Giloh": "<b>Giloh</b> - He That Rejoices; He That Overturns",
    "Gimzo": "<b>Gimzo</b> - That Bulrush",
    "Ginath": "<b>Ginath</b> - Ginnetho, A Garden",
    "Girgashite": "<b>Girgashite</b> - Who Arrives From Pilgrimage",
    "Gispa": "<b>Gispa</b> - Coming Hither",
    "Gittah-Hepher": "<b>Gittah-Hepher</b> - Digging; A Wine-Press",
    "Gittaim": "<b>Gittaim</b> - A Wine-Press",
    "Gittites": "<b>Gittites</b> - Men Of Gath, Ie., Of A Wine-Press",
    "Goath": "<b>Goath</b> - His Touching; His Roaring",
    "Gob": "<b>Gob</b> - Cistern; Grasshopper",
    "Gog": "<b>Gog</b> - Roof; Covering",
    "Golan": "<b>Golan</b> - Passage; Revolution",
    "Golgotha": "<b>Golgotha</b> - A Heap Of Skulls; Something Skull-Shaped",
    "Goliath": "<b>Goliath</b> - Passage; Revolution; Heap",
    "Gomer": "<b>Gomer</b> - To Finish; Complete",
    "Gomorrah": "<b>Gomorrah</b> - Rebellious People",
    "Goshen": "<b>Goshen</b> - Approaching; Drawing Near",
    "Gozan": "<b>Gozan</b> - Fleece; Pasture; Who Nourisheth The Body",
    "Gudgodah": "<b>Gudgodah</b> - Happiness",
    "Guni": "<b>Guni</b> - A Garden; A Covering",
    "Gur": "<b>Gur</b> - The Young Of A Beast; A Whelp",
    "Gur-Baal": "<b>Gur-Baal</b> - The Governor'S Whelp",
    "Haahashtari": "<b>Haahashtari</b> - A Runner",
    "Habaiah": "<b>Habaiah</b> - The Hiding Of The Lord",
    "Habakkuk": "<b>Habakkuk</b> - He That Embraces; A Wrestler",
    "Habazinaiah": "<b>Habazinaiah</b> - A Hiding Of The Shield Of The Lord",
    "Habor": "<b>Habor</b> - A Partaker; A Companion",
    "Hachaliah": "<b>Hachaliah</b> - Who Waits For The Lord",
    "Hachilah": "<b>Hachilah</b> - My Hope Is In Her",
    "Hachmoni": "<b>Hachmoni</b> - A Wise Man",
    "Hadad": "<b>Hadad</b> - Joy; Noise; Clamor",
    "Hadadezer": "<b>Hadadezer</b> - Beauty Of Assistance",
    "Hadadrimmon": "<b>Hadadrimmon</b> - Invocation To The God Rimmon",
    "Hadar": "<b>Hadar</b> - Power; Greatness",
    "Hadarezer": "<b>Hadarezer</b> - Same As Hadadezer",
    "Hadashah": "<b>Hadashah</b> - News; A Month",
    "Hadassah": "<b>Hadassah</b> - A Myrtle; Joy",
    "Hadid": "<b>Hadid</b> - Rejoicing; Sharp",
    "Hadlai": "<b>Hadlai</b> - Loitering; Hindering",
    "Hadoram": "<b>Hadoram</b> - Their Beauty; Their Power",
    "Hadrach": "<b>Hadrach</b> - Point; Joy Of Tenderness",
    "Hagab": "<b>Hagab</b> - Hagabah, A Grasshopper",
    "Hagar": "<b>Hagar</b> - A Stranger; One That Fears",
    "Haggai": "<b>Haggai</b> - Feast; Solemnity",
    "Haggeri": "<b>Haggeri</b> - Haggi, A Stranger",
    "Haggiah": "<b>Haggiah</b> - The Lord'S Feast",
    "Haggith": "<b>Haggith</b> - Rejoicing",
    "Hakkatan": "<b>Hakkatan</b> - Little",
    "Hakkoz": "<b>Hakkoz</b> - A Thorn; Summer; An End",
    "Hakupha": "<b>Hakupha</b> - A Commandment Of The Mouth",
    "Halah": "<b>Halah</b> - A Moist Table",
    "Halak": "<b>Halak</b> - Part",
    "Halhul": "<b>Halhul</b> - Grief; Looking For Grief",
    "Hali": "<b>Hali</b> - Sickness; A Beginning; A Precious Stone",
    "Hallelujah": "<b>Hallelujah</b> - Praise The Lord",
    "Halloesh": "<b>Halloesh</b> - Saying Nothing; An Enchanter",
    "Ham": "<b>Ham</b> - Hot; Heat; Brown",
    "Haman": "<b>Haman</b> - Noise; Tumult",
    "Hamath": "<b>Hamath</b> - Anger; Heat; A Wall",
    "Hamath-Zobah": "<b>Hamath-Zobah</b> - The Heat, Or The Wall, Of An Army",
    "Hammedatha": "<b>Hammedatha</b> - He That Troubles The Law",
    "Hammelech": "<b>Hammelech</b> - A King; A Counselor",
    "Hammon": "<b>Hammon</b> - Heat; The Sun",
    "Hamon-Gog": "<b>Hamon-Gog</b> - The Multitude Of Gog",
    "Hamonah": "<b>Hamonah</b> - His Multitude; His Uproar",
    "Hamor": "<b>Hamor</b> - An Ass; Clay; Dirt",
    "Hamoth": "<b>Hamoth</b> - Indignation",
    "Hamul": "<b>Hamul</b> - Godly; Merciful",
    "Hamutal": "<b>Hamutal</b> - The Shadow Of His Heat",
    "Hanameel": "<b>Hanameel</b> - The Grace That Comes From God; Gift Of God",
    "Hanan": "<b>Hanan</b> - Full Of Grace",
    "Hananeel": "<b>Hananeel</b> - Grace, Or Gift, Of God",
    "Hanani": "<b>Hanani</b> - My Grace; My Mercy",
    "Hananiah": "<b>Hananiah</b> - Grace; Mercy; Gift Of The Lord",
    "Hanes": "<b>Hanes</b> - Banishment Of Grace",
    "Haniel": "<b>Haniel</b> - The Gift Of God",
    "Hannah": "<b>Hannah</b> - Gracious; Merciful; He That Gives",
    "Hannathon": "<b>Hannathon</b> - The Gift Of Grace",
    "Hanniel": "<b>Hanniel</b> - Grace Or Mercy Of God",
    "Hanoch": "<b>Hanoch</b> - Dedicated",
    "Hanun": "<b>Hanun</b> - Gracious; Merciful",
    "Hapharaim": "<b>Hapharaim</b> - Searching; Digging",
    "Hara": "<b>Hara</b> - A Hill; Showing Forth",
    "Haradah": "<b>Haradah</b> - Well Of Great Fear",
    "Haran": "<b>Haran</b> - Mountainous Country",
    "Harbonah": "<b>Harbonah</b> - His Destruction; His Sword",
    "Hareph": "<b>Hareph</b> - Winter; Reproach",
    "Harhaiah": "<b>Harhaiah</b> - Heat, Or Anger, Of The Lord",
    "Harhas": "<b>Harhas</b> - Anger; Heat Of Confidence",
    "Harhur": "<b>Harhur</b> - Made Warm",
    "Harim": "<b>Harim</b> - Destroyed; Dedicated To God",
    "Harnepher": "<b>Harnepher</b> - The Anger Of A Bull; Increasing Heat",
    "Harod": "<b>Harod</b> - Astonishment; Fear",
    "Harosheth": "<b>Harosheth</b> - A Forest; Agriculture; Workmanship; Deafness; Silence",
    "Harran": "<b>Harran</b> - See <Term>Charran</Term>",
    "Harsha": "<b>Harsha</b> - Workmanship; A Wood",
    "Harum": "<b>Harum</b> - High; Throwing Down",
    "Harumaph": "<b>Harumaph</b> - Destruction",
    "Haruphite": "<b>Haruphite</b> - Slender; Sharp",
    "Haruz": "<b>Haruz</b> - Careful",
    "Hasadiah": "<b>Hasadiah</b> - The Mercy Of The Lord",
    "Hashabiah": "<b>Hashabiah</b> - The Estimation Of The Lord",
    "Hashabnah": "<b>Hashabnah</b> - Hashabniah, The Silence Of The Lord",
    "Hashem": "<b>Hashem</b> - Named; A Putting To",
    "Hashub": "<b>Hashub</b> - Esteemed; Numbered",
    "Hashubah": "<b>Hashubah</b> - Estimation; Thought",
    "Hashum": "<b>Hashum</b> - Silence; Their Hasting",
    "Hashupha": "<b>Hashupha</b> - Spent; Made Base",
    "Hasrah": "<b>Hasrah</b> - Wanting",
    "Hatach": "<b>Hatach</b> - He That Strikes",
    "Hathath": "<b>Hathath</b> - Fear",
    "Hatita": "<b>Hatita</b> - A Bending Of Sin",
    "Hattil": "<b>Hattil</b> - Howling For Sin",
    "Hattipha": "<b>Hattipha</b> - Robbery",
    "Hattush": "<b>Hattush</b> - Forsaking Sin",
    "Hauran": "<b>Hauran</b> - A Hole; Liberty; Whiteness",
    "Havilah": "<b>Havilah</b> - That Suffers Pain; That Brings Forth",
    "Havoth-Jair": "<b>Havoth-Jair</b> - The Villages That Enlighten",
    "Hazael": "<b>Hazael</b> - That Sees God",
    "Hazaiah": "<b>Hazaiah</b> - Seeing The Lord",
    "Hazar-Addar": "<b>Hazar-Addar</b> - An Imprisoned Generation",
    "Hazar-Hatticon": "<b>Hazar-Hatticon</b> - Middle Village; Preparation",
    "Hazar-Shual": "<b>Hazar-Shual</b> - A Wolf'S House",
    "Hazar-Susah": "<b>Hazar-Susah</b> - Or Susim, The Hay-Paunch Of A Horse",
    "Hazarenan": "<b>Hazarenan</b> - Imprisoned Cloud",
    "Hazargaddah": "<b>Hazargaddah</b> - Imprisoned Band",
    "Hazarmaveth": "<b>Hazarmaveth</b> - Dwelling Of Death",
    "Hazelelponi": "<b>Hazelelponi</b> - Sorrow Of Countenance",
    "Hazeroth": "<b>Hazeroth</b> - Villages; Palaces",
    "Hazezon-Tamar": "<b>Hazezon-Tamar</b> - Drawing Near To Bitterness",
    "Hazo": "<b>Hazo</b> - Seeing; Prophesying",
    "Hazor": "<b>Hazor</b> - Court; Hay",
    "Heber": "<b>Heber</b> - One That Passes; Anger",
    "Hebrews": "<b>Hebrews</b> - Descendants Of Heber",
    "Hebron": "<b>Hebron</b> - Society; Friendship",
    "Hegai": "<b>Hegai</b> - Or Hege, Meditation; Word; Groaning; Separation",
    "Helam": "<b>Helam</b> - Their Army; Their Trouble",
    "Helbah": "<b>Helbah</b> - Helbon, Milk, Fatness",
    "Heldai": "<b>Heldai</b> - Heleb, Heled, The World; Rustiness",
    "Helek": "<b>Helek</b> - Part; Portion",
    "Helem": "<b>Helem</b> - Dreaming; Healing",
    "Heleph": "<b>Heleph</b> - Changing; Passing Over",
    "Helez": "<b>Helez</b> - Armed; Set Free",
    "Heli": "<b>Heli</b> - Ascending; Climbing Up",
    "Helkai": "<b>Helkai</b> - Same As Helek",
    "Helkath-Hazzurim": "<b>Helkath-Hazzurim</b> - The Field Of Strong Men, Or Of Rocks",
    "Helon": "<b>Helon</b> - Window; Grief",
    "Heman": "<b>Heman</b> - Their Trouble; Tumult; Much; In Great Number",
    "Hen": "<b>Hen</b> - Grace; Quiet; Rest",
    "Hena": "<b>Hena</b> - Troubling",
    "Henadad": "<b>Henadad</b> - Grace Of The Beloved",
    "Henoch": "<b>Henoch</b> - Same As Enoch",
    "Hepher": "<b>Hepher</b> - A Digger",
    "Hephzibah": "<b>Hephzibah</b> - My Delight Is In Her",
    "Heres": "<b>Heres</b> - The Son; An Earthen Pot",
    "Heresh": "<b>Heresh</b> - A Carpenter",
    "Hermas": "<b>Hermas</b> - Hermes, Mercury; Gain; Refuge",
    "Hermogenes": "<b>Hermogenes</b> - Begotten Of Mercury",
    "Hermon": "<b>Hermon</b> - Anathema; Devoted To Destruction",
    "Herod": "<b>Herod</b> - Son Of A Hero",
    "Herodion": "<b>Herodion</b> - The Song Of Juno",
    "Heshbon": "<b>Heshbon</b> - Invention; Industry",
    "Heshmon": "<b>Heshmon</b> - A Hasty Messenger",
    "Heth": "<b>Heth</b> - Trembling; Fear",
    "Hethlon": "<b>Hethlon</b> - A Fearful Dwelling",
    "Hezekiah": "<b>Hezekiah</b> - Strength Of The Lord",
    "Hezer": "<b>Hezer</b> - Hezir, A Bog; Converted",
    "Hezrai": "<b>Hezrai</b> - An Entry Or Vestibule",
    "Hezron": "<b>Hezron</b> - The Dart Of Joy; The Division Of The Song",
    "Hiddai": "<b>Hiddai</b> - A Praise; A Cry",
    "Hiddekel": "<b>Hiddekel</b> - Sharp Voice; Sound",
    "Hiel": "<b>Hiel</b> - God Lives; The Life Of God",
    "Hierapolis": "<b>Hierapolis</b> - Holy City",
    "Higgaion": "<b>Higgaion</b> - Meditation; Consideration",
    "Hilen": "<b>Hilen</b> - A Window; Grief",
    "Hilkiah": "<b>Hilkiah</b> - God Is My Portion",
    "Hillel": "<b>Hillel</b> - He That Praises",
    "Hinnom": "<b>Hinnom</b> - There They Are; Their Riches",
    "Hirah": "<b>Hirah</b> - Liberty; Anger",
    "Hiram": "<b>Hiram</b> - Exaltation Of Life; A Destroyer",
    "Hittite": "<b>Hittite</b> - One Who Is Broken; Who Fears",
    "Hivites": "<b>Hivites</b> - Wicked; Wickedness",
    "Hizkijah": "<b>Hizkijah</b> - The Strength Of The Lord",
    "Hobab": "<b>Hobab</b> - Favored; Beloved",
    "Hobah": "<b>Hobah</b> - Love; Friendship; Secrecy",
    "Hod": "<b>Hod</b> - Praise; Confession",
    "Hodaiah": "<b>Hodaiah</b> - The Praise Of The Lord",
    "Hodaviah": "<b>Hodaviah</b> - Hodiah, Hodijah, Same As Hodaiah",
    "Hodesh": "<b>Hodesh</b> - A Table; News",
    "Hoglah": "<b>Hoglah</b> - His Festival Or Dance",
    "Hoham": "<b>Hoham</b> - Woe To Them",
    "Holon": "<b>Holon</b> - A Window; Grief",
    "Homam": "<b>Homam</b> - Making An Uproar",
    "Hophin": "<b>Hophin</b> - He That Covers; My Fist",
    "Hor": "<b>Hor</b> - Who Conceives, Or Shows; A Hill",
    "Hor-Hagidgad": "<b>Hor-Hagidgad</b> - The Hill Of Felicity",
    "Horam": "<b>Horam</b> - Their Hill",
    "Horeb": "<b>Horeb</b> - Desert; Solitude; Destruction",
    "Horem": "<b>Horem</b> - An Offering Dedicated To God",
    "Hori": "<b>Hori</b> - A Prince; Freeborn",
    "Horims": "<b>Horims</b> - Princes; Being Angry",
    "Hormah": "<b>Hormah</b> - Devoted Or Consecrated To God; Utter Destruction",
    "Horonaim": "<b>Horonaim</b> - Angers; Ragings",
    "Horonites": "<b>Horonites</b> - Men Of Anger, Or Of Fury, Or Of Liberty",
    "Hosah": "<b>Hosah</b> - Trusting",
    "Hosanna": "<b>Hosanna</b> - Save I Pray Thee; Keep; Preserve",
    "Hosea": "<b>Hosea</b> - Hoshea, Savior; Safety",
    "Hoshaiah": "<b>Hoshaiah</b> - The Salvation Of The Lord",
    "Hoshama": "<b>Hoshama</b> - Heard; He Obeys",
    "Hotham": "<b>Hotham</b> - A Seal",
    "Hothir": "<b>Hothir</b> - Excelling; Remaining",
    "Hukkok": "<b>Hukkok</b> - Engraver; Scribe; Lawyer",
    "Hul": "<b>Hul</b> - Pain; Infirmity",
    "Huldah": "<b>Huldah</b> - The World",
    "Hupham": "<b>Hupham</b> - Their Chamber; Their Bank",
    "Huppim": "<b>Huppim</b> - A Chamber Covered; The Sea-Shore",
    "Hur": "<b>Hur</b> - Liberty; Whiteness; Hole",
    "Huram": "<b>Huram</b> - Their Liberty; Their Whiteness; Their Hole",
    "Huri": "<b>Huri</b> - Being Angry; Or Same As Huram",
    "Hushah": "<b>Hushah</b> - Hasting; Holding Peace",
    "Hushai": "<b>Hushai</b> - Their Haste; Their Sensuality; Their Silence",
    "Hushathite": "<b>Hushathite</b> - Hushim, Man Of Haste, Or Of Silence",
    "Huz": "<b>Huz</b> - Counsel; Woods; Fastened",
    "Huzoth": "<b>Huzoth</b> - Streets; Populous",
    "Huzzab": "<b>Huzzab</b> - Molten",
    "Hymeneus": "<b>Hymeneus</b> - Nuptial; The God Of Marriage",
    "Ibhar": "<b>Ibhar</b> - Election; He That Is Chosen",
    "Ibleam": "<b>Ibleam</b> - Ancient People; People Decreasing",
    "Ibneiah": "<b>Ibneiah</b> - Ibniah, The Building Of The Lord; The Understanding Of The Lord; Son By Adoption",
    "Ibri": "<b>Ibri</b> - Passing Over; Being Angry; Being With Young",
    "Ibzan": "<b>Ibzan</b> - Father Of A Target; Father Of Coldness",
    "Ichabod": "<b>Ichabod</b> - Where Is The Glory? Or, No Glory",
    "Iconium": "<b>Iconium</b> - Coming",
    "Idalah": "<b>Idalah</b> - The Hand Of Slander, Or Of Cursing",
    "Idbash": "<b>Idbash</b> - Flowing With Honey; The Land Of Destruction",
    "Iddo": "<b>Iddo</b> - His Band; Power; Praise",
    "Idumea": "<b>Idumea</b> - Red; Earthy; Bloody",
    "Igal": "<b>Igal</b> - Redeemed; Defiled",
    "Igdaliah": "<b>Igdaliah</b> - The Greatness Of The Lord",
    "Igeal": "<b>Igeal</b> - A Redeemer; Redeemed; Defiled",
    "Iim": "<b>Iim</b> - Heaps Of Hebrews, Or Of Angry Men",
    "Ije-Abarim": "<b>Ije-Abarim</b> - Heaps Of Hebrews, Or Of Passers Over",
    "Ijon": "<b>Ijon</b> - Look; Eye; Fountain",
    "Ikkesh": "<b>Ikkesh</b> - Forward; Wicked",
    "Illyricum": "<b>Illyricum</b> - Joy; Rejoicing",
    "Imlah": "<b>Imlah</b> - Plentitude; Circumcision",
    "Immanuel": "<b>Immanuel</b> - God With Us",
    "Immer": "<b>Immer</b> - Saying; Speaking; A Lamb",
    "Imnah": "<b>Imnah</b> - Same As Jimnah",
    "Imrah": "<b>Imrah</b> - A Rebel; Waxing Bitter; Changing",
    "Imri": "<b>Imri</b> - Speaking; Exalting; Bitter; A Lamb",
    "India": "<b>India</b> - Praise; Law",
    "Iphedeiah": "<b>Iphedeiah</b> - Redemption Of The Lord",
    "Ir": "<b>Ir</b> - Watchman; City; Vision",
    "Ira": "<b>Ira</b> - Watchman; Making Bare; Pouring Out",
    "Irad": "<b>Irad</b> - Wild Ass; Heap Of Empire; Dragon",
    "Iram": "<b>Iram</b> - The Effusion Of Them; A High Heap",
    "Iri": "<b>Iri</b> - Fire; Light",
    "Irijah": "<b>Irijah</b> - The Fear Of The Lord",
    "Irpeel": "<b>Irpeel</b> - The Health, Medicine, Or Exulting Of God",
    "Irshemesh": "<b>Irshemesh</b> - A City Of Bondage",
    "Isaac": "<b>Isaac</b> - Laughter",
    "Isaiah": "<b>Isaiah</b> - The Salvation Of The Lord",
    "Iscah": "<b>Iscah</b> - He That Anoints",
    "Iscariot": "<b>Iscariot</b> - A Man Of Murder; A Hireling",
    "Ish-Pan": "<b>Ish-Pan</b> - Hid; Broken In Two",
    "Ish-Tob": "<b>Ish-Tob</b> - Good Man",
    "Ishbak": "<b>Ishbak</b> - Who Is Empty Or Exhausted",
    "Ishbi-Benob": "<b>Ishbi-Benob</b> - Respiration; Conversion; Taking Captive",
    "Ishbosheth": "<b>Ishbosheth</b> - A Man Of Shame",
    "Ishi": "<b>Ishi</b> - Salvation",
    "Ishiah": "<b>Ishiah</b> - It Is The Lord",
    "Ishma": "<b>Ishma</b> - Named; Marveling; Desolation",
    "Ishmachiah": "<b>Ishmachiah</b> - Cleaving To The Lord",
    "Ishmael": "<b>Ishmael</b> - God That Hears",
    "Ishmaiah": "<b>Ishmaiah</b> - Hearing Or Obeying The Lord",
    "Ishmerai": "<b>Ishmerai</b> - Keeper, Or Keeping",
    "Ishod": "<b>Ishod</b> - A Comely Man",
    "Ishua": "<b>Ishua</b> - Plainness; Equal",
    "Ispah": "<b>Ispah</b> - A Jasper Stone",
    "Israel": "<b>Israel</b> - Who Prevails With God",
    "Issachar": "<b>Issachar</b> - Reward; Recompense",
    "Isui": "<b>Isui</b> - Same As Ishuah",
    "Italy": "<b>Italy</b> - Abounding With Calves Or Heifers",
    "Ithai": "<b>Ithai</b> - Strong; My Sign; A Plowshare",
    "Ithamar": "<b>Ithamar</b> - Island Of The Palm-Tree",
    "Ithiel": "<b>Ithiel</b> - Sign, Or Coming Of God",
    "Ithmah": "<b>Ithmah</b> - An Orphan",
    "Ithran": "<b>Ithran</b> - Remaining; Searching Out Diligently",
    "Ithream": "<b>Ithream</b> - Excellence Of The People",
    "Ittah-Kazin": "<b>Ittah-Kazin</b> - Hour, Or Time, Of A Prince",
    "Iturea": "<b>Iturea</b> - Guarded; Mountainous",
    "Ivah": "<b>Ivah</b> - Iniquity",
    "Izehar": "<b>Izehar</b> - Izhar, Clearness; Oil",
    "Izrahiah": "<b>Izrahiah</b> - The Lord Ariseth; The Clearness Of The Lord",
    "Izri": "<b>Izri</b> - Fasting; Tribulation",
    "Jaakan": "<b>Jaakan</b> - Tribulation; Labor",
    "Jaakobah": "<b>Jaakobah</b> - Supplanter; Deceiver; The Heel",
    "Jaala": "<b>Jaala</b> - Ascending; A Little Doe Or Goat",
    "Jaalam": "<b>Jaalam</b> - Hidden; Young Man; Heir",
    "Jaanai": "<b>Jaanai</b> - Answering; Afflicting; Making Poor",
    "Jaasau": "<b>Jaasau</b> - Doing; My Doing",
    "Jaasiel": "<b>Jaasiel</b> - God'S Work",
    "Jaazah": "<b>Jaazah</b> - Jaazar, Helper",
    "Jaazaniah": "<b>Jaazaniah</b> - Whom The Lord Will Hear",
    "Jaaziah": "<b>Jaaziah</b> - Jaaziel, The Strength Of The Lord",
    "Jabal": "<b>Jabal</b> - Which Glides Away",
    "Jabbok": "<b>Jabbok</b> - Evacuation; Dissipation; Wrestling",
    "Jabesh": "<b>Jabesh</b> - Dryness; Confusion; Shame",
    "Jabez": "<b>Jabez</b> - Sorrow; Trouble",
    "Jabin": "<b>Jabin</b> - Jabneh, He That Understands; Building",
    "Jabneel": "<b>Jabneel</b> - Building Of God",
    "Jachan": "<b>Jachan</b> - Wearing Out; Oppressing",
    "Jachin": "<b>Jachin</b> - He That Strengthens And Makes Steadfast",
    "Jacob": "<b>Jacob</b> - That Supplants, Undermines; The Heel",
    "Jada": "<b>Jada</b> - Knowing",
    "Jadau": "<b>Jadau</b> - His Hand; His Confession",
    "Jaddua": "<b>Jaddua</b> - Known",
    "Jael": "<b>Jael</b> - He That Ascends; A Kid",
    "Jagur": "<b>Jagur</b> - Husbandman; Stranger",
    "Jah": "<b>Jah</b> - The Everlasting",
    "Jahaleel": "<b>Jahaleel</b> - Praising God; Light Of God",
    "Jahath": "<b>Jahath</b> - Broken In Pieces; Descending",
    "Jahaz": "<b>Jahaz</b> - Jahazah, Quarrel; Dispute",
    "Jahaziah": "<b>Jahaziah</b> - The Vision Of The Lord",
    "Jahaziel": "<b>Jahaziel</b> - Seeing God",
    "Jahdiel": "<b>Jahdiel</b> - The Unity, Or Sharpness, Or Revenge, Of God",
    "Jahdo": "<b>Jahdo</b> - I Alone; His Joy; His Sharpness Of Wit; His Newness",
    "Jahleel": "<b>Jahleel</b> - Waiting For, Or Beseeching, Or Hope In, God",
    "Jahmai": "<b>Jahmai</b> - Warm; Making Warm",
    "Jahzeel": "<b>Jahzeel</b> - God Hasteth, Or Divideth",
    "Jair": "<b>Jair</b> - Jairus, My Light; Who Diffuses Light",
    "Jakan": "<b>Jakan</b> - Same As Achan",
    "Jakim": "<b>Jakim</b> - Rising; Confirming; Establishing",
    "Jalon": "<b>Jalon</b> - Tarrying; Murmuring",
    "Jambres": "<b>Jambres</b> - Poverty; Bitter; A Rebel",
    "James": "<b>James</b> - Same As Jacob",
    "Jamin": "<b>Jamin</b> - Right Hand; South Wind",
    "Jamlech": "<b>Jamlech</b> - Reigning; Asking Counsel",
    "Janna": "<b>Janna</b> - Jannes, Who Speaks Or Answers; Afflicted; Poor",
    "Janoah": "<b>Janoah</b> - Janohah, Resting; Tarrying; Deriving",
    "Janum": "<b>Janum</b> - Sleeping",
    "Japhet": "<b>Japhet</b> - Enlarged; Fair; Persuading",
    "Japhia": "<b>Japhia</b> - Enlightening; Appearing",
    "Japhlet": "<b>Japhlet</b> - Japhleti, Delivered; Banished",
    "Japho": "<b>Japho</b> - Fairness; Comeliness",
    "Jarah": "<b>Jarah</b> - A Wood; Honeycomb; Watching Closely",
    "Jareb": "<b>Jareb</b> - A Revenger",
    "Jared": "<b>Jared</b> - A Ruling; Commanding; Coming Down",
    "Jaresiah": "<b>Jaresiah</b> - The Bed Of The Lord; The Lord Hath Taken Away; Poverty",
    "Jarib": "<b>Jarib</b> - Fighting; Chiding; Multiplying; Avenging",
    "Jarmuth": "<b>Jarmuth</b> - Fearing, Or Seeing, Or Throwing Down, Death",
    "Jarvah": "<b>Jarvah</b> - Breathing, Or Making, A Sweet Smell",
    "Jashem": "<b>Jashem</b> - Jashen, Ancient; Sleeping",
    "Jasher": "<b>Jasher</b> - Righteous; Upright",
    "Jashobeam": "<b>Jashobeam</b> - The People Sitting; Or Captivity Of The People",
    "Jashub": "<b>Jashub</b> - A Returning; A Controversy; A Dwelling Place",
    "Jasiel": "<b>Jasiel</b> - The Strength Of God",
    "Jason": "<b>Jason</b> - He That Cures",
    "Jathniel": "<b>Jathniel</b> - Gift Of God",
    "Jattir": "<b>Jattir</b> - A Remnant; Excellent",
    "Javan": "<b>Javan</b> - Deceiver; One Who Makes Sad",
    "Jazeel": "<b>Jazeel</b> - Strength Of God",
    "Jazer": "<b>Jazer</b> - Assistance; Helper",
    "Jaziz": "<b>Jaziz</b> - Brightness; Departing",
    "Jearim": "<b>Jearim</b> - A Leap; Woods",
    "Jeaterai": "<b>Jeaterai</b> - Searching Out",
    "Jeberechiah": "<b>Jeberechiah</b> - Speaking Well Of, Or Kneeling To, The Lord",
    "Jebus": "<b>Jebus</b> - Treading Under Foot; Manger",
    "Jebusi": "<b>Jebusi</b> - Trodden Under Foot; Mangers",
    "Jecamiah": "<b>Jecamiah</b> - Resurrection, Or Confirmation, Or Revenge, Of The Lord",
    "Jecoliah": "<b>Jecoliah</b> - Perfection, Or Power, Of The Lord",
    "Jeconiah": "<b>Jeconiah</b> - Preparation, Or Stability, Of The Lord",
    "Jedaiah": "<b>Jedaiah</b> - The Hand Of The Lord; Confessing The Lord",
    "Jedeiah": "<b>Jedeiah</b> - One Lord; The Joy Of The Lord",
    "Jediael": "<b>Jediael</b> - The Science, Or Knowledge, Of God",
    "Jedidah": "<b>Jedidah</b> - Well Beloved; Amiable",
    "Jedidiah": "<b>Jedidiah</b> - Beloved Of The Lord",
    "Jediel": "<b>Jediel</b> - The Knowledge, Or Renewing, Of God",
    "Jeduthun": "<b>Jeduthun</b> - His Law; Giving Praise",
    "Jeezer": "<b>Jeezer</b> - Island Of Help",
    "Jegar-Sahadutha": "<b>Jegar-Sahadutha</b> - Heap Of Witness",
    "Jehaleleel": "<b>Jehaleleel</b> - Jehalelel, Praising God; Clearness Of God",
    "Jehaziel": "<b>Jehaziel</b> - Same As Jahaziel",
    "Jehdeiah": "<b>Jehdeiah</b> - Joy Together, One Lord",
    "Jeheiel": "<b>Jeheiel</b> - God Liveth",
    "Jehezekel": "<b>Jehezekel</b> - Strength Of God",
    "Jehiah": "<b>Jehiah</b> - The Lord Liveth",
    "Jehiskiah": "<b>Jehiskiah</b> - The Strength, Or Taking, Of The Lord",
    "Jehoadah": "<b>Jehoadah</b> - Passing Over; Testimony Of The Lord",
    "Jehoaddan": "<b>Jehoaddan</b> - Pleasure, Or Time, Of The Lord",
    "Jehoahaz": "<b>Jehoahaz</b> - Possession Of The Lord",
    "Jehoash": "<b>Jehoash</b> - Fire Of The Lord",
    "Jehohanan": "<b>Jehohanan</b> - Grace, Or Mercy, Or Gift, Of The Lord",
    "Jehoiachin": "<b>Jehoiachin</b> - Preparation, Or Strength, Of The Lord",
    "Jehoiada": "<b>Jehoiada</b> - Knowledge Of The Lord",
    "Jehoiakim": "<b>Jehoiakim</b> - Avenging, Or Establishing, Or Resurrection, Of The Lord",
    "Jehoiarib": "<b>Jehoiarib</b> - Fighting, Or Multiplying, Of The Lord",
    "Jehonadab": "<b>Jehonadab</b> - Jonadab, Free Giver; Liberality",
    "Jehonathan": "<b>Jehonathan</b> - Gift Of The Lord; Gift Of A Dove",
    "Jehoram": "<b>Jehoram</b> - Exaltation Of The Lord",
    "Jehoshaphat": "<b>Jehoshaphat</b> - The Lord Is Judge",
    "Jehosheba": "<b>Jehosheba</b> - Fullness, Or Oath, Of The Lord",
    "Jehoshua": "<b>Jehoshua</b> - Same As Joshua",
    "Jehovah": "<b>Jehovah</b> - Self-Subsisting",
    "Jehovah-Jireh": "<b>Jehovah-Jireh</b> - The Lord Will Provide",
    "Jehovah-Nissi": "<b>Jehovah-Nissi</b> - The Lord My Banner",
    "Jehovah-Shalom": "<b>Jehovah-Shalom</b> - The Lord Send Peace",
    "Jehovah-Shammah": "<b>Jehovah-Shammah</b> - The Lord Is There",
    "Jehovah-Tsidkenu": "<b>Jehovah-Tsidkenu</b> - The Lord Our Righteousness",
    "Jehozabad": "<b>Jehozabad</b> - The Lord'S Dowry; Having A Dowry",
    "Jehozadak": "<b>Jehozadak</b> - Justice Of The Lord",
    "Jehu": "<b>Jehu</b> - Himself Who Exists",
    "Jehubbah": "<b>Jehubbah</b> - Hiding, Binding",
    "Jehucal": "<b>Jehucal</b> - Mighty; Perfect; Wasted",
    "Jehud": "<b>Jehud</b> - Jehudi, Praising; Conferring",
    "Jehudijah": "<b>Jehudijah</b> - The Praise Of The Lord",
    "Jehush": "<b>Jehush</b> - Keeping Counsel; Fastened",
    "Jekabzeel": "<b>Jekabzeel</b> - The Congregation Of God",
    "Jekamean": "<b>Jekamean</b> - The People Shall Arise",
    "Jekamiah": "<b>Jekamiah</b> - Establishing, Or Revenging, Of The Lord",
    "Jekuthiel": "<b>Jekuthiel</b> - Hope, Or Congregation, Of The Lord",
    "Jemima": "<b>Jemima</b> - Handsome As The Day",
    "Jemuel": "<b>Jemuel</b> - God'S Day; Son Of God",
    "Jephunneh": "<b>Jephunneh</b> - He That Beholds",
    "Jerah": "<b>Jerah</b> - The Moon; Month; Smelling Sweet",
    "Jerahmeel": "<b>Jerahmeel</b> - The Mercy, Or The Beloved, Of God",
    "Jerebai": "<b>Jerebai</b> - Fighting; Chiding; Multiplying",
    "Jered": "<b>Jered</b> - Ruling; Coming Down",
    "Jeremai": "<b>Jeremai</b> - My Height; Throwing Forth Waters",
    "Jeremiah": "<b>Jeremiah</b> - Exaltation Of The Lord",
    "Jeremoth": "<b>Jeremoth</b> - Eminences; One That Fears Death",
    "Jeriah": "<b>Jeriah</b> - Fear, Or Throwing Down, Of The Lord",
    "Jericho": "<b>Jericho</b> - His Moon; His Month; His Sweet Smell",
    "Jeriel": "<b>Jeriel</b> - Fear, Or Vision Of God",
    "Jerijah": "<b>Jerijah</b> - Same As Jeriah",
    "Jerimoth": "<b>Jerimoth</b> - He That Fears Or Rejects Death",
    "Jerioth": "<b>Jerioth</b> - Kettles; Breaking Asunder",
    "Jeroboam": "<b>Jeroboam</b> - He That Opposes The People",
    "Jeroham": "<b>Jeroham</b> - High; Merciful; Beloved",
    "Jerubbaal": "<b>Jerubbaal</b> - He That Defends Baal, Let Baal Defend His Cause",
    "Jerubbesheth": "<b>Jerubbesheth</b> - Let The Idol Of Confusion Defend Itself",
    "Jeruel": "<b>Jeruel</b> - Fear, Or Vision Of God",
    "Jerusalem": "<b>Jerusalem</b> - Vision Of Peace",
    "Jerusha": "<b>Jerusha</b> - Banished; Possession; Inheritance",
    "Jesaiah": "<b>Jesaiah</b> - Health, Or Salvation, Of The Lord",
    "Jeshebeab": "<b>Jeshebeab</b> - Sitting, Or Captivity, Of The Father",
    "Jesher": "<b>Jesher</b> - Right; Singing",
    "Jeshimon": "<b>Jeshimon</b> - Solitude; Desolation",
    "Jeshishai": "<b>Jeshishai</b> - Ancient; Rejoicing Exceedingly",
    "Jeshohaia": "<b>Jeshohaia</b> - The Lord Pressing; The Meditation Of God",
    "Jeshua": "<b>Jeshua</b> - Same As Joshua",
    "Jesiah": "<b>Jesiah</b> - Sprinkling Of The Lord",
    "Jesimiel": "<b>Jesimiel</b> - Naming, Or Astonishment, Of God",
    "Jesse": "<b>Jesse</b> - Gift; Oblation; One Who Is",
    "Jesui": "<b>Jesui</b> - Even-Tempered; Flat Country",
    "Jesus": "<b>Jesus</b> - Savior; Deliverer",
    "Jether": "<b>Jether</b> - He That Excels",
    "Jetheth": "<b>Jetheth</b> - Giving",
    "Jethlah": "<b>Jethlah</b> - Hanging Up; Heaping Up",
    "Jethro": "<b>Jethro</b> - His Excellence; His Posterity",
    "Jetur": "<b>Jetur</b> - Order; Succession; Mountainous",
    "Jeuel": "<b>Jeuel</b> - God Hath Taken Away; God Heaping Up",
    "Jeush": "<b>Jeush</b> - Jeuz, He That Is Devoured",
    "Jew": "<b>Jew</b> - Same As Judah",
    "Jezaniah": "<b>Jezaniah</b> - Nourishment, Or Weapons, Of The Lord",
    "Jezebel": "<b>Jezebel</b> - Chaste",
    "Jezer": "<b>Jezer</b> - Island Of Help",
    "Jeziah": "<b>Jeziah</b> - Jeziel, Sprinkling Of The Lord",
    "Jezneel": "<b>Jezneel</b> - Seed Of God",
    "Jezoar": "<b>Jezoar</b> - Clear; White",
    "Jezrahiah": "<b>Jezrahiah</b> - The Lord Arises; Brightness Of The Lord",
    "Jibsam": "<b>Jibsam</b> - Their Drought, Their Confusion",
    "Jidlaph": "<b>Jidlaph</b> - He That Distills Water",
    "Jimnah": "<b>Jimnah</b> - Right Hand; Numbering; Preparing",
    "Jiphtah": "<b>Jiphtah</b> - Opening",
    "Jiphthael": "<b>Jiphthael</b> - God Opening",
    "Joab": "<b>Joab</b> - Paternity; Voluntary",
    "Joah": "<b>Joah</b> - Fraternity; Brother Of The Lord",
    "Joahaz": "<b>Joahaz</b> - Apprehending; Possessing; Seeing",
    "Joakim": "<b>Joakim</b> - Rising Or Establishing Of The Lord",
    "Joanna": "<b>Joanna</b> - Grace Or Gift Of The Lord",
    "Joash": "<b>Joash</b> - Who Despairs Or Burns",
    "Joatham": "<b>Joatham</b> - Same As Jotham",
    "Job": "<b>Job</b> - He That Weeps Or Cries",
    "Jobab": "<b>Jobab</b> - Sorrowful, Hated",
    "Jochebed": "<b>Jochebed</b> - Glorious; Honorable",
    "Joed": "<b>Joed</b> - Witnessing; Robbing; Passing Over",
    "Joel": "<b>Joel</b> - He That Wills Or Commands",
    "Joelah": "<b>Joelah</b> - Lifting Up; Profiting; Taking Away Slander",
    "Joezer": "<b>Joezer</b> - He That Aids",
    "Jogbehah": "<b>Jogbehah</b> - An Exalting; High",
    "Jogli": "<b>Jogli</b> - Passing Over; Turning Back; Rejoicing",
    "Joha": "<b>Joha</b> - Who Enlivens Or Gives Life",
    "Johanan": "<b>Johanan</b> - Who Is Liberal Or Merciful",
    "John": "<b>John</b> - The Grace Or Mercy Of The Lord",
    "Joiarib": "<b>Joiarib</b> - Chiding, Or Multiplying, Of The Lord",
    "Jokdeam": "<b>Jokdeam</b> - Crookedness, Or Burning, Of The People",
    "Jokim": "<b>Jokim</b> - That Made The Sun Stand Still",
    "Jokmeam": "<b>Jokmeam</b> - Confirmation, Or Revenge, Of The People",
    "Jokneam": "<b>Jokneam</b> - Possessing, Or Building Up, Of The People",
    "Jokshan": "<b>Jokshan</b> - An Offense; Hardness; A Knocking",
    "Joktan": "<b>Joktan</b> - Small Dispute; Contention; Disgust",
    "Jonadab": "<b>Jonadab</b> - Who Gives Liberally",
    "Jonah": "<b>Jonah</b> - Or Jonas, A Dove; He That Oppresses; Destroyer",
    "Jonan": "<b>Jonan</b> - A Dove; Multiplying Of The People",
    "Jonathan": "<b>Jonathan</b> - Given Of God",
    "Joppa": "<b>Joppa</b> - Beauty; Comeliness",
    "Jorah": "<b>Jorah</b> - Jorai, Showing; Casting Forth; A Cauldron",
    "Joram": "<b>Joram</b> - To Cast; Elevated",
    "Jordan": "<b>Jordan</b> - The River Of Judgment",
    "Jorim": "<b>Jorim</b> - He That Exalts The Lord",
    "Josabad": "<b>Josabad</b> - Having A Dowry",
    "Josaphat": "<b>Josaphat</b> - Same As Jehoshaphat",
    "Jose": "<b>Jose</b> - Raised; Who Pardons",
    "Joseph": "<b>Joseph</b> - Increase; Addition",
    "Joses": "<b>Joses</b> - Same As Jose",
    "Joshah": "<b>Joshah</b> - Being; Forgetting; Owing",
    "Joshaviah": "<b>Joshaviah</b> - The Seat, Alteration, Or Captivity Of The Lord",
    "Joshbekesha": "<b>Joshbekesha</b> - It Is Requiring Or Beseeching",
    "Joshua": "<b>Joshua</b> - A Savior; A Deliverer",
    "Josiah": "<b>Josiah</b> - The Lord Burns; The Fire Of The Lord",
    "Josibiah": "<b>Josibiah</b> - The Seat, Or Captivity Of The Lord",
    "Josiphiah": "<b>Josiphiah</b> - Increase Of The Lord; The Lord'S Finishing",
    "Jotham": "<b>Jotham</b> - The Perfection Of The Lord",
    "Jothath": "<b>Jothath</b> - Jothatha, His Goodness",
    "Jozabad": "<b>Jozabad</b> - Same As Josabad",
    "Jozachar": "<b>Jozachar</b> - Remembering; Of The Male Sex",
    "Jubal": "<b>Jubal</b> - He That Runs; A Trumpet",
    "Jucal": "<b>Jucal</b> - Mighty; Perfect",
    "Judaea": "<b>Judaea</b> - Judea, Same As Judah",
    "Judah": "<b>Judah</b> - The Praise Of The Lord; Confession",
    "Judas": "<b>Judas</b> - Jude, Same As Judah",
    "Judith": "<b>Judith</b> - Same As Judah",
    "Julia": "<b>Julia</b> - Downy; Soft And Tender Hair",
    "Julius": "<b>Julius</b> - Same As Julia",
    "Junia": "<b>Junia</b> - Youth",
    "Jupiter": "<b>Jupiter</b> - The Father That Helpeth",
    "Jushabhesed": "<b>Jushabhesed</b> - Dwelling-Place; Change Of Mercy",
    "Justus": "<b>Justus</b> - Just Or Upright",
    "Juttah": "<b>Juttah</b> - Turning Away",
    "Kabzeel": "<b>Kabzeel</b> - The Congregation Of God",
    "Kadesh": "<b>Kadesh</b> - Holiness",
    "Kadesh-Barnea": "<b>Kadesh-Barnea</b> - Holiness Of An Inconstant Son",
    "Kadmiel": "<b>Kadmiel</b> - God Of Antiquity; God Of Rising",
    "Kadmonites": "<b>Kadmonites</b> - Ancients; Chiefs",
    "Kallai": "<b>Kallai</b> - Light; Resting By Fire; My Voice",
    "Kanah": "<b>Kanah</b> - Of Reeds",
    "Kareah": "<b>Kareah</b> - Bald; Ice",
    "Karkaa": "<b>Karkaa</b> - Floor; Dissolving Coldness",
    "Karkor": "<b>Karkor</b> - They Rested",
    "Karnaim": "<b>Karnaim</b> - Horns",
    "Kartah": "<b>Kartah</b> - Calling; Meeting",
    "Kedar": "<b>Kedar</b> - Blackness; Sorrow",
    "Kedemah": "<b>Kedemah</b> - Oriental; Ancient; First",
    "Kedemoth": "<b>Kedemoth</b> - Antiquity; Old Age",
    "Kehelahath": "<b>Kehelahath</b> - A Whole; A Congregation",
    "Keiiah": "<b>Keiiah</b> - She That Divides Or Cuts",
    "Kelaiah": "<b>Kelaiah</b> - Voice Of The Lord; Gathering Together",
    "Kelitah": "<b>Kelitah</b> - Same As Kelaiah",
    "Kemuel": "<b>Kemuel</b> - God Hath Raised Up, Or Established Him",
    "Kenah": "<b>Kenah</b> - Buying; Possession",
    "Kenan": "<b>Kenan</b> - Buyer; Owner",
    "Kenaz": "<b>Kenaz</b> - This Purchase; This Lamentation",
    "Kenites": "<b>Kenites</b> - Possession; Purchase; Lamentation",
    "Kenizzites": "<b>Kenizzites</b> - Possession; Purchase",
    "Keren-Happuch": "<b>Keren-Happuch</b> - The Horn Or Child Of Beauty",
    "Kerioth": "<b>Kerioth</b> - The Cities; The Callings",
    "Keros": "<b>Keros</b> - Crooked; Crookedness",
    "Keturah": "<b>Keturah</b> - That Makes The Incense To Fume",
    "Kezia": "<b>Kezia</b> - Superficies; The Angle; Cassia",
    "Keziz": "<b>Keziz</b> - End; Extremity",
    "Kibroth-Hattaavah": "<b>Kibroth-Hattaavah</b> - The Graves Of Lust",
    "Kibzaim": "<b>Kibzaim</b> - Congregation",
    "Kidron": "<b>Kidron</b> - Obscure; Making Black Or Sad",
    "Kinah": "<b>Kinah</b> - Same As Kenah",
    "Kir": "<b>Kir</b> - A City; Wall; Meeting",
    "Kirharaseth": "<b>Kirharaseth</b> - Kirharesh, City Of The Sun; Wall Of Burnt Brick",
    "Kirioth": "<b>Kirioth</b> - Same As Kerioth",
    "Kirjath": "<b>Kirjath</b> - City; Vocation; Meeting",
    "Kirjath-Arba": "<b>Kirjath-Arba</b> - City Of Four; Fourth City",
    "Kirjath-Arim": "<b>Kirjath-Arim</b> - City Of Those Who Watch",
    "Kirjath-Baal": "<b>Kirjath-Baal</b> - City Of Baal, Or Of A Ruler",
    "Kirjath-Huzoth": "<b>Kirjath-Huzoth</b> - City Of Streets; Populous City",
    "Kirjath-Jearim": "<b>Kirjath-Jearim</b> - City Of Woods",
    "Kirjath-Sannah": "<b>Kirjath-Sannah</b> - City Of Enmity, Or Of A Blackberry Bush",
    "Kirjath-Sepher": "<b>Kirjath-Sepher</b> - City Of Letters, Or Of The Book",
    "Kirjathaim": "<b>Kirjathaim</b> - The Two Cities; Callings; Or Meetings",
    "Kish": "<b>Kish</b> - Hard; Difficult; Straw; For Age",
    "Kishi": "<b>Kishi</b> - Hardness; His Gravity; His Offense",
    "Kishion": "<b>Kishion</b> - Hardness; Soreness",
    "Kishon": "<b>Kishon</b> - Hard; Sore",
    "Kithlish": "<b>Kithlish</b> - It Is A Wall; The Company Of A Lioness",
    "Kitron": "<b>Kitron</b> - Making Sweet; Binding Together",
    "Kittim": "<b>Kittim</b> - Breaking; Bruising Small; Gold; Coloring",
    "Koa": "<b>Koa</b> - Hope; A Congregation; A Line; A Rule",
    "Kohath": "<b>Kohath</b> - Congregation; Wrinkle; Bluntness",
    "Kolariah": "<b>Kolariah</b> - Voice Of The Lord",
    "Korah": "<b>Korah</b> - Baldness; Ice; Frost",
    "Kushaiah": "<b>Kushaiah</b> - Same As Kishi",
    "Laadah": "<b>Laadah</b> - To Assemble Together; To Testify; Passing Over",
    "Laadan": "<b>Laadan</b> - For Pleasure; Devouring; Judgment",
    "Laban": "<b>Laban</b> - White; Shining; Gentle; Brittle",
    "Labana": "<b>Labana</b> - The Moon; Whiteness; Frankincense",
    "Lachish": "<b>Lachish</b> - Who Walks, Or Exists, Of Himself",
    "Lael": "<b>Lael</b> - To God; To The Mighty",
    "Lahad": "<b>Lahad</b> - Praising; To Confess",
    "Lahairoi": "<b>Lahairoi</b> - Who Liveth And Seeth Me",
    "Lahmam": "<b>Lahmam</b> - Their Bread; Their War",
    "Lahmi": "<b>Lahmi</b> - My Bread; My War",
    "Laish": "<b>Laish</b> - A Lion",
    "Lamech": "<b>Lamech</b> - Poor; Made Low",
    "Laodicea": "<b>Laodicea</b> - Just People",
    "Lapidoth": "<b>Lapidoth</b> - Enlightened; Lamps",
    "Lasea": "<b>Lasea</b> - Thick; Wise",
    "Lashah": "<b>Lashah</b> - To Call; To Anoint",
    "Lazarus": "<b>Lazarus</b> - Assistance Of God",
    "Leah": "<b>Leah</b> - Weary; Tired",
    "Lebanon": "<b>Lebanon</b> - White, Incense",
    "Lebaoth": "<b>Lebaoth</b> - Lividness",
    "Lebbeus": "<b>Lebbeus</b> - A Man Of Heart; Praising; Confessing",
    "Lebonah": "<b>Lebonah</b> - Same As Labana",
    "Lehabim": "<b>Lehabim</b> - Flames; Inflamed; Swords",
    "Lehi": "<b>Lehi</b> - Jawbone",
    "Lekah": "<b>Lekah</b> - Walking; Going",
    "Lemuel": "<b>Lemuel</b> - God With Them, Or Him",
    "Leshem": "<b>Leshem</b> - A Name; Putting; A Precious Stone",
    "Letushim": "<b>Letushim</b> - Hammermen; Filemen",
    "Leummim": "<b>Leummim</b> - Countries; Without Water",
    "Levi": "<b>Levi</b> - Associated With Him",
    "Libnah": "<b>Libnah</b> - White; Whiteness",
    "Libni": "<b>Libni</b> - Same As Libnah",
    "Libya": "<b>Libya</b> - The Heart Of The Sea; Fat",
    "Linus": "<b>Linus</b> - Net",
    "Lo-Ammi": "<b>Lo-Ammi</b> - Not My People",
    "Lo-Ruhamah": "<b>Lo-Ruhamah</b> - Not Having Obtained Mercy; Not Pitied",
    "Lod": "<b>Lod</b> - Nativity; Generation",
    "Lois": "<b>Lois</b> - Better",
    "Lot": "<b>Lot</b> - Lotan, Wrapt Up; Hidden; Covered; Myrrh; Rosin",
    "Lubin": "<b>Lubin</b> - Heart Of A Man; Heart Of The Sea",
    "Lucas": "<b>Lucas</b> - Lucius, Luminous; White",
    "Lucifer": "<b>Lucifer</b> - Bringing Light",
    "Lud": "<b>Lud</b> - Ludim, Same As Lod",
    "Luhith": "<b>Luhith</b> - Made Of Boards",
    "Luke": "<b>Luke</b> - Luminous; White",
    "Luz": "<b>Luz</b> - Separation; Departure; An Almond",
    "Lycaonia": "<b>Lycaonia</b> - She-Wolf",
    "Lydda": "<b>Lydda</b> - Lydia, A Standing Pool",
    "Lysanias": "<b>Lysanias</b> - That Drives Away Sorrow",
    "Lysias": "<b>Lysias</b> - Dissolving",
    "Lysimachus": "<b>Lysimachus</b> - Scattering The Battle",
    "Lystra": "<b>Lystra</b> - That Dissolves Or Disperses",
    "Maachah": "<b>Maachah</b> - Pressed Down; Worn; Fastened",
    "Maachathi": "<b>Maachathi</b> - Broken",
    "Maadai": "<b>Maadai</b> - Pleasant; Testifying",
    "Maadiah": "<b>Maadiah</b> - Pleasantness; The Testimony Of The Lord",
    "Maai": "<b>Maai</b> - Belly; Heaping Up",
    "Maale-Akrabbim": "<b>Maale-Akrabbim</b> - Ascent Of Scorpions",
    "Maarath": "<b>Maarath</b> - Den; Making Empty; Watching",
    "Maaseiah": "<b>Maaseiah</b> - The Work Of The Lord",
    "Maasiai": "<b>Maasiai</b> - The Defense, Or Strength, Or Trust Of The Lord",
    "Maath": "<b>Maath</b> - Wiping Away; Breaking; Fearing; Smiting",
    "Maaz": "<b>Maaz</b> - Wood; Wooden",
    "Macedonia": "<b>Macedonia</b> - Burning; Adoration",
    "Machbenah": "<b>Machbenah</b> - Machbanai, Poverty; The Smiting Of His Son",
    "Machi": "<b>Machi</b> - Poor; A Smiter",
    "Machir": "<b>Machir</b> - Selling; Knowing",
    "Machnadebai": "<b>Machnadebai</b> - Smiter",
    "Machpelah": "<b>Machpelah</b> - Double",
    "Madai": "<b>Madai</b> - A Measure; Judging; A Garment",
    "Madian": "<b>Madian</b> - Judgment; Striving; Covering; Chiding",
    "Madmannah": "<b>Madmannah</b> - Measure Of A Gift; Preparation Of A Garment",
    "Madon": "<b>Madon</b> - A Chiding; A Garment; His Measure",
    "Magbish": "<b>Magbish</b> - Excelling; Height",
    "Magdala": "<b>Magdala</b> - Tower; Greatness",
    "Magdalene": "<b>Magdalene</b> - A Person From Magdala",
    "Magdiel": "<b>Magdiel</b> - Declaring God; Chosen Fruit Of God",
    "Magog": "<b>Magog</b> - Covering; Roof; Dissolving",
    "Magor-Missabib": "<b>Magor-Missabib</b> - Fear On Every Side",
    "Magpiash": "<b>Magpiash</b> - A Body Thrust Hard Together",
    "Mahalah": "<b>Mahalah</b> - Mahalath, Sickness; A Company Of Dancers; A Harp",
    "Mahaleleel": "<b>Mahaleleel</b> - Praising God",
    "Mahali": "<b>Mahali</b> - Infirmity; A Harp; Pardon",
    "Mahanaim": "<b>Mahanaim</b> - Tents; Two Fields; Two Armies",
    "Mahanehdan": "<b>Mahanehdan</b> - Tents Of Judgment",
    "Mahanem": "<b>Mahanem</b> - A Comforter",
    "Maharai": "<b>Maharai</b> - Hasting; A Hill; From A Hill",
    "Mahath": "<b>Mahath</b> - Same As Maath",
    "Mahavites": "<b>Mahavites</b> - Declaring A Message; Marrow",
    "Mahaz": "<b>Mahaz</b> - An End; Ending; Growing Hope",
    "Mahazioth": "<b>Mahazioth</b> - Seeing A Sign; Seeing A Letter",
    "Maher-Shalal-Hash-Baz": "<b>Maher-Shalal-Hash-Baz</b> - Making Speed To The Spoil; He Hastens To The Prey",
    "Mahlah": "<b>Mahlah</b> - Mahli, Mahlon, Same As Mahali",
    "Makas": "<b>Makas</b> - Same As Mahaz",
    "Makheloth": "<b>Makheloth</b> - Assemblies; Congregations",
    "Makkedah": "<b>Makkedah</b> - Worshiping; Burning; Raised; Crookedness",
    "Malachi": "<b>Malachi</b> - My Messenger; My Angel",
    "Malcham": "<b>Malcham</b> - Malchom, Their King; Their Counselor",
    "Malchiah": "<b>Malchiah</b> - Malchijah, The Lord My King, Or My Counselor",
    "Malchiel": "<b>Malchiel</b> - God Is My King, Or Counselor",
    "Malchus": "<b>Malchus</b> - My King, Kingdom, Or Counselor",
    "Maleleel": "<b>Maleleel</b> - Same As Mahaleleel",
    "Mallothi": "<b>Mallothi</b> - Fullness; Circumcision",
    "Malluch": "<b>Malluch</b> - Reigning; Counseling",
    "Mammon": "<b>Mammon</b> - Riches",
    "Mamre": "<b>Mamre</b> - Rebellious; Bitter; Set With Trees",
    "Manaen": "<b>Manaen</b> - A Comforter; A Leader",
    "Manahethites": "<b>Manahethites</b> - My Lady; My Prince Of Rest",
    "Manasseh": "<b>Manasseh</b> - Forgetfulness; He That Is Forgotten",
    "Manoah": "<b>Manoah</b> - Rest; A Present",
    "Maon": "<b>Maon</b> - House; Place Of Sin",
    "Mara": "<b>Mara</b> - Marah, Bitter; Bitterness",
    "Maralah": "<b>Maralah</b> - Sleep; A Sacrifice Of Myrrh; Ascension",
    "Maranatha": "<b>Maranatha</b> - The Lord Is Coming",
    "Marcus": "<b>Marcus</b> - Polite; Shining",
    "Mareshah": "<b>Mareshah</b> - From The Beginning; An Inheritance",
    "Mark": "<b>Mark</b> - Same As Marcus",
    "Maroth": "<b>Maroth</b> - Bitterness",
    "Marsena": "<b>Marsena</b> - Bitterness Of A Bramble",
    "Martha": "<b>Martha</b> - Who Becomes Bitter; Provoking",
    "Mary": "<b>Mary</b> - Same As Miriam",
    "Mash": "<b>Mash</b> - Same As Meshech",
    "Mashal": "<b>Mashal</b> - A Parable; Governing",
    "Masrekah": "<b>Masrekah</b> - Whistling; Hissing",
    "Massa": "<b>Massa</b> - A Burden; Prophecy",
    "Massah": "<b>Massah</b> - Temptation",
    "Matred": "<b>Matred</b> - Wand Of Government",
    "Matri": "<b>Matri</b> - Rain; Prison",
    "Mattan": "<b>Mattan</b> - Mattana, Mattenai, Gifts; Rains",
    "Mattaniah": "<b>Mattaniah</b> - Gift, Or Hope, Of The Lord",
    "Mattatha": "<b>Mattatha</b> - His Gift",
    "Mattathias": "<b>Mattathias</b> - The Gift Of The Lord",
    "Matthal": "<b>Matthal</b> - Gift; He That Gives",
    "Matthan": "<b>Matthan</b> - Same As Mattan",
    "Matthanias": "<b>Matthanias</b> - Same As Mattaniah",
    "Matthew": "<b>Matthew</b> - Given; A Reward",
    "Matthias": "<b>Matthias</b> - Mattithiah, Same As Mattathias",
    "Mazzaroth": "<b>Mazzaroth</b> - The Twelve Signs Of The Zodiac",
    "Meah": "<b>Meah</b> - A Hundred Cubits",
    "Mearah": "<b>Mearah</b> - Den; Cave; Making Empty",
    "Mebunnai": "<b>Mebunnai</b> - Son; Building; Understanding",
    "Mecherath": "<b>Mecherath</b> - Selling; Knowledge",
    "Medad": "<b>Medad</b> - He That Measures; Water Of Love",
    "Medan": "<b>Medan</b> - Judgment; Process",
    "Medeba": "<b>Medeba</b> - Waters Of Grief; Waters Springing Up",
    "Media": "<b>Media</b> - Measure; Habit; Covering",
    "Megiddo": "<b>Megiddo</b> - His Precious Fruit; Declaring A Message",
    "Megiddon": "<b>Megiddon</b> - Same As Megiddo",
    "Mehetabel": "<b>Mehetabel</b> - How Good Is God",
    "Mehida": "<b>Mehida</b> - A Riddle; Sharpness Of Wit",
    "Mehir": "<b>Mehir</b> - A Reward",
    "Mehujael": "<b>Mehujael</b> - Who Proclaims God",
    "Mehuman": "<b>Mehuman</b> - Making An Uproar; A Multitude",
    "Mejarkon": "<b>Mejarkon</b> - The Waters Of Jordan",
    "Mekonah": "<b>Mekonah</b> - A Foot Of A Pillar; Provision",
    "Melatiah": "<b>Melatiah</b> - Deliverance Of The Lord",
    "Melchi": "<b>Melchi</b> - My King; My Counsel",
    "Melchi-Shua": "<b>Melchi-Shua</b> - King Of Health; Magnificent King",
    "Melchiah": "<b>Melchiah</b> - God Is My King",
    "Melchizedek": "<b>Melchizedek</b> - King Of Justice",
    "Melea": "<b>Melea</b> - Supplying; Supplied",
    "Melech": "<b>Melech</b> - King; Counselor",
    "Melita": "<b>Melita</b> - Affording Honey",
    "Mellicu": "<b>Mellicu</b> - His Kingdom; His Counselor",
    "Melzar": "<b>Melzar</b> - Circumcision Of A Narrow Place, Or Of A Bond",
    "Memphis": "<b>Memphis</b> - Abode Of The Good",
    "Memucan": "<b>Memucan</b> - Impoverished; To Prepare; Certain; True",
    "Menahem": "<b>Menahem</b> - Comforter; Who Conducts Them; Preparation Of Heat",
    "Menan": "<b>Menan</b> - Numbered; Rewarded; Prepared",
    "Mene": "<b>Mene</b> - Who Reckons Or Is Counted",
    "Meonenim": "<b>Meonenim</b> - Charmers, Regarders Of Times",
    "Mephaath": "<b>Mephaath</b> - Appearance, Or Force, Of Waters",
    "Mephibosheth": "<b>Mephibosheth</b> - Out Of My Mouth Proceeds Reproach",
    "Merab": "<b>Merab</b> - He That Fights Or Disputes",
    "Meraioth": "<b>Meraioth</b> - Bitterness; Rebellious; Changing",
    "Merari": "<b>Merari</b> - Bitter; To Provoke",
    "Mercurius": "<b>Mercurius</b> - An Orator; An Interpreter",
    "Mered": "<b>Mered</b> - Rebellious, Ruling",
    "Meremoth": "<b>Meremoth</b> - Bitterness; Myrrh Of Death",
    "Meres": "<b>Meres</b> - Defluxion; Imposthume",
    "Meribah": "<b>Meribah</b> - Dispute; Quarrel",
    "Meribbaal": "<b>Meribbaal</b> - He That Resists Baal; Rebellion",
    "Merodach": "<b>Merodach</b> - Bitter Contrition",
    "Merodach-Baladan": "<b>Merodach-Baladan</b> - Bitter Contrition, Without Judgment",
    "Merom": "<b>Merom</b> - Eminences; Elevations",
    "Meronothite": "<b>Meronothite</b> - My Singing; Rejoicing; Bearing Rule",
    "Meroz": "<b>Meroz</b> - Secret, Leanness",
    "Mesha": "<b>Mesha</b> - Burden; Salvation",
    "Meshach": "<b>Meshach</b> - That Draws With Force",
    "Meshech": "<b>Meshech</b> - Who Is Drawn By Force",
    "Meshelemiah": "<b>Meshelemiah</b> - Peace, Or Perfection, Of The Lord",
    "Meshezaheel": "<b>Meshezaheel</b> - God Taking Away; The Salvation Of God",
    "Meshillamith": "<b>Meshillamith</b> - Peaceable; Perfect; Giving Again",
    "Meshullam": "<b>Meshullam</b> - Peaceable; Perfect; Their Parables",
    "Mesobaite": "<b>Mesobaite</b> - The Lord'S Standing-Place; A Little Doe",
    "Mesopotamia": "<b>Mesopotamia</b> - Between Two Rivers",
    "Messiah": "<b>Messiah</b> - Anointed",
    "Metheg-Ammah": "<b>Metheg-Ammah</b> - Bridle Of Bondage",
    "Methusael": "<b>Methusael</b> - Who Demands His Death",
    "Methusaleh": "<b>Methusaleh</b> - He Has Sent His Death",
    "Meunim": "<b>Meunim</b> - Dwelling-Places; Afflicted",
    "Mezahab": "<b>Mezahab</b> - Gilded",
    "Miamin": "<b>Miamin</b> - The Right Hand",
    "Mibhar": "<b>Mibhar</b> - Chosen; Youth",
    "Mibsam": "<b>Mibsam</b> - Smelling Sweet",
    "Mibzar": "<b>Mibzar</b> - Defending; Forbidding; Taking Away",
    "Micah": "<b>Micah</b> - Poor; Humble",
    "Micaiah": "<b>Micaiah</b> - Who Is Like To God?",
    "Micha": "<b>Micha</b> - Same As Micaiah",
    "Michaiah": "<b>Michaiah</b> - Michael, Same As Micah",
    "Michal": "<b>Michal</b> - Who Is Perfect?",
    "Michmach": "<b>Michmach</b> - He That Strikes",
    "Michmethah": "<b>Michmethah</b> - The Gift Or Death Of A Striker",
    "Michri": "<b>Michri</b> - Selling",
    "Michtam": "<b>Michtam</b> - Golden Psalm",
    "Middin": "<b>Middin</b> - Judgment; Striving",
    "Midian": "<b>Midian</b> - Judgment; Covering; Habit",
    "Migdalel": "<b>Migdalel</b> - Tower Of God",
    "Migdalgad": "<b>Migdalgad</b> - Tower Compassed About",
    "Migdol": "<b>Migdol</b> - A Tower",
    "Migron": "<b>Migron</b> - Fear; Farm; Throat",
    "Mijamin": "<b>Mijamin</b> - Right Hand",
    "Mikloth": "<b>Mikloth</b> - Little Wants; Little Voices; Looking Downward",
    "Milalai": "<b>Milalai</b> - Circumcision; My Talk",
    "Milcah": "<b>Milcah</b> - Queen",
    "Milcom": "<b>Milcom</b> - Their King",
    "Miletum": "<b>Miletum</b> - Red; Scarlet",
    "Millo": "<b>Millo</b> - Fullness",
    "Miniamin": "<b>Miniamin</b> - Right Hand",
    "Minneiah": "<b>Minneiah</b> - Possession Of The Lord",
    "Minni": "<b>Minni</b> - Reckoned; Prepared",
    "Minnith": "<b>Minnith</b> - Same As Minni",
    "Miriam": "<b>Miriam</b> - Rebellion",
    "Mishael": "<b>Mishael</b> - Who Is Asked For Or Lent",
    "Mishal": "<b>Mishal</b> - Parables; Governing",
    "Misham": "<b>Misham</b> - Their Savior; Taking Away",
    "Misheal": "<b>Misheal</b> - Requiring; Lent; Pit",
    "Mishma": "<b>Mishma</b> - Hearing; Obeying",
    "Mishmannah": "<b>Mishmannah</b> - Fatness; Taking Away Provision",
    "Mishraites": "<b>Mishraites</b> - Spread Abroad",
    "Mispar": "<b>Mispar</b> - Mispereth, Numbering; Showing; Increase Of Tribute",
    "Misrephoth-Maim": "<b>Misrephoth-Maim</b> - Hot Waters",
    "Mithcah": "<b>Mithcah</b> - Sweetness; Pleasantness",
    "Mithnite": "<b>Mithnite</b> - Loin; Gift; Hope",
    "Mithredath": "<b>Mithredath</b> - Breaking The Law",
    "Mitylene": "<b>Mitylene</b> - Purity; Cleansing; Press",
    "Mizar": "<b>Mizar</b> - Little",
    "Mizpah": "<b>Mizpah</b> - Mizpeh, A Watch-Tower; Speculation",
    "Mizraim": "<b>Mizraim</b> - Tribulations",
    "Mizzah": "<b>Mizzah</b> - Defluxion From The Head",
    "Mnason": "<b>Mnason</b> - A Diligent Seeker; An Exhorter",
    "Moab": "<b>Moab</b> - Of His Father",
    "Moladah": "<b>Moladah</b> - Birth; Generation",
    "Molech": "<b>Molech</b> - Moloch, King",
    "Molid": "<b>Molid</b> - Nativity; Generation",
    "Mordecai": "<b>Mordecai</b> - Contrition; Bitter; Bruising",
    "Moreh": "<b>Moreh</b> - Stretching",
    "Moriah": "<b>Moriah</b> - Bitterness Of The Lord",
    "Moserah": "<b>Moserah</b> - Moseroth, Erudition; Discipline",
    "Moses": "<b>Moses</b> - Taken Out; Drawn Forth",
    "Mozah": "<b>Mozah</b> - Unleavened",
    "Muppim": "<b>Muppim</b> - Out Of The Mouth; Covering",
    "Mushi": "<b>Mushi</b> - He That Touches, That Withdraws Or Takes Away",
    "Myra": "<b>Myra</b> - I Flow; Pour Out; Weep",
    "Mysia": "<b>Mysia</b> - Criminal; Abominable",
    "Naam": "<b>Naam</b> - Fair; Pleasant",
    "Naamah": "<b>Naamah</b> - Naaman, Beautiful; Agreeable",
    "Naarah": "<b>Naarah</b> - Naarai, Young Person",
    "Naashon": "<b>Naashon</b> - That Foretells; That Conjectures",
    "Nabal": "<b>Nabal</b> - Fool; Senseless",
    "Naboth": "<b>Naboth</b> - Words; Prophecies",
    "Nachon": "<b>Nachon</b> - Ready; Sure",
    "Nachor": "<b>Nachor</b> - Same As Nahor",
    "Nadab": "<b>Nadab</b> - Free And Voluntary Gift; Prince",
    "Nagge": "<b>Nagge</b> - Clearness; Brightness; Light",
    "Nahaliel": "<b>Nahaliel</b> - Inheritance; Valley Of God",
    "Nahallal": "<b>Nahallal</b> - Praised; Bright",
    "Naham": "<b>Naham</b> - Nahamani, Comforter; Leader",
    "Naharai": "<b>Naharai</b> - My Nostrils; Hot; Anger",
    "Nahash": "<b>Nahash</b> - Snake; Serpent",
    "Nahath": "<b>Nahath</b> - Rest; A Leader",
    "Nahbi": "<b>Nahbi</b> - Very Secret",
    "Nahor": "<b>Nahor</b> - Hoarse; Dry; Hot",
    "Nahshon": "<b>Nahshon</b> - Same As Naashon",
    "Nahum": "<b>Nahum</b> - Comforter; Penitent",
    "Nain": "<b>Nain</b> - Beauty; Pleasantness",
    "Naioth": "<b>Naioth</b> - Beauties; Habitations",
    "Naomi": "<b>Naomi</b> - Beautiful; Agreeable",
    "Naphish": "<b>Naphish</b> - The Soul; He That Rests, Refreshes Himself, Or Respires",
    "Naphtali": "<b>Naphtali</b> - That Struggles Or Fights",
    "Narcissus": "<b>Narcissus</b> - Astonishment; Stupidity",
    "Nason": "<b>Nason</b> - Helper; Entry-Way",
    "Nathan": "<b>Nathan</b> - Given; Giving; Rewarded",
    "Nathan-Melech": "<b>Nathan-Melech</b> - The Gift Of The King, Or Of Counsel",
    "Nathanael": "<b>Nathanael</b> - The Gift Of God",
    "Naum": "<b>Naum</b> - Same As Nahum",
    "Nazareth": "<b>Nazareth</b> - Separated; Crowned; Sanctified",
    "Nazarite": "<b>Nazarite</b> - One Chosen Or Set Apart",
    "Neah": "<b>Neah</b> - Moved; Moving",
    "Neapolis": "<b>Neapolis</b> - The New City",
    "Neariah": "<b>Neariah</b> - Child Of The Lord",
    "Nebai": "<b>Nebai</b> - Budding; Speaking; Prophesying",
    "Nebaioth": "<b>Nebaioth</b> - Words; Prophecies; Buds",
    "Neballat": "<b>Neballat</b> - Prophecy; Budding",
    "Nebat": "<b>Nebat</b> - That Beholds",
    "Nebo": "<b>Nebo</b> - That Speaks Or Prophesies",
    "Nebuchadnezzar": "<b>Nebuchadnezzar</b> - Nebuchadrezzar, Tears And Groans Of Judgment",
    "Nebushasi_Hahban": "<b>Nebushasi_Hahban</b> - Speech; Prophecy; Springing; Flowing",
    "Nebuzar-Adan": "<b>Nebuzar-Adan</b> - Fruits Or Prophecies Of Judgment",
    "Necho": "<b>Necho</b> - Lame; Beaten",
    "Nedabiah": "<b>Nedabiah</b> - Prince Or Vow Of The Lord",
    "Neginoth": "<b>Neginoth</b> - Stringed Instruments",
    "Nehelamite": "<b>Nehelamite</b> - Dreamer; Vale; Brook",
    "Nehemiah": "<b>Nehemiah</b> - Consolation; Repentance Of The Lord",
    "Nehum": "<b>Nehum</b> - Comforter; Penitent",
    "Nehushta": "<b>Nehushta</b> - Made Of Brass",
    "Nehushtan": "<b>Nehushtan</b> - A Trifling Thing Of Brass",
    "Neiel": "<b>Neiel</b> - Commotion, Or Moving, Of God",
    "Nekoda": "<b>Nekoda</b> - Painted; Inconstant",
    "Nemuel": "<b>Nemuel</b> - The Sleeping Of God",
    "Nepheg": "<b>Nepheg</b> - Weak; Slacked",
    "Nephish": "<b>Nephish</b> - Same As Naphish",
    "Nephishesim": "<b>Nephishesim</b> - Diminished; Torn In Pieces",
    "Nephthalim": "<b>Nephthalim</b> - Same As Naphtali",
    "Nephthoah": "<b>Nephthoah</b> - Opening; Open",
    "Nephusim": "<b>Nephusim</b> - Same As Nephishesim",
    "Ner": "<b>Ner</b> - A Lamp; New-Tilled Land",
    "Nereus": "<b>Nereus</b> - Same As Ner",
    "Nergal": "<b>Nergal</b> - The Great Man; The Hero",
    "Nergal-Sharezer": "<b>Nergal-Sharezer</b> - Treasurer Of Nergal",
    "Neri": "<b>Neri</b> - My Light",
    "Neriah": "<b>Neriah</b> - Light; Lamp Of The Lord",
    "Nethaneel": "<b>Nethaneel</b> - Same As Nathanael",
    "Nethaniah": "<b>Nethaniah</b> - The Gift Of The Lord",
    "Nethinims": "<b>Nethinims</b> - Given Or Offered",
    "Neziah": "<b>Neziah</b> - Conqueror; Strong",
    "Nezib": "<b>Nezib</b> - Standing-Place",
    "Nibhaz": "<b>Nibhaz</b> - Budding; Prophesying",
    "Nibshan": "<b>Nibshan</b> - Prophecy; Growing Of A Tooth",
    "Nicanor": "<b>Nicanor</b> - A Conqueror; Victorious",
    "Nicodemus": "<b>Nicodemus</b> - Victory Of The People",
    "Nicolaitanes": "<b>Nicolaitanes</b> - Followers Of Nicolas",
    "Nicolas": "<b>Nicolas</b> - Same As Nicodemus",
    "Nicopolis": "<b>Nicopolis</b> - The City Of Victory",
    "Niger": "<b>Niger</b> - Black",
    "Nimrah": "<b>Nimrah</b> - Nimrim, Leopard; Bitterness; Rebellion",
    "Nimrod": "<b>Nimrod</b> - Rebellion (But Probably An Unknown Assyrian Word)",
    "Nimshi": "<b>Nimshi</b> - Rescued From Danger",
    "Nineveh": "<b>Nineveh</b> - Handsome; Agreeable",
    "Nisan": "<b>Nisan</b> - Standard; Miracle",
    "Nisroch": "<b>Nisroch</b> - Flight; Proof; Temptation; Delicate",
    "No": "<b>No</b> - Stirring Up; Forbidding",
    "Noadiah": "<b>Noadiah</b> - Witness, Or Ornament, Of The Lord",
    "Noah": "<b>Noah</b> - That Quavers Or Totters (Zelophehad'S Daughter)",
    "Noah": "<b>Noah</b> - Repose; Consolation",
    "Nob": "<b>Nob</b> - Discourse; Prophecy",
    "Nobah": "<b>Nobah</b> - That Barks Or Yelps",
    "Nod": "<b>Nod</b> - Vagabond; Fugitive",
    "Nodab": "<b>Nodab</b> - Vowing Of His Own Accord",
    "Noe": "<b>Noe</b> - Same As Noah",
    "Nogah": "<b>Nogah</b> - Brightness; Clearness",
    "Noha": "<b>Noha</b> - Rest; A Guide",
    "Non": "<b>Non</b> - Posterity; A Fish; Eternal",
    "Noph": "<b>Noph</b> - Honeycomb; Anything That Distills Or Drops",
    "Nophah": "<b>Nophah</b> - Fearful; Binding",
    "Nun": "<b>Nun</b> - Same As Non",
    "Nymphas": "<b>Nymphas</b> - Spouse; Bridegroom",
    "Obadiah": "<b>Obadiah</b> - Servant Of The Lord",
    "Obal": "<b>Obal</b> - Inconvenience Of Old Age",
    "Obed": "<b>Obed</b> - A Servant; Workman",
    "Obed-Edom": "<b>Obed-Edom</b> - Servant Of Edom",
    "Obil": "<b>Obil</b> - That Weeps; Who Deserves To Be Bewailed",
    "Oboth": "<b>Oboth</b> - Dragons; Fathers; Desires",
    "Ocran": "<b>Ocran</b> - A Disturber; That Disorders",
    "Oded": "<b>Oded</b> - To Sustain, Hold Or Lift Up",
    "Og": "<b>Og</b> - A Cake; Bread Baked In Ashes",
    "Ohad": "<b>Ohad</b> - Praising; Confessing",
    "Ohel": "<b>Ohel</b> - Tent; Tabernacle; Brightness",
    "Olympas": "<b>Olympas</b> - Heavenly",
    "Omar": "<b>Omar</b> - He That Speaks; Bitter",
    "Omega": "<b>Omega</b> - The Last Letter Of The Greek Alphabet; Long O",
    "Omri": "<b>Omri</b> - Sheaf Of Corn",
    "On": "<b>On</b> - Pain; Force; Iniquity",
    "Onam": "<b>Onam</b> - Onan, Same As On",
    "Onesimus": "<b>Onesimus</b> - Profitable; Useful",
    "Onesiphorus": "<b>Onesiphorus</b> - Who Brings Profit",
    "Ono": "<b>Ono</b> - Grief Or Strength Or Iniquity Of Him",
    "Ophel": "<b>Ophel</b> - A Tower; Darkness; Small White Cloud",
    "Ophir": "<b>Ophir</b> - Fruitful Region",
    "Ophni": "<b>Ophni</b> - Wearisomeness; Folding Together",
    "Ophrah": "<b>Ophrah</b> - Dust; Lead; A Fawn",
    "Oreb": "<b>Oreb</b> - A Raven",
    "Ornan": "<b>Ornan</b> - That Rejoices",
    "Orpah": "<b>Orpah</b> - The Neck Or Skull",
    "Oshea": "<b>Oshea</b> - Same As Joshua",
    "Othni": "<b>Othni</b> - My Time; My Hour",
    "Othniel": "<b>Othniel</b> - The Hour Of God",
    "Ozem": "<b>Ozem</b> - That Fasts; Their Eagerness",
    "Ozias": "<b>Ozias</b> - Strength From The Lord",
    "Ozni": "<b>Ozni</b> - An Ear; My Hearkening",
    "Paarai": "<b>Paarai</b> - Opening",
    "Padan-Aram": "<b>Padan-Aram</b> - Cultivated Field Or Table-Land",
    "Padon": "<b>Padon</b> - His Redemption; Ox-Yoke",
    "Pagiel": "<b>Pagiel</b> - Prevention, Or Prayer, Of God",
    "Pahath-Moab": "<b>Pahath-Moab</b> - Ruler Of Moab",
    "Pai": "<b>Pai</b> - Pau, Howling; Sighing",
    "Palal": "<b>Palal</b> - Thinking",
    "Palestina": "<b>Palestina</b> - Which Is Covered; Watered; Or Brings And Causes Ruin",
    "Pallu": "<b>Pallu</b> - Marvelous; Hidden",
    "Palti": "<b>Palti</b> - Deliverance; Flight",
    "Paltiel": "<b>Paltiel</b> - Deliverance; Or Banishment, Of God",
    "Pamphylia": "<b>Pamphylia</b> - A Nation Made Up Of Every Tribe",
    "Paphos": "<b>Paphos</b> - Which Boils, Or Is Very Hot",
    "Parah": "<b>Parah</b> - A Cow; Increasing",
    "Paran": "<b>Paran</b> - Beauty; Glory; Ornament",
    "Parbar": "<b>Parbar</b> - A Suburb",
    "Parmashta": "<b>Parmashta</b> - A Yearling Bull",
    "Parmenas": "<b>Parmenas</b> - That Abides, Or Is Permanent",
    "Parnach": "<b>Parnach</b> - A Bull Striking, Or Struck",
    "Parosh": "<b>Parosh</b> - A Flea; The Fruit Of A Moth",
    "Parshandatha": "<b>Parshandatha</b> - Given By Prayer",
    "Paruah": "<b>Paruah</b> - Flourishing; That Flies Away",
    "Pasach": "<b>Pasach</b> - Thy Broken Piece",
    "Pasdammin": "<b>Pasdammin</b> - Portion Or Diminishing Of Blood",
    "Paseah": "<b>Paseah</b> - Passing Over; Halting",
    "Pashur": "<b>Pashur</b> - That Extends Or Multiplies The Hole; Whiteness",
    "Patara": "<b>Patara</b> - Trodden Under Foot",
    "Pathros": "<b>Pathros</b> - Pathrusim, Mouthful Of Dough; Persuasion Of Ruin",
    "Patmos": "<b>Patmos</b> - Mortal",
    "Patrobas": "<b>Patrobas</b> - Paternal; That Pursues The Steps Of His Father",
    "Pau": "<b>Pau</b> - Same As Pai",
    "Paul": "<b>Paul</b> - Small; Little",
    "Paulus": "<b>Paulus</b> - Same As Paul",
    "Pedahzur": "<b>Pedahzur</b> - Strong Or Powerful Savior; Stone Of Redemption",
    "Pedaiah": "<b>Pedaiah</b> - Redemption Of The Lord",
    "Pekah": "<b>Pekah</b> - He That Opens; That Is At Liberty",
    "Pekahiah": "<b>Pekahiah</b> - It Is The Lord That Opens",
    "Pekod": "<b>Pekod</b> - Noble; Rulers",
    "Pelaiah": "<b>Pelaiah</b> - The Lord'S Secret Or Miracle",
    "Pelaliah": "<b>Pelaliah</b> - Entreating The Lord",
    "Pelatiah": "<b>Pelatiah</b> - Let The Lord Deliver; Deliverance Of The Lord",
    "Peleg": "<b>Peleg</b> - Division",
    "Pelethites": "<b>Pelethites</b> - Judges; Destroyers",
    "Pelonite": "<b>Pelonite</b> - Falling; Secret",
    "Peniel": "<b>Peniel</b> - Face Or Vision Of God; That Sees God",
    "Peninnah": "<b>Peninnah</b> - Pearl; Precious Stone; The Face",
    "Pentapolis": "<b>Pentapolis</b> - Five Cities",
    "Pentateuch": "<b>Pentateuch</b> - The Five Books Of Moses",
    "Pentecost": "<b>Pentecost</b> - Fiftieth",
    "Penuel": "<b>Penuel</b> - Same As Peniel",
    "Peor": "<b>Peor</b> - Hole; Opening",
    "Perazim": "<b>Perazim</b> - Divisions",
    "Peresh": "<b>Peresh</b> - Horseman",
    "Perez": "<b>Perez</b> - Divided",
    "Perez-Uzza": "<b>Perez-Uzza</b> - Division Of Uzza, Or Of Strength",
    "Perga": "<b>Perga</b> - Very Earthy",
    "Pergamos": "<b>Pergamos</b> - Height; Elevation",
    "Perida": "<b>Perida</b> - Separation; Division",
    "Perizzites": "<b>Perizzites</b> - Dwelling In Villages",
    "Persia": "<b>Persia</b> - That Cuts Or Divides; A Nail; A Gryphon; A Horseman",
    "Persis": "<b>Persis</b> - Same As Persia",
    "Peruda": "<b>Peruda</b> - Same As Perida",
    "Peter": "<b>Peter</b> - A Rock Or Stone",
    "Pethahiah": "<b>Pethahiah</b> - The Lord Opening; Gate Of The Lord",
    "Pethuel": "<b>Pethuel</b> - Mouth Of God; Persuasion Of God",
    "Peulthai": "<b>Peulthai</b> - My Works",
    "Phalec": "<b>Phalec</b> - Same As Peleg",
    "Phallu": "<b>Phallu</b> - Pallu, Admirable; Hidden",
    "Phalti Palti": "<b>Phalti Palti</b> - Deliverance, Flight",
    "Phanuel": "<b>Phanuel</b> - Face Or Vision Of God",
    "Pharaoh": "<b>Pharaoh</b> - That Disperses; That Spoils",
    "Pharez": "<b>Pharez</b> - Division; Rupture",
    "Pharisees": "<b>Pharisees</b> - Set Apart",
    "Pharpar": "<b>Pharpar</b> - That Produces Fruit",
    "Phebe": "<b>Phebe</b> - Shining; Pure",
    "Phenice": "<b>Phenice</b> - Phoenicia, Red; Purple",
    "Phichol": "<b>Phichol</b> - The Mouth Of All, Or Every Tongue",
    "Philadelphia": "<b>Philadelphia</b> - Love Of A Brother",
    "Philemon": "<b>Philemon</b> - Who Kisses",
    "Philetus": "<b>Philetus</b> - Amiable; Beloved",
    "Philip": "<b>Philip</b> - Warlike; A Lover Of Horses",
    "Philippi": "<b>Philippi</b> - Same As Philip, In The Plural",
    "Philistines": "<b>Philistines</b> - Those Who Dwell In Villages",
    "Philologus": "<b>Philologus</b> - A Lover Of Letters, Or Of The Word",
    "Phinehas": "<b>Phinehas</b> - Bold Aspect; Face Of Trust Or Protection",
    "Phlegon": "<b>Phlegon</b> - Zealous; Burning",
    "Phrygia": "<b>Phrygia</b> - Dry; Barren",
    "Phurah": "<b>Phurah</b> - That Bears Fruit, Or Grows",
    "Phygellus": "<b>Phygellus</b> - Fugitive",
    "Phylacteries": "<b>Phylacteries</b> - Things To Be Especially Observed",
    "Pi-Beseth": "<b>Pi-Beseth</b> - Abode Of The Goddess Bahest Or Bast",
    "Pi-Hahiroth": "<b>Pi-Hahiroth</b> - The Mouth; The Pass Of Hiroth",
    "Pilate": "<b>Pilate</b> - Armed With A Dart",
    "Pinon": "<b>Pinon</b> - Pearl; Gem; That Beholds",
    "Piram": "<b>Piram</b> - A Wild Ass Of Them",
    "Pirathon": "<b>Pirathon</b> - His Dissipation Or Deprivation; His Rupture",
    "Pisgah": "<b>Pisgah</b> - Hill; Eminence; Fortress",
    "Pisidia": "<b>Pisidia</b> - Pitch; Pitchy",
    "Pison": "<b>Pison</b> - Changing; Extension Of The Mouth",
    "Pithom": "<b>Pithom</b> - Their Mouthful; A Dilatation Of The Mouth",
    "Pithon": "<b>Pithon</b> - Mouthful; Persuasion",
    "Pochereth": "<b>Pochereth</b> - Cutting Of The Mouth Of Warfare",
    "Pontius": "<b>Pontius</b> - Marine; Belonging To The Sea",
    "Pontus": "<b>Pontus</b> - The Sea",
    "Poratha": "<b>Poratha</b> - Fruitful",
    "Potiphar": "<b>Potiphar</b> - Bull Of Africa; A Fat Bull",
    "Potipherah": "<b>Potipherah</b> - That Scatters Abroad, Or Demolishes, The Fat",
    "Prisca": "<b>Prisca</b> - Ancient",
    "Priscilla": "<b>Priscilla</b> - Same As Prisca",
    "Prochorus": "<b>Prochorus</b> - He That Presides Over The Choirs",
    "Puah": "<b>Puah</b> - Mouth; Corner; Bush Of Hair",
    "Publius": "<b>Publius</b> - Common",
    "Pudens": "<b>Pudens</b> - Shamefaced",
    "Pul": "<b>Pul</b> - Bean; Destruction",
    "Punites": "<b>Punites</b> - Beholding; My Face",
    "Punon": "<b>Punon</b> - Precious Stone; That Beholds",
    "Pur": "<b>Pur</b> - Purim, Lot",
    "Puteoli": "<b>Puteoli</b> - Sulphureous Wells",
    "Putiel": "<b>Putiel</b> - God Is My Fatness",
    "Quartus": "<b>Quartus</b> - Fourth",
    "Raamah": "<b>Raamah</b> - Greatness; Thunder; Some Sort Of Evil",
    "Raamiah": "<b>Raamiah</b> - Thunder, Or Evil, From The Lord",
    "Rab-Saris": "<b>Rab-Saris</b> - Chief Of The Eunuchs",
    "Rab-Shakeh": "<b>Rab-Shakeh</b> - Cup-Bearer Of The Prince",
    "Rabbah": "<b>Rabbah</b> - Great; Powerful; Contentious",
    "Rabbi": "<b>Rabbi</b> - Rabboni, My Master",
    "Rabmag": "<b>Rabmag</b> - Who Overthrows Or Destroys A Multitude",
    "Raca": "<b>Raca</b> - Worthless; Good-For-Nothing",
    "Rachab": "<b>Rachab</b> - Same As Rahab",
    "Rachal": "<b>Rachal</b> - To Whisper; An Embalmer",
    "Rachel": "<b>Rachel</b> - Sheep",
    "Raddai": "<b>Raddai</b> - Ruling; Coming Down",
    "Ragau": "<b>Ragau</b> - Friend; Shepherd",
    "Raguel": "<b>Raguel</b> - Shepherd, Or Friend Of God",
    "Rahab": "<b>Rahab</b> - Proud; Quarrelsome (Applied To Egypt)",
    "Rahab": "<b>Rahab</b> - Large; Extended (Name Of A Woman)",
    "Raham": "<b>Raham</b> - Compassion; A Friend",
    "Rakkath": "<b>Rakkath</b> - Empty; Temple Of The Head",
    "Rakkon": "<b>Rakkon</b> - Vain; Void; Mountain Of Enjoyment",
    "Ram": "<b>Ram</b> - Elevated; Sublime",
    "Ramah": "<b>Ramah</b> - Same As Ram",
    "Ramath": "<b>Ramath</b> - Ramatha, Raised; Lofty",
    "Ramath-Lehi": "<b>Ramath-Lehi</b> - Elevation Of The Jaw-Bone",
    "Ramath-Mizpeh": "<b>Ramath-Mizpeh</b> - Elevation Of The Watch-Tower",
    "Ramathaim-Zophim": "<b>Ramathaim-Zophim</b> - The Two Watch-Towers",
    "Ramiah": "<b>Ramiah</b> - Exaltation Of The Lord",
    "Ramoth": "<b>Ramoth</b> - Eminences; High Places",
    "Raphah": "<b>Raphah</b> - Raphu, Relaxation; Physic; Comfort",
    "Reaiah": "<b>Reaiah</b> - Vision Of The Lord",
    "Reba": "<b>Reba</b> - The Fourth; A Square; That Lies Or Stoops Down",
    "Rebekah": "<b>Rebekah</b> - Fat; Fattened; A Quarrel Appeased",
    "Rechab": "<b>Rechab</b> - Square; Chariot With Team Of Four Horses",
    "Reelaiah": "<b>Reelaiah</b> - Shepherd Or Companion To The Lord",
    "Regem": "<b>Regem</b> - That Stones Or Is Stoned; Purple",
    "Regemmelech": "<b>Regemmelech</b> - He That Stones The King; Purple Of The King",
    "Rehabiah": "<b>Rehabiah</b> - Breadth, Or Extent, Of The Lord",
    "Rehob": "<b>Rehob</b> - Breadth; Space; Extent",
    "Rehoboam": "<b>Rehoboam</b> - Who Sets The People At Liberty",
    "Rehoboth": "<b>Rehoboth</b> - Spaces; Places",
    "Rehpaim": "<b>Rehpaim</b> - Giants; Physicians; Relaxed",
    "Rehum": "<b>Rehum</b> - Merciful; Compassionate",
    "Rei": "<b>Rei</b> - My Shepherd; My Companion; My Friend",
    "Rekem": "<b>Rekem</b> - Vain Pictures; Divers Picture",
    "Remaliah": "<b>Remaliah</b> - The Exaltation Of The Lord",
    "Remmon": "<b>Remmon</b> - Greatness; Elevation; A Pomegranate-Tree",
    "Remphan": "<b>Remphan</b> - Prepared; Arrayed",
    "Rephael": "<b>Rephael</b> - The Physic Or Medicine Of God",
    "Rephaiah": "<b>Rephaiah</b> - Medicine Or Refreshment Of The Lord",
    "Rephidim": "<b>Rephidim</b> - Beds; Places Of Rest",
    "Resen": "<b>Resen</b> - A Bridle Or Bit",
    "Reu": "<b>Reu</b> - His Friend; His Shepherd",
    "Reuben": "<b>Reuben</b> - Who Sees The Son; The Vision Of The Son",
    "Reuel": "<b>Reuel</b> - The Shepherd Or Friend Of God",
    "Reumah": "<b>Reumah</b> - Lofty; Sublime",
    "Rezeph": "<b>Rezeph</b> - Pavement; Burning Coal",
    "Rezin": "<b>Rezin</b> - Good-Will; Messenger",
    "Rezon": "<b>Rezon</b> - Lean; Small; Secret; Prince",
    "Rhegium": "<b>Rhegium</b> - Rupture; Fracture",
    "Rhesa": "<b>Rhesa</b> - Will; Course",
    "Rhoda": "<b>Rhoda</b> - A Rose",
    "Rhodes": "<b>Rhodes</b> - Same As Rhoda",
    "Ribai": "<b>Ribai</b> - Strife",
    "Riblah": "<b>Riblah</b> - Quarrel; Greatness To Him",
    "Rimmon": "<b>Rimmon</b> - Exalted; Pomegranate",
    "Rinnah": "<b>Rinnah</b> - Song; Rejoicing",
    "Riphath": "<b>Riphath</b> - Remedy; Medicine; Release; Pardon",
    "Rissah": "<b>Rissah</b> - Watering; Distillation; Dew",
    "Rithmah": "<b>Rithmah</b> - Juniper; Noise",
    "Rizpah": "<b>Rizpah</b> - Bed; Extension; A Coal",
    "Rogelim": "<b>Rogelim</b> - A Foot Or Footman",
    "Rohgah": "<b>Rohgah</b> - Filled Or Drunk With Talk",
    "Romamti-Ezer": "<b>Romamti-Ezer</b> - Exaltation Of Help",
    "Roman": "<b>Roman</b> - Strong; Powerful",
    "Rome": "<b>Rome</b> - Strength; Power",
    "Rosh": "<b>Rosh</b> - The Head; Top, Or Beginning",
    "Rufus": "<b>Rufus</b> - Red",
    "Ruhamah": "<b>Ruhamah</b> - Having Obtained Mercy",
    "Rumah": "<b>Rumah</b> - Exalted; Sublime; Rejected",
    "Ruth": "<b>Ruth</b> - Drunk; Satisfied",
    "Sabaoth": "<b>Sabaoth</b> - Lord Of Hosts",
    "Sabeans": "<b>Sabeans</b> - Captivity; Conversion; Old Age",
    "Sabtah": "<b>Sabtah</b> - A Going About Or Circuiting; Old Age",
    "Sabtechah": "<b>Sabtechah</b> - That Surrounds; That Causes Wounding",
    "Sacar": "<b>Sacar</b> - Wares; A Price",
    "Sadducees": "<b>Sadducees</b> - Followers Of Sadoc, Or Zadok",
    "Sadoc": "<b>Sadoc</b> - Or Zadok, Just; Righteous",
    "Salah": "<b>Salah</b> - Mission; Sending",
    "Salamis": "<b>Salamis</b> - Shaken; Test; Beaten",
    "Salathiel": "<b>Salathiel</b> - Asked Or Lent Of God",
    "Salcah": "<b>Salcah</b> - Thy Basket; Thy Lifting Up",
    "Salem": "<b>Salem</b> - Complete Or Perfect Peace",
    "Salim": "<b>Salim</b> - Foxes; Fists; Path",
    "Sallai": "<b>Sallai</b> - Sallu, An Exaltation; A Basket",
    "Salma": "<b>Salma</b> - Peace; Perfection",
    "Salmon": "<b>Salmon</b> - Peaceable; Perfect; He That Rewards",
    "Salome": "<b>Salome</b> - Same As Salmon",
    "Samaria": "<b>Samaria</b> - Watch-Mountain",
    "Samlah": "<b>Samlah</b> - His Raiment; His Left Hand; His Astonishment",
    "Samos": "<b>Samos</b> - Full Of Gravel",
    "Samothracia": "<b>Samothracia</b> - An Island Possessed By The Samians And Thracians",
    "Samson": "<b>Samson</b> - His Sun; His Service; There The Second Time",
    "Samuel": "<b>Samuel</b> - Heard Of God; Asked Of God",
    "Sanballat": "<b>Sanballat</b> - Bramble-Bush; Enemy In Secret",
    "Sanhedrin": "<b>Sanhedrin</b> - Sitting Together",
    "Sansannah": "<b>Sansannah</b> - Bough Or Bramble Of The Enemy",
    "Saph": "<b>Saph</b> - Rushes; Sea-Moss",
    "Saphir": "<b>Saphir</b> - Delightful",
    "Sapphira": "<b>Sapphira</b> - That Relates Or Tells",
    "Sarah": "<b>Sarah</b> - Lady; Princess; Princess Of The Multitude",
    "Sarai": "<b>Sarai</b> - My Lady; My Princess",
    "Sardis": "<b>Sardis</b> - Prince Of Joy",
    "Sardites": "<b>Sardites</b> - Removing A Dissension",
    "Sarepta": "<b>Sarepta</b> - A Goldsmith'S Shop",
    "Sargon": "<b>Sargon</b> - Who Takes Away Protection",
    "Sarid": "<b>Sarid</b> - Remaining; Hand Of A Prince",
    "Saron": "<b>Saron</b> - Same As Sharon",
    "Sarsechim": "<b>Sarsechim</b> - Master Of The Wardrobe",
    "Saruch": "<b>Saruch</b> - Branch; Layer; Lining",
    "Satan": "<b>Satan</b> - Contrary; Adversary; Enemy; Accuser",
    "Saul": "<b>Saul</b> - Demanded; Lent; Ditch; Death",
    "Sceva": "<b>Sceva</b> - Disposed; Prepared",
    "Schaaph": "<b>Schaaph</b> - Fleeing; Thinking",
    "Seba": "<b>Seba</b> - A Drunkard; That Turns",
    "Sebat": "<b>Sebat</b> - Twig; Scepter; Tribe",
    "Secacah": "<b>Secacah</b> - Shadow; Covering; Defense",
    "Sechu": "<b>Sechu</b> - Defense; Bough",
    "Secundus": "<b>Secundus</b> - Second",
    "Segub": "<b>Segub</b> - Fortified; Raised",
    "Seir": "<b>Seir</b> - Seirath, Hairy; Goat; Demon; Tempest",
    "Sela": "<b>Sela</b> - A Rock",
    "Sela-Hammah-Lekoth": "<b>Sela-Hammah-Lekoth</b> - Rock Of Divisions",
    "Selah": "<b>Selah</b> - The End; A Pause",
    "Seled": "<b>Seled</b> - Affliction; Warning",
    "Seleucia": "<b>Seleucia</b> - Shaken Or Beaten By The Waves",
    "Sem": "<b>Sem</b> - Same As Shem",
    "Semachiah": "<b>Semachiah</b> - Joined To The Lord",
    "Semaiah": "<b>Semaiah</b> - Obeying The Lord",
    "Semei": "<b>Semei</b> - Hearing; Obeying",
    "Senaah": "<b>Senaah</b> - Bramble; Enemy",
    "Seneh": "<b>Seneh</b> - Same As Senaah",
    "Senir": "<b>Senir</b> - Bed-Candle; Changing",
    "Sennacherib": "<b>Sennacherib</b> - Bramble Of Destruction",
    "Seorim": "<b>Seorim</b> - Gates; Hairs; Tempests",
    "Sephar": "<b>Sephar</b> - Book; Scribe; Number",
    "Sepharad": "<b>Sepharad</b> - A Book Descending",
    "Sepharvaim": "<b>Sepharvaim</b> - The Two Books; The Two Scribes",
    "Serah": "<b>Serah</b> - Lady Of Scent; Song; The Morning Star",
    "Seraiah": "<b>Seraiah</b> - Prince Of The Lord",
    "Seraphim": "<b>Seraphim</b> - Burning; Fiery",
    "Sered": "<b>Sered</b> - Dyer'S Vat",
    "Sergius": "<b>Sergius</b> - Net",
    "Serug": "<b>Serug</b> - Branch; Layer; Twining",
    "Seth": "<b>Seth</b> - Put; Who Puts; Fixed",
    "Sethur": "<b>Sethur</b> - Hid; Destroying",
    "Shaalabbim": "<b>Shaalabbim</b> - Understanding, Or Son Of A Fox",
    "Shaalbim": "<b>Shaalbim</b> - That Beholds The Heart",
    "Shaalbonite": "<b>Shaalbonite</b> - A Fox'S Building",
    "Shaaraim": "<b>Shaaraim</b> - Gates; Valuation; Hairs",
    "Shaashgaz": "<b>Shaashgaz</b> - He That Presses The Fleece; That Shears The Sheep",
    "Shabbethai": "<b>Shabbethai</b> - My Rest",
    "Shachia": "<b>Shachia</b> - Protection Of The Lord",
    "Shadrach": "<b>Shadrach</b> - Tender, Nipple",
    "Shage": "<b>Shage</b> - Touching Softly; Multiplying Much",
    "Shalem": "<b>Shalem</b> - Same As Salem",
    "Shalim": "<b>Shalim</b> - Same As Salim",
    "Shalisha": "<b>Shalisha</b> - Three; The Third; Prince; Captain",
    "Shallum": "<b>Shallum</b> - Perfect; Agreeable",
    "Shalmai": "<b>Shalmai</b> - My Garment",
    "Shalman": "<b>Shalman</b> - Peaceable; Perfect; That Rewards",
    "Shalmaneser": "<b>Shalmaneser</b> - Peace; Tied; Chained; Perfection; Retribution",
    "Shamariah": "<b>Shamariah</b> - Throne Or Keeping Of The Lord",
    "Shamed": "<b>Shamed</b> - Destroying; Wearing Out",
    "Shamer": "<b>Shamer</b> - Keeper; Thorn; Dregs",
    "Shamgar": "<b>Shamgar</b> - Named A Stranger; He Is Here A Stranger",
    "Shamhuth": "<b>Shamhuth</b> - Desolation; Destruction",
    "Shamir": "<b>Shamir</b> - Shamer, Prison; Bush; Lees; Thorn",
    "Shammah": "<b>Shammah</b> - Loss; Desolation; Astonishment",
    "Shammai": "<b>Shammai</b> - My Name; My Desolations",
    "Shammoth": "<b>Shammoth</b> - Names; Desolations",
    "Shammuah": "<b>Shammuah</b> - He That Is Heard; He That Is Obeyed",
    "Shamsherai": "<b>Shamsherai</b> - There A Singer Or Conqueror",
    "Shapham": "<b>Shapham</b> - Shaphan, Rabbit; Wild Rat; Their Lip; Their Brink",
    "Shaphat": "<b>Shaphat</b> - Judge",
    "Sharai": "<b>Sharai</b> - My Lord; My Prince; My Song",
    "Sharar": "<b>Sharar</b> - Navel; Thought; Singing",
    "Sharezer": "<b>Sharezer</b> - Overseer Of The Treasury, Or Of The Storehouse",
    "Sharon": "<b>Sharon</b> - His Plain; His Song",
    "Shashai": "<b>Shashai</b> - Rejoicing; Mercy; Linen",
    "Shashak": "<b>Shashak</b> - A Bag Of Linen; The Sixth Bag",
    "Shaul": "<b>Shaul</b> - Saul, Asked; Lent; A Grave",
    "Shaveh": "<b>Shaveh</b> - The Plain; That Makes Equality",
    "Shealtiel": "<b>Shealtiel</b> - Same As Salathiel",
    "Shear-Jashub": "<b>Shear-Jashub</b> - The Remnant Shall Return",
    "Sheariah": "<b>Sheariah</b> - Gate Of The Lord; Tempest Of The Lord",
    "Sheba": "<b>Sheba</b> - Captivity; Old Man; Repose; Oath",
    "Shebam": "<b>Shebam</b> - Compassing About; Old Men",
    "Shebaniah": "<b>Shebaniah</b> - The Lord That Converts, Or Recalls From Captivity",
    "Shebarim": "<b>Shebarim</b> - Breakings; Hopes",
    "Sheber": "<b>Sheber</b> - Breaking; Hope",
    "Shebna": "<b>Shebna</b> - Who Rests Himself; Who Is Now Captive",
    "Shebuel": "<b>Shebuel</b> - Turning, Or Captivity, Or Seat, Of God",
    "Shecaniah": "<b>Shecaniah</b> - Habitation Of The Lord",
    "Shechem": "<b>Shechem</b> - Part; Portion; Back Early In The Morning",
    "Shedeur": "<b>Shedeur</b> - Field Of Light; Light Of The Almighty",
    "Shehariah": "<b>Shehariah</b> - Mourning Or Blackness Of The Lord",
    "Shelah": "<b>Shelah</b> - That Breaks; That Unties; That Undresses",
    "Shelemiah": "<b>Shelemiah</b> - God Is My Perfection; My Happiness; My Peace",
    "Sheleph": "<b>Sheleph</b> - Who Draws Out",
    "Shelesh": "<b>Shelesh</b> - Captain; Prince",
    "Shelomi": "<b>Shelomi</b> - Shelomith, My Peace; My Happiness; My Recompense",
    "Shelumiel": "<b>Shelumiel</b> - Same As Shelemiah",
    "Shem": "<b>Shem</b> - Name; Renown",
    "Shema": "<b>Shema</b> - Hearing; Obeying",
    "Shemaiah": "<b>Shemaiah</b> - That Hears Or Obeys The Lord",
    "Shemariah": "<b>Shemariah</b> - God Is My Guard",
    "Shemeber": "<b>Shemeber</b> - Name Of Force; Name Of The Strong",
    "Shemer": "<b>Shemer</b> - Guardian; Thorn",
    "Shemida": "<b>Shemida</b> - Name Of Knowledge; That Puts Knowledge",
    "Sheminith": "<b>Sheminith</b> - Eighth (An Eight-Stringed Instrument)",
    "Shemiramoth": "<b>Shemiramoth</b> - The Height Of The Heavens",
    "Shemuel": "<b>Shemuel</b> - Appointed By God",
    "Shen": "<b>Shen</b> - Tooth; Ivory; Change",
    "Shenazar": "<b>Shenazar</b> - Treasurer Of A Tooth",
    "Shenir": "<b>Shenir</b> - Lantern; Light That Sleeps",
    "Shephatiah": "<b>Shephatiah</b> - The Lord That Judges",
    "Shephi": "<b>Shephi</b> - Beholder; Honeycomb; Garment",
    "Shepho": "<b>Shepho</b> - Desert",
    "Shephuphan": "<b>Shephuphan</b> - Serpent",
    "Sherah": "<b>Sherah</b> - Flesh; Relationship",
    "Sherebiah": "<b>Sherebiah</b> - Singing With The Lord",
    "Sheshach": "<b>Sheshach</b> - Bag Of Flax Or Linen",
    "Sheshai": "<b>Sheshai</b> - Six; Mercy; Flax",
    "Sheshan": "<b>Sheshan</b> - Lily; Rose; Joy; Flax",
    "Sheshbazzar": "<b>Sheshbazzar</b> - Joy In Tribulation; Joy Of The Vintage",
    "Shethar": "<b>Shethar</b> - Putrefied; Searching",
    "Shethar-Boznai": "<b>Shethar-Boznai</b> - That Makes To Rot; That Seeks Those Who Despise Me",
    "Sheva": "<b>Sheva</b> - Vanity; Elevation; Fame; Tumult",
    "Shibboleth": "<b>Shibboleth</b> - Sibboleth, Ear Of Corn; Stream Or Flood",
    "Shibmah": "<b>Shibmah</b> - Overmuch Captivity, Or Sitting",
    "Shicron": "<b>Shicron</b> - Drunkenness; His Gift; His Wages",
    "Shiggaion": "<b>Shiggaion</b> - A Song Of Trouble Or Comfort",
    "Shihon": "<b>Shihon</b> - Sound; Wall Of Strength",
    "Shihor-Libnah": "<b>Shihor-Libnah</b> - Blackness Of Libnah",
    "Shilhi": "<b>Shilhi</b> - Shilhim, Bough; Weapon; Armor",
    "Shillem": "<b>Shillem</b> - Peace; Perfection; Retribution",
    "Shiloah": "<b>Shiloah</b> - Same As Siloah",
    "Shiloh": "<b>Shiloh</b> - Sent",
    "Shiloh (Name Of A City)": "<b>Shiloh (Name Of A City)</b> - Peace; Abundance",
    "Shilom": "<b>Shilom</b> - Tarrying; Peace-Maker",
    "Shilshah": "<b>Shilshah</b> - Three; Chief; Captain",
    "Shimeah": "<b>Shimeah</b> - Shimeath, That Hears, Or Obeys; Perdition",
    "Shimei": "<b>Shimei</b> - Shimi, That Hears Or Obeys; My Reputation; My Fame",
    "Shimeon": "<b>Shimeon</b> - Same As Simeon",
    "Shimma": "<b>Shimma</b> - Same As Shimeah",
    "Shimon": "<b>Shimon</b> - Providing Well; Fatness; Oil",
    "Shimrath": "<b>Shimrath</b> - Hearing; Obedient",
    "Shimri": "<b>Shimri</b> - Thorn; Dregs",
    "Shimrith": "<b>Shimrith</b> - Shimron, Same As Shimri",
    "Shimshai": "<b>Shimshai</b> - My Son",
    "Shinab": "<b>Shinab</b> - Father Of Changing",
    "Shinar": "<b>Shinar</b> - Watch Of Him That Sleeps",
    "Shiphi": "<b>Shiphi</b> - Multitude",
    "Shiphrah": "<b>Shiphrah</b> - Handsome; Trumpet; That Does Good",
    "Shisha": "<b>Shisha</b> - Of Marble; Pleasant",
    "Shishak": "<b>Shishak</b> - Present Of The Bag; Of The Pot; Of The Thigh",
    "Shitrai": "<b>Shitrai</b> - Gatherer Of Money",
    "Shittim": "<b>Shittim</b> - Thorns",
    "Shiza": "<b>Shiza</b> - This Gift",
    "Shoa": "<b>Shoa</b> - Kings; Tyrants",
    "Shobab": "<b>Shobab</b> - Returned; Turned Back; A Spark",
    "Shobach": "<b>Shobach</b> - Your Bonds; Your Chains",
    "Shobai": "<b>Shobai</b> - Turning Captivity",
    "Shobal": "<b>Shobal</b> - Path; Ear Of Corn",
    "Shobek": "<b>Shobek</b> - Made Void; Forsaken",
    "Shochoh": "<b>Shochoh</b> - Defense; A Bough",
    "Shoham": "<b>Shoham</b> - Keeping Back",
    "Shomer": "<b>Shomer</b> - Keeper; Dregs",
    "Shophach": "<b>Shophach</b> - Pouring Out",
    "Shophan": "<b>Shophan</b> - Rabbit; Hid",
    "Shoshannim": "<b>Shoshannim</b> - Those That Shall Be Changed",
    "Shua": "<b>Shua</b> - Crying; Saving",
    "Shuah": "<b>Shuah</b> - Ditch; Swimming; Humiliation",
    "Shual": "<b>Shual</b> - Fox; Path; First",
    "Shubael": "<b>Shubael</b> - Returning Captivity; Seat Of God",
    "Shuham": "<b>Shuham</b> - Talking; Thinking; Humiliation; Budding",
    "Shulamite": "<b>Shulamite</b> - Peaceable; Perfect; That Recompenses",
    "Shunem": "<b>Shunem</b> - Their Change; Their Sleep",
    "Shuni": "<b>Shuni</b> - Changed; Sleeping",
    "Shuphim": "<b>Shuphim</b> - Shuppim, Wearing Them Out; Their Shore",
    "Shur": "<b>Shur</b> - Wall; Ox; That Beholds",
    "Shushan": "<b>Shushan</b> - Lily; Rose; Joy",
    "Shuthelah": "<b>Shuthelah</b> - Plant; Verdure; Moist; Pot",
    "Sia": "<b>Sia</b> - Moving; Help",
    "Sibbechai": "<b>Sibbechai</b> - Bough; Cottage; Of Springs",
    "Sibmah": "<b>Sibmah</b> - Conversion; Captivity",
    "Sichem": "<b>Sichem</b> - Portion; Shoulder",
    "Siddim": "<b>Siddim</b> - The Tilled Field",
    "Sidon": "<b>Sidon</b> - Hunting; Fishing; Venison",
    "Sigionoth": "<b>Sigionoth</b> - According To Variable Songs Or Tunes,",
    "Sihon": "<b>Sihon</b> - Rooting Out; Conclusion",
    "Sihor": "<b>Sihor</b> - Black; Trouble (The River Nile)",
    "Silas": "<b>Silas</b> - Three, Or The Third",
    "Silla": "<b>Silla</b> - Exalting",
    "Siloa": "<b>Siloa</b> - Siloam, Siloe, Same As Shilhi",
    "Silvanus": "<b>Silvanus</b> - Who Loves The Forest",
    "Simeon": "<b>Simeon</b> - That Hears Or Obeys; That Is Heard",
    "Simon": "<b>Simon</b> - That Hears; That Obeys",
    "Sin": "<b>Sin</b> - Bush",
    "Sinai": "<b>Sinai</b> - A Bush; Enmity",
    "Sinim": "<b>Sinim</b> - South Country,",
    "Sinon": "<b>Sinon</b> - A Breast-Plate; Deliverance",
    "Sion": "<b>Sion</b> - Noise; Tumult",
    "Sippai": "<b>Sippai</b> - Threshold; Silver Cup",
    "Sisamai": "<b>Sisamai</b> - House; Blindness",
    "Sisera": "<b>Sisera</b> - That Sees A Horse Or A Swallow",
    "Sitnah": "<b>Sitnah</b> - Hatred",
    "Sivan": "<b>Sivan</b> - A Bush Or Thorn",
    "Smyrna": "<b>Smyrna</b> - Myrrh",
    "So": "<b>So</b> - A Measure For Grain; Vail",
    "Socoh": "<b>Socoh</b> - Tents; Tabernacles",
    "Sodi": "<b>Sodi</b> - My Secret",
    "Sodom": "<b>Sodom</b> - Their Secret; Their Cement",
    "Solomon": "<b>Solomon</b> - Peaceable; Perfect; One Who Recompenses",
    "Sopater": "<b>Sopater</b> - Sosipater, Who Defends The Father",
    "Sophereth": "<b>Sophereth</b> - Scribe, Numbering",
    "Sorek": "<b>Sorek</b> - Vine; Hissing; A Color Inclining To Yellow",
    "Sosthenes": "<b>Sosthenes</b> - Savior; Strong; Powerful",
    "Sotai": "<b>Sotai</b> - Conclusion In Pleading; Binding",
    "Spain": "<b>Spain</b> - Rare; Precious",
    "Stachys": "<b>Stachys</b> - Spike Or Ear Of Corn",
    "Stephanas": "<b>Stephanas</b> - Crown; Crowned",
    "Stephen": "<b>Stephen</b> - Same As Stephanas",
    "Suah": "<b>Suah</b> - Speaking; Entreating; Ditch",
    "Succoth": "<b>Succoth</b> - Tents; Tabernacles",
    "Succoth-Benoth": "<b>Succoth-Benoth</b> - The Tents Of Daughters, Or Young Women; Or Prostitutes",
    "Sud": "<b>Sud</b> - My Secret",
    "Sur": "<b>Sur</b> - That Withdraws Or Departs; Rebellion",
    "Susanna": "<b>Susanna</b> - Lily; Rose; Joy",
    "Susi": "<b>Susi</b> - Horse; Swallow; Moth",
    "Sychar": "<b>Sychar</b> - End",
    "Syene": "<b>Syene</b> - A Bush; Enmity",
    "Syntyche": "<b>Syntyche</b> - That Speaks Or Discourses",
    "Syracuse": "<b>Syracuse</b> - That Draws Violently",
    "Taanach": "<b>Taanach</b> - Who Humbles Thee; Who Answers Thee",
    "Taanach-Shilo": "<b>Taanach-Shilo</b> - Breaking Down A Fig-Tree",
    "Tabbath": "<b>Tabbath</b> - Good; Goodness",
    "Tabeal": "<b>Tabeal</b> - Tabeel, Good God",
    "Taberah": "<b>Taberah</b> - Burning",
    "Tabitha": "<b>Tabitha</b> - Clear-Sighted; A Roe-Deer",
    "Tabor": "<b>Tabor</b> - Choice; Purity; Bruising",
    "Tabrimon": "<b>Tabrimon</b> - Good Pomegranate; The Navel; The Middle",
    "Tadmor": "<b>Tadmor</b> - The Palm-Tree; Bitterness",
    "Tahan": "<b>Tahan</b> - Beseeching; Merciful",
    "Tahapenes": "<b>Tahapenes</b> - Secret Temptation",
    "Tahath": "<b>Tahath</b> - Fear; Going Down",
    "Tahpenes": "<b>Tahpenes</b> - Standard; Flight; Temptation",
    "Tahrea": "<b>Tahrea</b> - Anger; Wicked Contention",
    "Talitha-Cumi": "<b>Talitha-Cumi</b> - Young Woman, Arise",
    "Talmai": "<b>Talmai</b> - My Furrow; That Suspends The Waters; Heap Of Waters",
    "Tamah": "<b>Tamah</b> - Blotting Or Wiping Out; Smiting",
    "Tamar": "<b>Tamar</b> - Palm; Palm-Tree",
    "Tammuz": "<b>Tammuz</b> - Abstruse; Concealed; Consumed",
    "Tanach": "<b>Tanach</b> - Same As Taanach",
    "Tanhumeth": "<b>Tanhumeth</b> - Consolation; Repentance",
    "Taphath": "<b>Taphath</b> - Distillation; Drop",
    "Tappuah": "<b>Tappuah</b> - Apple; Swelling",
    "Tarah": "<b>Tarah</b> - A Hair; A Wretch; One Banished",
    "Taralah": "<b>Taralah</b> - Searching Out Slander, Or Strength",
    "Tarea": "<b>Tarea</b> - Howling; Doing Evil",
    "Tarpelites": "<b>Tarpelites</b> - Ravishers; Succession Of Miracles",
    "Tarshish": "<b>Tarshish</b> - Contemplation; Examination",
    "Tarsus": "<b>Tarsus</b> - Winged; Feathered",
    "Tartak": "<b>Tartak</b> - Chained; Bound; Shut Up",
    "Tartan": "<b>Tartan</b> - A General (Official Title)",
    "Tatnai": "<b>Tatnai</b> - That Gives; The Overseer Of The Gifts And Tributes",
    "Tebah": "<b>Tebah</b> - Murder; Butchery; Guarding Of The Body; A Cook",
    "Tebaliah": "<b>Tebaliah</b> - Baptism, Or Goodness, Of The Lord",
    "Tebeth": "<b>Tebeth</b> - Good, Goodness (The Tenth Month Of The Hebrews)",
    "Tehinnah": "<b>Tehinnah</b> - Entreaty; A Favor",
    "Tekel": "<b>Tekel</b> - Weight",
    "Tekoa": "<b>Tekoa</b> - Trumpet; That Is Confirmed",
    "Tel-Melah": "<b>Tel-Melah</b> - Heap Of Salt",
    "Telabib": "<b>Telabib</b> - A Heap Of New Grain",
    "Telah": "<b>Telah</b> - Moistening; Greenness",
    "Telassar": "<b>Telassar</b> - Taking Away; Heaping Up",
    "Telem": "<b>Telem</b> - Their Dew; Their Shadow",
    "Telharsa": "<b>Telharsa</b> - Suspension Of The Plow",
    "Tema": "<b>Tema</b> - Admiration; Perfection; Consummation",
    "Teman": "<b>Teman</b> - Temani, The South; Africa; Perfect",
    "Terah": "<b>Terah</b> - To Breathe; Scent; Blow",
    "Teraphim": "<b>Teraphim</b> - Images; Idols",
    "Tertius": "<b>Tertius</b> - Third",
    "Tertullus": "<b>Tertullus</b> - Third",
    "Tetrarch": "<b>Tetrarch</b> - Governor Of A Fourth Part",
    "Thaddeus": "<b>Thaddeus</b> - That Praises Or Confesses",
    "Thahash": "<b>Thahash</b> - That Makes Haste; That Keeps Silence",
    "Thamah": "<b>Thamah</b> - That Blots Out; That Suppresses",
    "Tharah": "<b>Tharah</b> - Same As Terah",
    "Thebez": "<b>Thebez</b> - Muddy; Eggs; Fine Linen Or Silk",
    "Thelasar": "<b>Thelasar</b> - Same As Telassar",
    "Theophilus": "<b>Theophilus</b> - Friend Of God",
    "Thessalonica": "<b>Thessalonica</b> - Victory Against The Thessalians",
    "Theudas": "<b>Theudas</b> - Flowing With Water",
    "Thomas": "<b>Thomas</b> - A Twin",
    "Thummim": "<b>Thummim</b> - Perfection; Truth",
    "Thyatira": "<b>Thyatira</b> - A Perfume; Sacrifice Of Labor",
    "Tibbath": "<b>Tibbath</b> - Killing; A Cook",
    "Tiberias": "<b>Tiberias</b> - Good Vision; The Navel",
    "Tiberius": "<b>Tiberius</b> - The Son Of Tiber",
    "Tibni": "<b>Tibni</b> - Straw; Hay",
    "Tidal": "<b>Tidal</b> - That Breaks The Yoke; Knowledge Of Elevation",
    "Tiglath-Pileser": "<b>Tiglath-Pileser</b> - That Binds Or Takes Away Captivity",
    "Tikvah": "<b>Tikvah</b> - Hope; A Little Line; Congregation",
    "Tilon": "<b>Tilon</b> - Murmuring",
    "Timeus": "<b>Timeus</b> - Perfect; Admirable; Honorable",
    "Timnah": "<b>Timnah</b> - Forbidding",
    "Timnath": "<b>Timnath</b> - Image; Figure; Enumeration",
    "Timnath-Heres": "<b>Timnath-Heres</b> - Or Timnath-Serah, Image Of The Sun; Numbering Of The Rest",
    "Timon": "<b>Timon</b> - Honorable; Worthy",
    "Timotheus": "<b>Timotheus</b> - Honor Of God; Valued Of God",
    "Tiphsah": "<b>Tiphsah</b> - Passage; Leap; Step; The Passover",
    "Tirhakah": "<b>Tirhakah</b> - Inquirer; Examiner; Dull Observer",
    "Tiria": "<b>Tiria</b> - Searching Out",
    "Tirshatha": "<b>Tirshatha</b> - A Governor",
    "Tirzah": "<b>Tirzah</b> - Benevolent; Complaisant; Pleasing",
    "Tishbite": "<b>Tishbite</b> - That Makes Captive",
    "Titus": "<b>Titus</b> - Pleasing",
    "Toah": "<b>Toah</b> - Weapon; Dart",
    "Tob": "<b>Tob</b> - Good; Goodness",
    "Tob-Adonijah": "<b>Tob-Adonijah</b> - My Good God; The Goodness Of The Foundation Of The Lord",
    "Tobiah": "<b>Tobiah</b> - Tobijah, The Lord Is Good",
    "Tochen": "<b>Tochen</b> - Middle",
    "Togarmah": "<b>Togarmah</b> - Which Is All Bone",
    "Tohu": "<b>Tohu</b> - That Lives; That Declares",
    "Toi": "<b>Toi</b> - Who Wanders",
    "Tola": "<b>Tola</b> - Worm; Grub; Scarlet",
    "Tolad": "<b>Tolad</b> - A Generation",
    "Tophel": "<b>Tophel</b> - Ruin; Folly; Without Understanding",
    "Tophet": "<b>Tophet</b> - A Drum; Betraying",
    "Trachonitis": "<b>Trachonitis</b> - Stony",
    "Troas": "<b>Troas</b> - Penetrated",
    "Trophimus": "<b>Trophimus</b> - Well Educated; Well Brought Up",
    "Tryphena": "<b>Tryphena</b> - Delicious; Delicate",
    "Tryphon": "<b>Tryphon</b> - Masculine Of Tryphena",
    "Tryphosa": "<b>Tryphosa</b> - Thrice Shining",
    "Tubal": "<b>Tubal</b> - The Earth; The World; Confusion",
    "Tubal-Cain": "<b>Tubal-Cain</b> - Worldly Possession; Possessed Of Confusion",
    "Tychicus": "<b>Tychicus</b> - Casual; By Chance",
    "Tyrannus": "<b>Tyrannus</b> - A Prince; One That Reigns",
    "Tyre": "<b>Tyre</b> - Tyrus, Strength; Rock; Sharp",
    "Ucal": "<b>Ucal</b> - Power, Prevalency",
    "Uel": "<b>Uel</b> - Desiring God",
    "Ulai": "<b>Ulai</b> - Strength; Fool; Senseless",
    "Ulam": "<b>Ulam</b> - The Porch; The Court; Their Strength; Their Folly",
    "Ulla": "<b>Ulla</b> - Elevation; Leaf; Young Child",
    "Ummah": "<b>Ummah</b> - Darkened; Covered; His People",
    "Unni": "<b>Unni</b> - Poor; Afflicted; That Answers",
    "Upharsin": "<b>Upharsin</b> - Divided",
    "Uphaz": "<b>Uphaz</b> - Pure Gold; Gold Of Phasis Or Pison",
    "Ur": "<b>Ur</b> - Fire, Light, A Valley",
    "Urbane": "<b>Urbane</b> - Courteous",
    "Uri": "<b>Uri</b> - My Light, My Fire",
    "Uriah": "<b>Uriah</b> - Or Urijah, The Lord Is My Light Or Fire",
    "Uriel": "<b>Uriel</b> - Same As Uriah",
    "Urim": "<b>Urim</b> - Lights; Fires",
    "Uthai": "<b>Uthai</b> - My Iniquity",
    "Uz": "<b>Uz</b> - Counsel; Words",
    "Uzai": "<b>Uzai</b> - He",
    "Uzal": "<b>Uzal</b> - Wandering",
    "Uzzah": "<b>Uzzah</b> - Strength; Goat",
    "Uzzen-Sherah": "<b>Uzzen-Sherah</b> - Ear Of The Flesh",
    "Uzzi": "<b>Uzzi</b> - My Strength; My Kid",
    "Uzziah": "<b>Uzziah</b> - Uzziel, The Strength, Or Kid, Of The Lord",
    "Vajezatha": "<b>Vajezatha</b> - Sprinkling The Chamber",
    "Vaniah": "<b>Vaniah</b> - Nourishment, Or Weapons, Of The Lord",
    "Vashni": "<b>Vashni</b> - The Second; Changed; A Tooth",
    "Vashti": "<b>Vashti</b> - That Drinks; Thread",
    "Vophsi": "<b>Vophsi</b> - Fragrant; Diminution",
    "Zaanannim": "<b>Zaanannim</b> - Movings; A Person Asleep",
    "Zaavan": "<b>Zaavan</b> - Trembling",
    "Zabad": "<b>Zabad</b> - Dowry; Endowed",
    "Zabbai": "<b>Zabbai</b> - Flowing",
    "Zabdi": "<b>Zabdi</b> - Same As Zabad",
    "Zaccai": "<b>Zaccai</b> - Pure Meat; Just",
    "Zaccheus": "<b>Zaccheus</b> - Pure; Clean; Just",
    "Zaccur": "<b>Zaccur</b> - Of The Male Kind; Mindful",
    "Zachariah": "<b>Zachariah</b> - Memory Of The Lord",
    "Zadok": "<b>Zadok</b> - Just; Justified",
    "Zaham": "<b>Zaham</b> - Crime; Filthiness; Impurity",
    "Zair": "<b>Zair</b> - Little; Afflicted; In Tribulation",
    "Zalaph": "<b>Zalaph</b> - Shadow; Ringing; Shaking",
    "Zalmon": "<b>Zalmon</b> - His Shade; His Image",
    "Zalmonah": "<b>Zalmonah</b> - The Shade; The Sound Of The Number; His Image",
    "Zalmunna": "<b>Zalmunna</b> - Shadow; Image; Idol Forbidden",
    "Zamzummims": "<b>Zamzummims</b> - Projects Of Crimes; Enormous Crimes",
    "Zanoah": "<b>Zanoah</b> - Forgetfulness; Desertion",
    "Zaphnath-Paaneah": "<b>Zaphnath-Paaneah</b> - One Who Discovers Hidden Things",
    "Zarah": "<b>Zarah</b> - East; Brightness",
    "Zareah": "<b>Zareah</b> - Leprosy; Hornet",
    "Zared": "<b>Zared</b> - Strange Descent",
    "Zarephath": "<b>Zarephath</b> - Ambush Of The Mouth",
    "Zaretan": "<b>Zaretan</b> - Tribulation; Perplexity",
    "Zatthu": "<b>Zatthu</b> - Olive Tree",
    "Zaza": "<b>Zaza</b> - Belonging To All",
    "Zebadiah": "<b>Zebadiah</b> - Portion Of The Lord; The Lord Is My Portion",
    "Zebah": "<b>Zebah</b> - Victim; Sacrifice",
    "Zebedee": "<b>Zebedee</b> - Abundant; Portion",
    "Zebina": "<b>Zebina</b> - Flowing Now; Selling; Buying",
    "Zeboiim": "<b>Zeboiim</b> - Deer; Goats",
    "Zebudah": "<b>Zebudah</b> - Endowed; Endowing",
    "Zebul": "<b>Zebul</b> - A Habitation",
    "Zebulun": "<b>Zebulun</b> - Zebulon, Dwelling; Habitation",
    "Zechariah": "<b>Zechariah</b> - Same As Zachariah",
    "Zedad": "<b>Zedad</b> - His Side; His Hunting",
    "Zedekiah": "<b>Zedekiah</b> - The Lord Is My Justice; The Justice Of The Lord",
    "Zeeb": "<b>Zeeb</b> - Wolf",
    "Zelah": "<b>Zelah</b> - Rib; Side; Halting",
    "Zelek": "<b>Zelek</b> - The Shadow Or Noise Of Him That Licks Or Laps",
    "Zelophehad": "<b>Zelophehad</b> - The Shade Or Tingling Of Fear",
    "Zelotes": "<b>Zelotes</b> - Zealous",
    "Zelzah": "<b>Zelzah</b> - Noontide",
    "Zemaraim": "<b>Zemaraim</b> - Wool; Pith",
    "Zemira": "<b>Zemira</b> - Song; Vine; Palm",
    "Zenan": "<b>Zenan</b> - Coldness; Target; Weapon",
    "Zenas": "<b>Zenas</b> - Living",
    "Zephaniah": "<b>Zephaniah</b> - The Lord Is My Secret",
    "Zephath": "<b>Zephath</b> - Which Beholds; That Attends Or That Covers",
    "Zepho": "<b>Zepho</b> - Zephon, That Sees And Observes; That Expects Or Covers",
    "Zer": "<b>Zer</b> - Perplexity",
    "Zerah": "<b>Zerah</b> - Same As Zarah",
    "Zerahiah": "<b>Zerahiah</b> - The Lord Rising; Brightness Of The Lord",
    "Zeredah": "<b>Zeredah</b> - Ambush; Change Of Dominion",
    "Zeresh": "<b>Zeresh</b> - Misery; Strange; Dispersed Inheritance",
    "Zereth": "<b>Zereth</b> - Same As Zer",
    "Zeror": "<b>Zeror</b> - Root; That Straitens Or Binds; That Keeps Tight",
    "Zeruah": "<b>Zeruah</b> - Leprous; Wasp; Hornet",
    "Zerubbabel": "<b>Zerubbabel</b> - A Stranger At Babylon; Dispersion Of Confusion",
    "Zeruiah": "<b>Zeruiah</b> - Pain Or Tribulation Of The Lord",
    "Zethar": "<b>Zethar</b> - He That Examines Or Beholds",
    "Zia": "<b>Zia</b> - Sweat; Swelling",
    "Ziba": "<b>Ziba</b> - Army; Fight; Strength",
    "Zibeon": "<b>Zibeon</b> - Iniquity That Dwells",
    "Zibiah": "<b>Zibiah</b> - The Lord Dwells; Deer; Goat",
    "Zichri": "<b>Zichri</b> - That Remembers; That Is A Man",
    "Ziddim": "<b>Ziddim</b> - Huntings; Treasons; Destructions",
    "Zidkijah": "<b>Zidkijah</b> - Justice Of The Lord",
    "Zidon": "<b>Zidon</b> - Hunting; Fishing; Venison",
    "Zif": "<b>Zif</b> - This Or That; Brightness; Comeliness",
    "Ziha": "<b>Ziha</b> - Brightness; Whiteness; Drought",
    "Ziklag": "<b>Ziklag</b> - Measure Pressed Down",
    "Zillah": "<b>Zillah</b> - Shadow; The Tingling Of The Ear",
    "Zilpah": "<b>Zilpah</b> - Distillation From The Mouth",
    "Zilthai": "<b>Zilthai</b> - My Shadow; My Talk",
    "Zimmah": "<b>Zimmah</b> - Thought; Wickedness",
    "Zimran": "<b>Zimran</b> - Song; Singer; Vine",
    "Zimzi": "<b>Zimzi</b> - My Field; My Vine",
    "Zin": "<b>Zin</b> - Buckler; Coldness",
    "Zina": "<b>Zina</b> - Shining; Going Back",
    "Zion": "<b>Zion</b> - Monument; Raised Up; Sepulcher",
    "Zior": "<b>Zior</b> - Ship Of Him That Watches",
    "Ziph": "<b>Ziph</b> - This Mouth Or Mouthful; Falsehood",
    "Ziphron": "<b>Ziphron</b> - Falsehood Of A Song; Rejoicing",
    "Zippor": "<b>Zippor</b> - Bird; Sparrow; Crown; Desert",
    "Zipporah": "<b>Zipporah</b> - Beauty; Trumpet; Mourning",
    "Zithri": "<b>Zithri</b> - To Hide; Demolished",
    "Ziz": "<b>Ziz</b> - Flower; Branch; A Lock Of Hair",
    "Ziza": "<b>Ziza</b> - Same As Zina",
    "Zoan": "<b>Zoan</b> - Motion",
    "Zoar": "<b>Zoar</b> - Little; Small",
    "Zobah": "<b>Zobah</b> - Zobebah, An Army; Warring",
    "Zohar": "<b>Zohar</b> - White; Bright; Dryness",
    "Zoheleth": "<b>Zoheleth</b> - That Creeps, Slides, Or Draws",
    "Zoheth": "<b>Zoheth</b> - Separation; Amazing",
    "Zophah": "<b>Zophah</b> - Viol; Honeycomb",
    "Zophar": "<b>Zophar</b> - Rising Early; Crown",
    "Zophim": "<b>Zophim</b> - Place For A Watchman",
    "Zorah": "<b>Zorah</b> - Leprosy; Scab; Hornet",
    "Zorobabel": "<b>Zorobabel</b> - Same As Zerubbabel",
    "Zuar": "<b>Zuar</b> - Same As Zoar",
    "Zuph": "<b>Zuph</b> - That Beholds, Observes, Watches; Roof; Covering",
    "Zur": "<b>Zur</b> - Stone; Rock; That Besieges",
    "Zuriel": "<b>Zuriel</b> - Rock Or Strength Of God",
    "Zurishaddai": "<b>Zurishaddai</b> - The Almighty Is My Rock And Strength",
    "Zuzims": "<b>Zuzims</b> - The Posts Of A Door; Splendor; Beauty",
}
